# AUTHOR: JOSHUA KIM

# PURPOSE: Take the new Walmart dta files with Customer Keys 
# and create a Consumer Dataset with Consumer / Week level
# information. Use this consumer data to sample consumers
# to create the panel dataset.

# INPUTS:
# 1. w_i.dta

# OUTPUTS:
# 1. consumers.csv

rm(list=ls())

# -------------------------------
#        FUNCTIONS

getDtaName = function(i){
  # Given an integer i, returns a string called
  # 'wi.dta'
  
  dta.file = paste('w_', i, '.dta', sep = '')
  
  return(dta.file)
}

getMode = function(x){
  ux = unique(x)
  mode = ux[which.max(tabulate(match(x, ux)))]
  return(mode)
}

cleanDta = function(dta){
  # Cleans a raw dta file
  
  cl.dta = dta[rut_doc != 'NULL', ]
  
  cl.dta = cl.dta[quantity > 0, ]
  
  cl.dta[, NumTransactions := uniqueN(trx_id), by = rut_doc]
  cl.dta[, NumVisits := uniqueN(date), by = rut_doc]
  cl.dta[, TotalSpent := sum(sales_final), by = rut_doc]
  cl.dta[, TotalProducts := sum(quantity), by = rut_doc]
  
  # Note: Mode is actually the most shopped at store, 
  # weighted by total products bought
  cl.dta[, MainStore := getMode(store_id), by = rut_doc]
  
  keep.vars = c('rut_doc', 'week', 'NumTransactions',
                'NumVisits', 'TotalSpent', 'TotalProducts',
                'MainStore')
  
  cl.dta = unique(cl.dta[, ..keep.vars])
  
  return(cl.dta)
}

# ------------------------------
#         SET UP 

library(data.table)
library(readstata13)

data.dir = './00_files/02_intermediate/01_panel/weekly_data/'
out.dir = './00_files/02_intermediate/03_consumers'

setwd(data.dir)

# -----------------------------
#        Get all the consumers data

consumers.dta = data.table()

for (i in 1:152){
  print(i)
  dta.name = getDtaName(i)
  
  rawDta.file = data.table(read.dta13(dta.name))
  dta.file = cleanDta(rawDta.file)
  
  consumers.dta = rbind(consumers.dta, dta.file)
  
}

setwd(out.dir)

fwrite(consumers.dta, file = '01_consumers.csv')
