/*******************************************************************************
AUTHOR: Nano & Cris
CREATION: 03-July-18
MODIFIED: 30-July-18
ACTION: Products List to Products Raw
*******************************************************************************/

clear all
set more off

******************************************************************************** 
** 1. SET PATH AND LOCALS
******************************************************************************** 

if c(username)=="Nano"   		  global Repo "/Users/Nano/Dropbox/Research/FoodLabels/food_labels/04_replication"
else 							  global Repo "."

******************************************************************************** 
** 2. MERGE THREE DATASETS
******************************************************************************** 


*** 1. Product List

import delimited "${Repo}/00_files/01_source/01_walmart/productList.txt", delimiter("|") varnames(nonames) stripquote(yes) clear stringc(_all) bindq(nobind)

ren v1 item_id
ren v2 product_id 
ren v3 upc_id 
ren v4 name 
ren v5 brand 
ren v6 package 
ren v7 type_unit
ren v8 sell_q 
ren v9 department 
ren v10 category 
ren v11 subcategory 
ren v12 fineline 
ren v13 country 
ren v14 date_creation 
ren v15 date_shipping 

duplicates drop upc_id, force

drop date_creation date_shipping

tempfile main
save `main', replace


*** 2. Include products classification

import excel "${Repo}/00_files/01_source/01_walmart/Clasificacion.xlsx", sheet("Hoja1") firstrow allstring clear case(lower) // encoding(utf8) 
 
ren segmento segmento_name
ren categoria category_name
ren depto_comercial department_name
ren subcategoria subcategory_name
ren subgrupo subgrupo_name
ren findline fineline_name

ren cod_segmento  segmento
ren cod_subgrupo subgrupo
ren cod_depto_comercial  department
ren cod_categoria category
ren cod_subcategoria subcategory
ren cod_fineline  fineline   

foreach var in department category subcategory fineline {
destring `var', replace
}
duplicates drop department category subcategory fineline, force

foreach var in department_name category_name subcategory_name fineline_name {
replace `var' = trim(itrim(`var'))
}
tempfile tempcat
save `tempcat', replace


*** 3. Include info of scanned products

import delimited "${Repo}/00_files/01_source/02_nutrition/Productos_escaneados_3.csv", delimiter(",") stripquote(yes) clear stringc(_all) bindq(strict)

ren barra upc_id
ren aa label_sugar
ren as label_sodium 
ren ag label_fat_sat
ren ac label_energy 
ren foto picture
ren usuario enumerator
ren momentoescaneo scan_timestamp

drop nombre marca

tempfile tempscan
save `tempscan', replace

use `main', clear
foreach var in department category subcategory fineline {
destring `var', replace
}
merge n:1 department category subcategory fineline using `tempcat'
drop if _merge==2
drop _merge

merge 1:1 upc_id using `tempscan'
gen scanned = _merge==3
drop _merge

* 1 if it has label, 0 otherwise
replace label_sugar   = "1" if label_sugar   == "Si"
replace label_sugar   = "0" if label_sugar   == "No"
replace label_sodium  = "1" if label_sodium  == "Si"
replace label_sodium  = "0" if label_sodium  == "No"
replace label_fat_sat = "1" if label_fat_sat == "Si"
replace label_fat_sat = "0" if label_fat_sat == "No"
replace label_energy  = "1" if label_energy  == "Si"
replace label_energy  = "0" if label_energy  == "No"
destring label*, replace


save "${Repo}/00_files/02_intermediate/02_nutrition/01_products_raw.dta", replace
