/*******************************************************************************
AUTHOR: Cristine von Dessauer
CREATION: 13-mayo-2018
ACTION: Define which products are food/non-food and packaged/non-packaged 
********************************************************************************/

clear all
set more off

set scheme s1mono

******************************************************************************** 
** SET PATH AND LOCALS
******************************************************************************** 

if c(username)=="Nano"   		  global Repo "/Users/Nano/Dropbox/Research/FoodLabels/food_labels/04_replication"
else 							  global Repo "."


******************************************************************************** 
** LOAD DATA
******************************************************************************** 

use "${Repo}/00_files/02_intermediate/02_nutrition/01_products_raw.dta", clear

******************************************************************************** 
** DEFINE WHICH PRODUCTS ARE FOOD/NON-FOOD, KEEP FOOD 
******************************************************************************** 


gen food=1

* DEPARTMENTS

replace food=0 if department_name=="02 CUIDADO E HIGIENE CORPORAL"
replace food=0 if department_name=="03 LIBRERIA/PAPELERIA"
replace food=0 if department_name=="04 PAPELES DOMESTICOS"
replace food=0 if department_name=="05 ELECTRONICA"
replace food=0 if department_name=="06 FOTOGRAFIA"
replace food=0 if department_name=="07 JUGUETES"
replace food=0 if department_name=="08 MASCOTAS"
replace food=0 if department_name=="09 DEPORTES"
replace food=0 if department_name=="10 AUTOMOTRIZ"
replace food=0 if department_name=="11 FERRETERIA"
replace food=0 if department_name=="12 PINTURAS"
replace food=0 if department_name=="13 QUIMICOS/ARTICULOS DE LIMPIEZA"
replace food=0 if department_name=="14 ARTICULOS HOGAR/ORGANIZACION"
replace food=0 if department_name=="15 ELECTRODOMESTICOS"
replace food=0 if department_name=="16 JARDINERIA"
replace food=0 if department_name=="17 MUEBLES/DECORACION/MALETERIA"
replace food=0 if department_name=="18 ARTICULOS DE TEMPORADA"
replace food=0 if department_name=="19 TELAS/MANUALIDADES"
replace food=0 if department_name=="20 COCINA Y BANO"
replace food=0 if department_name=="21 CORTINAS Y PERSIANAS"
replace food=0 if department_name=="22 ROPA DE CAMA"
replace food=0 if department_name=="23 CABALLEROS"
replace food=0 if department_name=="24 NINOS"
replace food=0 if department_name=="25 ZAPATERIA"
replace food=0 if department_name=="27 CALCETINES"
replace food=0 if department_name=="28 PANTY MEDIAS"
replace food=0 if department_name=="29 ROPA DE DORMIR"
replace food=0 if department_name=="30 ROPA INTERIOR"
replace food=0 if department_name=="31 ACCESORIOS"
replace food=0 if department_name=="32 JOYERIA"
replace food=0 if department_name=="33 NINAS"
replace food=0 if department_name=="34 DAMAS"
replace food=0 if department_name=="35 MATERNIDAD Y TALLAS GRANDES"
replace food=0 if department_name=="37 VENTAS DESCONTADAS"
replace food=0 if department_name=="40 CUIDADO Y SALUD"
replace food=0 if department_name=="46 COSMETICOS"
replace food=0 if department_name=="49 OPTICA"
replace food=0 if department_name=="53 DESCARTABLES Y CUMPLEANOS"
replace food=0 if department_name=="56 VIVERO/PLANTAS VIVAS"
replace food=0 if department_name=="58 WARRANTIES"
replace food=0 if department_name=="59 COSMETICOS"
replace food=0 if department_name=="66 DEPOSITO DE BOTELLAS"
replace food=0 if department_name=="67 HOME DELIVERY"
replace food=0 if department_name=="73 LIBROS Y REVISTAS"
replace food=0 if department_name=="74 VESTUARIO BEBE"
replace food=0 if department_name=="77 LINEA BLANCA HOGAR"
replace food=0 if department_name=="79 HARDLINES BEBE"
replace food=0 if department_name=="84 FLORES/BOUQUET"
replace food=0 if department_name=="86 FINANCIAL SERVICES"
replace food=0 if department_name=="87 TELEFONO MOVIL"
replace food=0 if department_name=="89 VENTAS SUSTENTABLES"
replace food=0 if department_name=="99 SUMISTROS PARA CONSUMO INTERNO"

	// DROP BABY-RELATED ITEMS
replace food=0 if department_name=="26 CONSUMIBLE BEBE"

* CATEGORIES

replace food=0 if category_name=="08353 TABACO & FUMAR"
replace food=0 if category_name=="08403 PA?ALES BEBE-ENTRENA"
replace food=0 if category_name=="08407 ACCES DORMIR"
replace food=0 if category_name=="08408 JUGUETES Y ACTIVIDADES"
replace food=0 if category_name=="08412 BEBE - ROPA CASUAL"
replace food=0 if category_name=="08418 REVISTAS Y PERI?DICOS"
replace food=0 if category_name=="08420 PILAS"
replace food=0 if category_name=="08984 BEBE - ROPA INTERIOR"
replace food=0 if category_name=="09467 MUEBLES PARA BEBE"
replace food=0 if category_name=="09535 APARATOS DE CUIDADO PERSONAL"
replace food=0 if category_name=="09547 CHECKOUTS - COLAS PEGAMENTOS & SELLANTES"
replace food=0 if category_name=="09550 COMO VISTO EN TV"
replace food=0 if category_name=="09564 CHECKOUTS - SET DE REGALO"
replace food=0 if category_name=="09567 SOUVENIR & RECUERDOS"
replace food=0 if category_name=="09760 CONSIGNADO AFECTO"
replace food=0 if category_name=="10922 CVP"
replace food=0 if category_name=="10923 CVP"
replace food=0 if category_name=="10924 CVP"
replace food=0 if category_name=="10925 CVP"
replace food=0 if category_name=="10926 CVP"
replace food=0 if category_name=="10928 CVP"
replace food=0 if category_name=="10929 CVP"
replace food=0 if category_name=="10930 CVP"
replace food=0 if category_name=="10943 CVP"
replace food=0 if category_name=="10960 CVP"
replace food=0 if category_name=="10961 CVP"
replace food=0 if category_name=="10962 CVP"
replace food=0 if category_name=="10963 CVP"
replace food=0 if category_name=="11098 CANASTAS FIESTAS"

* DROP OTHERS

replace food=0 if strpos(name,"ERROR DE")!=0
replace food=0 if strpos(name,"ERROR CREACION")!=0

/* Non-food items associated with product packaging*/

replace food=0 if strpos(name,"ALUMINIO") & strpos(subcategory_name, "MATERIAS")
replace food=0 if strpos(name,"ENV")      & strpos(subcategory_name, "MATERIAS")
replace food=0 if strpos(name, "BOLETA") != 0
replace food=0 if strpos(name, "INVENTARIO") != 0
replace food=0 if strpos(name, "INGRESO") != 0
replace food=0 if strpos(name, "SHIPPER") != 0
replace food=0 if strpos(name, "SHIPER") != 0

replace food=0 if fineline_name=="9000 ITEMS OBSOLETOS"

/* Non-food items associated with the administration of the establishment*/

/*Promotional Products that were only temprarily sold*/

******************************************************************************** 
** MERGE   
******************************************************************************** 

******************************************************************************** 
** IDENTIFY WHICH PRODUCTS ARE PACKAGED/NON-PACKAGED  
******************************************************************************** 

gen pckg = .
label variable pckg "Takes value 1 if product is packaged, 0 otherwise"

replace pckg = 0 if strpos(department_name, "CARNE") != 0
replace pckg = 0 if strpos(department_name, "FRUTAS") != 0
replace pckg = 0 if strpos(department_name, "PANADERIA") != 0 &  strpos(subcategory_name,"LOCAL")!= 0 & strpos(category_name,"PAN")!= 0 & strpos(category_name,"LOCAL")!= 0 
replace pckg = 0 if strpos(department_name, "PANADERIA") != 0 &  strpos(subcategory_name,"MATERIA")!= 0  & strpos(name,"CORRIENTE")!= 0 
replace pckg = 0 if strpos(department_name, "PANADERIA") != 0 &  strpos(subcategory_name,"MATERIA")!= 0  & strpos(name,"INTEGRAL")!= 0 
/*Assigning the value zero to all departments where most of the products are unpacked*/

replace pckg = 1 if strpos(department_name, "PANADERIA") != 0 &  pckg!=0

replace pckg = 1 if strpos(department_name, "CONFITERIA") != 0
replace pckg = 1 if strpos(department_name, "BEBE") != 0
replace pckg = 1 if strpos(department_name, "SNACK") != 0
replace pckg = 1 if strpos(department_name, "CHECK") != 0
replace pckg = 1 if strpos(department_name, "SERVICE") != 0
replace pckg = 1 if strpos(department_name, "LACTEOS") != 0
replace pckg = 1 if strpos(department_name, "CONGELADOS") != 0
replace pckg = 1 if strpos(department_name, "ABARROTES") != 0
replace pckg = 1 if strpos(department_name, "LICORES") != 0
replace pckg = 1 if strpos(department_name, "PESCADO") != 0
/*Assigning the value one to all departments where most of the products are packed*/

replace pckg = 0 if strpos(package, "GRA") != 0
replace pckg = 0 if strpos(package, "MAL") != 0
replace pckg = 0 if strpos(package, "S-E") != 0
replace pckg = 0 if strpos(package, "UNI") != 0
/*Assigning the value zero to all products without package, sold in bulk*/

replace pckg = 0 if strpos(name, "GRANEL") != 0
/*Assigning the value zero to all products whose name indicates they are sold in bulk*/

replace pckg = 1 if strpos(package, "CAJA") != 0
replace pckg = 1 if strpos(package, "CJ") != 0
replace pckg = 1 if strpos(package, "CAJ") != 0
replace pckg = 1 if strpos(package, "BOT") != 0
replace pckg = 1 if strpos(package, "BOL") != 0
replace pckg = 1 if strpos(package, "BID") != 0
replace pckg = 1 if strpos(package, "PAC") != 0
replace pckg = 1 if strpos(package, "LAT") != 0
replace pckg = 1 if strpos(package, "FCO") != 0
replace pckg = 1 if strpos(package, "PQT") != 0
replace pckg = 1 if strpos(package, "TAR") != 0
replace pckg = 1 if strpos(package, "SOB") != 0
replace pckg = 1 if strpos(package, "BAN") != 0
replace pckg = 1 if strpos(package, "SAC") != 0
replace pckg = 1 if strpos(package, "POT") != 0
replace pckg = 1 if strpos(package, "BAR") != 0
replace pckg = 1 if strpos(package, "GAL") != 0
replace pckg = 1 if strpos(package, "TAB") != 0
replace pckg = 1 if strpos(package, "PAQ") != 0
replace pckg = 1 if strpos(package, "TIR") != 0
replace pckg = 1 if strpos(package, "PAN") != 0
replace pckg = 1 if strpos(package, "EST") != 0
replace pckg = 1 if strpos(package, "BAG") != 0
replace pckg = 1 if strpos(package, "FRASCO") != 0
replace pckg = 1 if strpos(package, "MIPE") != 0
replace pckg = 1 if strpos(package, "PAR") != 0
replace pckg = 1 if strpos(package, "PDQ") != 0
replace pckg = 1 if strpos(package, "POM") != 0
replace pckg = 1 if strpos(package, "ROL") != 0
replace pckg = 1 if strpos(package, "TAM") != 0
replace pckg = 1 if strpos(package, "TUB") != 0
replace pckg = 1 if strpos(package, "VER") != 0
replace pckg = 1 if strpos(package, "VAS") != 0
replace pckg = 1 if strpos(package, "VAC") != 0
replace pckg = 1 if strpos(package, "PAL") != 0
replace pckg = 1 if strpos(package, "DOY") != 0
replace pckg = 1 if strpos(package, "MIX") != 0
/*Assigning the value one to all products whose package variable indicates they are packaged*/

replace pckg = 1 if strpos(name, "CAJA") != 0
replace pckg = 1 if strpos(name, "BOTELLA") != 0
replace pckg = 1 if strpos(name, "BOLSA") != 0
replace pckg = 1 if strpos(name, "BIDON") != 0
replace pckg = 1 if strpos(name, "PACK") != 0
replace pckg = 1 if strpos(name, "LATA") != 0
replace pckg = 1 if strpos(name, "FRASCO") != 0
replace pckg = 1 if strpos(name, "PQT") != 0
replace pckg = 1 if strpos(name, "TARRO") != 0
replace pckg = 1 if strpos(name, "SOBRE ") != 0
replace pckg = 1 if strpos(name, "SACO") != 0
replace pckg = 1 if strpos(name, "POTE") != 0
replace pckg = 1 if strpos(name, "BARRA") != 0
replace pckg = 1 if strpos(name, "FRASCO") != 0
replace pckg = 1 if strpos(name, "POUCH") != 0
replace pckg = 1 if strpos(name, "GASEOSA") != 0
/*Assigning the value one to all products whose name indicates they are packaged*/

replace pckg = . if food == 0
/*Assigns no value to pckg if product is not food*/

order pckg, after(package)
sort pckg package

codebook pckg

save "${Repo}/00_files/02_intermediate/02_nutrition/02_products_food.dta", replace
export delimited using "${Repo}/00_files/02_intermediate/02_nutrition/02b_products_food.csv", delimiter(tab) nolabel replace
