
/*******************************************************************************
AUTHOR: Cristóbal & Nine
CREATION: 05-July-18
MODIFIED: 30-July-18
ACTION: Clean nutritional information raw data
*******************************************************************************/

clear all
set more off

******************************************************************************** 
** 1. SET PATH AND LOCALS
******************************************************************************** 

if c(username)=="Nano"   		  global Repo "/Users/Nano/Dropbox/Research/FoodLabels/food_labels/04_replication"
else 							  global Repo "."


******************************************************************************** 
** 2. PRELIMINARIES
******************************************************************************** 


import excel using "${Repo}/00_files/01_source/02_nutrition/nutritional_info_raw.xlsx", first clear
duplicates drop image_name, force

** Fix Portion Size
replace portion_size = "" if strpos(portion_size,"+")
egen fixed_size = sieve(portion_size), keep (n o)
order fixed_size, after(portion_size)
drop portion_size
rename fixed_size portion_size


******************************************************************************** 
** 3. CORRECT POSSIBLE MISTAKES & PAVAN's REMARKS and OBSERVATIONS
******************************************************************************** 
/* See 07_clearNutritionalInfo_v1 for checking procedures */

* Clean spaces and replace commas
	foreach i in portion_size energy_100 energy_portion proteins_100 proteins_portion fat_100            ///
			 fat_portion fat_sat_100 fat_sat_portion fat_mono_portion fat_poli_100 fat_poli_portion  ///
			 fat_acids_100 fat_acids_portion cholesterol_100 cholesterol_portion carbs_100           ///
			 carbs_portion sugar_100 sugar_portion sugar_sacch_100 sugar_sacch_portion dietfiber_100 ///
			 dietfiber_portion sodium_100 sodium_portion calcium_100 calcium_portion vitB2_100 		 /// 
			 vitB2_portion iodo_100 iodo_portion {
		replace `i' = trim(itrim(`i'))
		replace `i' = subinstr(`i',",",".",.)
		replace `i' = subinstr(`i'," ","",.)
		replace `i' = subinstr(`i',"(**)","",.)
}


** Correct observations by nutrient
	/* Portion size & type */ {
	replace portion_size = "12"   if image_name == "78742236063-201803240753156798image.jpg"
	replace portion_size = "12.5" if image_name == "7613035089495-2018032407044523746image.jpg"
	replace portion_size = "50"   if image_name == "7804636410010-2018032411024810091image.jpg"
	replace portion_size = "150"  if image_name == "7804641490021-201803241041331965image.jpg"
	replace portion_size = "140"  if image_name == "7802910004047-2018032410242722049image.jpg"
	replace portion_size = "22"   if image_name == "7807900004625-2018041408573421642image.jpg"
	replace portion_size = "21"   if image_name == "7790580151300-201803241037497262image.jpg"
	replace portion_size = "8.8"  if image_name == "5099864006094-2018041410553713723image.jpg"
	replace portion_size = "60"   if image_name == "7790349851083-201803240713086591521897145701463971576.jpg"
	replace portion_size = "117"  if image_name == "78742089737-2018032411160521401image.jpg"
	replace portion_size = "89"   if image_name == "78742099118-2018032409585413910image.jpg"
	replace portion_size = "89"   if image_name == "78742099118-2018032410001410911image.jpg"
	replace portion_size = "68"   if image_name == "78742122601-201803241003121628image.jpg"
	replace portion_size = "300"  if image_name == "7804640480030-2018032411322512121image.jpg"
	replace portion_size = "300"  if image_name == "7804640480030-201803241132435564image.jpg"
	replace portion_size = "4.4"  if image_name == "7613032054694-201804140723028454image.jpg"
	replace portion_size = "31"   if image_name == "5099864007190-201804141056293443image.jpg"
	replace portion_size = "51"   if image_name == "0206171011610-2018060215480222856image.jpg"
	replace portion_size = "140"  if image_name == "7802920006802-2018060213084014480image.jpg"
	replace portion_size = "40"   if image_name == "7803525000714-201806021207346794image.jpg"
	replace portion_size = "200"  if image_name == "2093190000002-20180603094551228361528040675127988639078.jpg"
	replace portion_size = "64"   if image_name == "41789001833-201803241019187325image.jpg"
	replace portion_size = "64"   if image_name == "41789001918-201803241020479799image.jpg"
	replace portion_size = "64"   if image_name == "41789001925-2018032410201218546image.jpg"
	replace portion_size = "64"   if image_name == "41789001956-20180324102118836image.jpg"
	replace portion_size = "64"   if image_name == "41789001956-2018032410214410267image.jpg"
	replace portion_size = "64"   if image_name == "41789001987-2018032410184313398image.jpg"
	replace portion_size = "47.2" if image_name == "41789003981-2018032410165113775image.jpg"
	replace portion_size = "56.7" if image_name == "41789007927-201803241016083287image.jpg"
	replace portion_size = "4.6"  if image_name == "7613034467683-201803240958465348image.jpg"
	replace portion_size = "4.8"  if image_name == "7613035190139-2018032409542821799image.jpg"
	replace portion_size = "4.8"  if image_name == "7613035190467-2018032409552524307image.jpg"
	replace portion_size = "4.6"  if image_name == "7613035190498-2018032409481110401image.jpg"
	replace portion_size = "5"    if image_name == "7613035190528-2018032409531114234image.jpg"
	replace portion_size = "4.8"  if image_name == "7613035191792-201803240954566453image.jpg"
	replace portion_size = "5" 	  if image_name == "7613035191822-2018032409500514812image.jpg"
	replace portion_size = "5" 	  if image_name == "7613035191822-201803240950148950image.jpg"
	replace portion_size = "18.5" if image_name == "7613035630680-201803240900505085image.jpg"
	replace portion_size = "140"  if image_name == "7802920002712-2018032410220316094image.jpg"
	replace portion_size = "140"  if image_name == "7802920006796-2018032410534220750image.jpg"
	replace portion_size = "50"   if image_name == "7803473004369-2018032409530711693image.jpg"
	replace portion_size = "25"   if image_name == "7803473241214-20180324093201207221521905332322845183503.jpg"
	replace portion_size = "40"   if image_name == "7803473500069-201803240951092125215219065685631877455433.jpg"
	replace portion_size = "2"    if image_name == "7794612407465-2018041406245824701image.jpg"
	replace portion_size = "2"    if image_name == "7794612407472-201804140617117565image.jpg"
	replace portion_size = "16"   if image_name == "7802225582445-2018041307575015993image.jpg"
	replace portion_size = "15"   if image_name == "8858135000158-2018032410365753551521909365828-13700479.jpg"
	replace portion_size = "16.4" if image_name == "5099864006162-201804141101512266image.jpg"
	replace portion_size = "20"   if image_name == "7792070001102-201803241125009646image.jpg"
	replace portion_size = "11"   if image_name == "7801970026433-201804140652091390image.jpg"
	replace portion_size = "14"   if image_name == "4410932140419-2018032409591220735image.jpg"
	replace portion_size = "4.36" if image_name == "7613033200762-2018041407215920656image.jpg"
	replace portion_size = "4.4"  if image_name == "7613034751829-2018041407244016941image.jpg"
	replace portion_size = "4.4"  if image_name == "7613034751829-2018041411033123240image.jpg"
	replace portion_size = "4.4"  if image_name == "7613035881037-2018041407211610785image.jpg"
	replace portion_size = "200"  if image_name == "3112070540410-2018032406260518406image.jpg"
	replace portion_size = "75"   if image_name == "7804646760006-2018032409364729121521905857270134551031.jpg"
	replace portion_size = "54"   if image_name == "7809565700010-201804140824029095image.jpg"
	replace portion_size = "23"   if image_name == "8000070012141-2018032411021920919image.jpg"
	replace portion_size = "23"   if image_name == "8000070036116-2018032411020121561image.jpg"
	replace portion_size = "25"   if image_name == "8003334000328-2018032407402024783image.jpg"
	replace portion_size = "200"  if image_name == "70177197377-201803240943151195image.jpg"
	replace portion_size = "200"  if image_name == "70177197346-201803241001583630image.jpg"
	replace portion_size = "26"   if image_name == "7613030788751-2018032408382113386image.jpg"
	replace portion_size = "30"   if image_name == "7613031768592-2018032408254920141image.jpg"
	replace portion_size = "30"   if image_name == "7613031768622-2018032408272916170image.jpg"
	replace portion_size = "30"   if image_name == "7613031768622-2018032408273521426image.jpg"
	replace portion_size = "30"   if image_name == "7613031769582-201803240828446207image.jpg"
	replace portion_size = "24"   if image_name == "7613035896178-201803240831534250image.jpg"
	replace portion_size = "23"   if image_name == "859940002441-2018032410590923920image.jpg"
	replace portion_size = "140"  if image_name == "7802920002712-2018032410234719706image.jpg"
	replace portion_size = "200"  if image_name == "7801875001276-201803241006252684image.jpg"
	replace portion_size = "56"   if image_name == "7801909000718-2018032408321624393image.jpg"
	replace portion_size = "75"   if image_name == "7804646760006-20180324093604202781521905857270134551031.jpg"
		
	replace portion_type = "g"    if image_name == "7803525000714-201806021207346794image.jpg"
	replace portion_type = "g"    if image_name == "0206171011610-2018060215480222856image.jpg"
	replace portion_type = "g"    if image_name == "7613035089495-2018032407044523746image.jpg"
	replace portion_type = "g"    if image_name == "7804636410010-2018032411024810091image.jpg"
	replace portion_type = "g" 	  if image_name == "7804641490021-201803241041331965image.jpg"
	replace portion_type = "g" 	  if image_name == "7790580151300-201803241037497262image.jpg"
	replace portion_type = "g"    if image_name == "5099864006094-2018041410553713723image.jpg"
	replace portion_type = "g"    if image_name == "7804624800007-2018041408273416814image.jpg"
	replace portion_type = "g"    if image_name == "7790349851083-201803240713086591521897145701463971576.jpg"
	replace portion_type = "ml"   if image_name == "78742089737-2018032411160521401image.jpg"
	replace portion_type = "ml"   if image_name == "78742099118-2018032409585413910image.jpg"
	replace portion_type = "ml"   if image_name == "78742099118-2018032410001410911image.jpg"
	replace portion_type = "ml"   if image_name == "78742122601-201803241003121628image.jpg"
	replace portion_type = "g" 	  if image_name == "7613032054694-201804140723028454image.jpg"
	replace portion_type = "g"    if image_name == "5099864007190-201804141056293443image.jpg"
	replace portion_type = "g"    if image_name == "7803473241214-20180324093201207221521905332322845183503.jpg"
	replace portion_type = "g"    if image_name == "7794612407472-201804140617117565image.jpg"
	replace portion_type = "g"    if image_name == "7802225582445-2018041307575015993image.jpg"
	replace portion_type = "ml"   if image_name == "8858135000158-2018032410365753551521909365828-13700479.jpg"
	replace portion_type = "g"    if image_name == "7613034467683-201803240958465348image.jpg"
	replace portion_type = "g"    if image_name == "7613035630680-201803240900505085image.jpg"
	replace portion_type = "g"    if image_name == "7803473004369-2018032409530711693image.jpg"
	replace portion_type = "g" 	  if image_name == "7803473500069-201803240951092125215219065685631877455433.jpg"
	replace portion_type = "g"    if image_name == "7794612407465-2018041406245824701image.jpg"
	replace portion_type = "g"    if image_name == "7801970026433-201804140652091390image.jpg"
	replace portion_type = "g"    if image_name == "5099864006162-201804141101512266image.jpg"
	replace portion_type = "g"    if image_name == "7792070001102-201803241125009646image.jpg"
	replace portion_type = "g"    if image_name == "7613035881037-2018041407211610785image.jpg"
	replace portion_type = "g"    if image_name == "7613034751829-2018041411033123240image.jpg"
	replace portion_type = "g"    if image_name == "7613034751829-2018041407244016941image.jpg"
	replace portion_type = "g"    if image_name == "4410932140419-2018032409591220735image.jpg"
	replace portion_type = "g"    if image_name == "7613033200762-2018041407215920656image.jpg"
	replace portion_type = "ml"   if image_name == "3112070540410-2018032406260518406image.jpg"
	replace portion_type = "g" 	  if image_name == "7807900005141-201806021212418596image.jpg"
	replace portion_type = "ml"   if image_name == "70177197346-201803241001583630image.jpg"
	replace portion_type = "ml"   if image_name == "70177197377-201803240943151195image.jpg"
	replace portion_type = "g" 	  if image_name == "7613030788751-2018032408382113386image.jpg"
	replace portion_type = "g" 	  if image_name == "7613031768592-2018032408254920141image.jpg"
	replace portion_type = "g" 	  if image_name == "7613031768622-2018032408272916170image.jpg"
	replace portion_type = "g" 	  if image_name == "7613031768622-2018032408273521426image.jpg"
	replace portion_type = "g" 	  if image_name == "7613031769582-201803240828446207image.jpg"
	replace portion_type = "g" 	  if image_name == "7613035896178-201803240831534250image.jpg"
	replace portion_type = "g" 	  if image_name == "859940002441-2018032410590923920image.jpg"
	replace portion_type = "ml"   if image_name == "7801875001276-201803241006252684image.jpg"
	replace portion_type = "ml"   if image_name == "7804617040342-2018032411401917615219131580101240476133.jpg"
	replace portion_type = "ml"   if image_name == "7804617040342-201803241140361293615219131580101240476133.jpg"
	replace portion_type = "ml"   if image_name == "7801256006005-2018032409562674031521906926927-372502137.jpg"
	replace portion_type = "g"    if portion_type  == "g aprox"
	
	destring portion_size, replace
	replace  portion_size = portion_size/1000 if portion_type == "mg"
	replace  portion_type = "g"  if portion_type == "mg"
}
	/* Energy */ {
	replace energy_100  	  	= "124"     if image_name == "7809611700742-2018032408084315264image.jpg"
	replace energy_100  	  	= "123"     if image_name == "7809611700773-20180414074021154881523713195736381704727.jpg"
	replace energy_100  	  	= "130"     if image_name == "7809611700759-20180414074227144771523713327774304950668.jpg"
	replace energy_100  	  	= "172.5"   if image_name == "7809611700780-2018032408082417981image.jpg"
	replace energy_100 			= "136"		if image_name == "7809611700780-2018032408082417981image.jpg"
	replace energy_100 			= "313"		if image_name == "7801970000143-20180324100422109001521907338531-187976785.jpg"
	replace energy_100 			= "330"		if image_name == "7801970026433-201804140652091390image.jpg"
	replace energy_100 			= "150"		if image_name == "7792070001102-201803241125009646image.jpg"
	replace energy_100 		  	= "267" 	if image_name == "78022096-20180324075711168791521899708587-2121943462.jpg"
	replace energy_100 		  	= "294.4"   if image_name == "7801916038513-201804140951352559image.jpg"
	replace energy_100 		  	= "513"  	if image_name == "7613033200762-2018041407215920656image.jpg" // Kj
	replace energy_100 		  	= "520" 	if image_name == "7802200846968-2018032411101618081image.jpg"
	replace energy_100 	  	    = "153" 	if image_name == "2131830000002-20180603101648221371528042526636269413235.jpg"
	replace energy_100 	  	    = "136.3" 	if image_name == "2135700000000-201806030926111995615280394911601023878052.jpg"
	replace energy_portion 	  	= "68.8"   	if image_name == "7804115001012-201806021017228860image.jpg" // Kj
	replace energy_portion 	  	= "22"   	if image_name == "7613033200762-2018041407215920656image.jpg" // Kj
	replace energy_portion	  	= "99"   	if image_name == "7801926003310-2018041407242314207image.jpg"
	replace energy_portion 	  	= "99" 	 	if image_name == "7801926003679-2018041407235413496image.jpg"
	replace energy_portion 	  	= "131" 	if image_name == "7802200894129-201803241031358529image.jpg"
}
	/* Proteins */ {
	replace proteins_100  	  	= "0" 	 	if image_name == "613008743796-2018032408344228731521902016065-934070117.jpg"
	replace proteins_100 	  	= "7.7"   	if image_name == "686352816614-201803240927431507image.jpg"   // proteins_100 = "7..7"
	replace proteins_100 	  	= "0.8"   	if image_name == "7506105606077-201806031248437909image.jpg"
	replace proteins_100 	  	= "0.8"   	if image_name == "7506105606077-2018060312490123183image.jpg"
	replace proteins_100 	  	= "16.8"   	if image_name == "7798016102254-20180603102138115241528042805101451061854.jpg"
	replace proteins_portion  	= "0.3"  	if image_name == "7310390855108-2018060209031311997image.jpg"
	replace proteins_portion  	= "0.3"  	if image_name == "7805000300548-201806021600256362image.jpg"
	replace proteins_portion  	= "0" 	 	if image_name == "7804522005405-2018032410453712307image.jpg"
	replace proteins_portion  	= "1"      	if image_name == "16000426412-2018032408120219294image.jpg"	
	replace proteins_portion  	= "1.2" 	if image_name == "7610400068529-201804141025461622image.jpg"  // proteins_portion = "1..2"
	replace proteins_portion  	= "2"   	if image_name == "16000407619-2018032408035620552image.jpg"
}
	/* Fats */ {
	replace fat_100  	 	 	= "3.6"     if image_name == "7809611700759-20180414074227144771523713327774304950668.jpg"
	replace fat_100  	    	= "5.75"    if image_name == "7809611700759-20180414074227144771523713327774304950668.jpg"
	replace fat_100  		  	= "11.6"   	if image_name == "7809611700780-2018032408082417981image.jpg"
	replace fat_100  		  	= "0"   	if image_name == "613008743796-2018032408344228731521902016065-934070117.jpg"
	replace fat_100           	= "1.8"  	if image_name == "7802920801087-201803240622122789image.jpg"  // fat_sat_portion = "1.8."
	replace fat_100		  	  	= "1.9"     if image_name == "7809611700742-2018032408084315264image.jpg"
	replace fat_100		  	  	= "5.6"     if image_name == "7809611700742-2018032408084315264image.jpg"
	replace fat_100 			= "6.6"		if image_name == "7809611700780-2018032408082417981image.jpg"
	replace fat_100           	= "0.8"  	if image_name == "7802000009297-201806031014536427image.jpg"
	replace fat_portion         = "13.6"    if image_name == "2131830000002-20180603101648221371528042526636269413235.jpg"	
	replace fat_portion         = "0"       if image_name == "7702011305244-2018060309583617035image.jpg"
	replace fat_sat_100	  	  	= "1.9"     if image_name == "7809611700742-2018032408084315264image.jpg"
	replace fat_sat_100  	 	= "1.2"     if image_name == "7809611700759-20180414074227144771523713327774304950668.jpg"
	replace fat_sat_100  	  	= "1.9"     if image_name == "7809611700759-20180414074227144771523713327774304950668.jpg"
	replace fat_sat_100  		= "4.5"   	if image_name == "7809611700780-2018032408082417981image.jpg"
	replace fat_sat_100 		= "2.4"		if image_name == "7809611700780-2018032408082417981image.jpg"
	replace fat_sat_100 		= "0" 		if image_name == "7801305004921-2018032409412224799image.jpg"
	replace fat_sat_100 		= "3.5"		if image_name == "7792070001102-201803241125009646image.jpg"
	replace fat_sat_100 		= "2.5" 	if image_name == "2093190000002-20180603094551228361528040675127988639078.jpg"
	replace fat_sat_portion   	= "0.25" 	if image_name == "7801926002221-201803241003329340image.jpg"	
	replace fat_mono_100 	  	= "0" 	    if image_name == "7801305004921-2018032409412224799image.jpg"
	replace fat_mono_100 	  	= "3.7"	 	if image_name == "7802575540041-2018032411523912505image"
	replace fat_mono_100 	  	= "4"	    if image_name == "5998710132201-2018060307594618106image.jpg"
	replace fat_mono_100 	  	= "4" 	 	if image_name == "5998710132201-201806030800118140image.jpg"
	replace fat_mono_portion  	= "0" 		if image_name == "7803960000379-2018032410064516678image.jpg"
	replace fat_mono_portion  	= "0.1" 	if image_name == "7804662110212-20180324102422194721521908611126648966670.jpg"
	replace fat_mono_portion  	= "0.4" 	if image_name == "7804097001666-2018032408383920812image.jpg"
	replace fat_mono_portion  	= "1.2" 	if image_name == "400006278036-201803241018027302image.jpg"
	replace fat_mono_portion  	= "1.8" 	if image_name == "816855020076-2018041410252022599image.jpg"
	replace fat_mono_portion  	= "2.2" 	if image_name == "7798016102230-201803240747369615image.jpg"
	replace fat_mono_portion  	= "2.2" 	if image_name == "7798016102230-2018032407483017618image.jpg"
	replace fat_acids_100 	  	= "0" 		if image_name == "46000821214-201803240837399643image.jpg"
	replace fat_acids_100 	  	= "0" 		if image_name == "7801930015088-20180324105046116401521910315711-506516786"
	replace fat_acids_100 	  	= "0" 		if image_name == "7801930015101-201803241049041214515219102045062098451714"
	replace fat_acids_100 	  	= "0" 		if image_name == "7801930015606-20180324104955174541521910262414770820596"
	replace fat_acids_100 	  	= "0" 		if image_name == "6293018059700-201804141103096148image.jpg"
	replace fat_acids_100 	  	= "0" 		if image_name == "7801930010953-20180324095934147251521907195593-1764378000"
	replace fat_acids_100 	  	= "0" 		if image_name == "7801930012001-20180324075427378515218996866241713216907.jpg"
	replace fat_acids_100 	  	= "1" 		if image_name == "7802960000785-201803240900158899image.jpg"
	replace fat_acids_100  	  	= "1" 		if image_name == "4000417102003-201803241117267805image.jpg"
	replace fat_acids_portion  	= "0" 		if image_name == "7801916038513-201804140951352559image.jpg"
	replace fat_acids_portion 	= "0" 		if image_name == "7802410351108-201803240944379669image.jpg"
	replace fat_acids_portion 	= "0" 		if image_name == "7803960000379-2018032410064516678image.jpg"
	replace fat_acids_portion 	= "0" 		if image_name == "7802960001942-2018032409122020033image.jpg"
	replace fat_acids_portion 	= "0" 	 	if image_name == "7801380001730-201803240957371008415219070123821964529549.jpg"
	replace fat_acids_portion 	= "0.1" 	if image_name == "7804097001789-2018032408371324629image.jpg"
	replace fat_acids_portion   = "0"  		if image_name == "7804661960566-201803241141018640image.jpg"
	replace fat_acids_portion   = "0"  		if image_name == "7814661960152-20180324114350448image.jpg"
	replace fat_acids_portion   = "0"  		if image_name == "7501008660751-201803241143107434image.jpg"
	replace fat_acids_portion   = "0"  		if image_name == "5010677800754-201803241141357887image.jpg"
	replace fat_acids_portion   = "0"  		if image_name == "8000570552505-2018032411421721496image.jpg"
	replace fat_poli_100 		= "6.5" 	if image_name == "7803500000319-201804140908584603image.jpg"
	replace fat_poli_100	 	= "7" 		if image_name == "7802960000785-201803240900158899image.jpg"
	replace fat_poli_100	 	= "0.8" 	if image_name == "2093180000005-201806030938076481528040205533888368436.jpg"
	replace fat_poli_portion 	= "0.2" 	if image_name == "7803410000102-2018032408075930091521900432226-846662098.jpg"	
	replace fat_poli_portion 	= "0.4" 	if image_name == "7804097001666-2018032408383920812image.jpg"	
	replace fat_poli_portion 	= "1.1" 	if image_name == "7896022203092-201804141057489954image.jpg"
	replace fat_poli_portion 	= "1.4" 	if image_name == "7798016102230-201803240747369615image.jpg"
	replace fat_poli_portion 	= "1.4" 	if image_name == "7798016102230-2018032407483017618image.jpg"
	replace fat_poli_portion 	= "1.9"	 	if image_name == "7801930010953-20180324095934147251521907195593-1764378000"
	replace fat_poli_portion 	= "2" 		if image_name == "7801916038513-201804140951352559image.jpg"
	replace fat_poli_portion    = "0.6"     if image_name == "2103250000009-201806030933372441315280399393141190916102.jpg"
}	
	/* Cholesterol */ {
	replace cholesterol_100     = "0"   	if image_name == "7802000009297-201806031014536427image.jpg"
	replace cholesterol_portion = "1.1" 	if image_name == "7807900004533-2018032410125321114image.jpg"
	replace cholesterol_portion = "1.1" 	if image_name == "7807900004540-2018032410104623128image.jpg"
	replace cholesterol_portion = "1.1" 	if image_name == "7807900004557-2018032410120820333image.jpg"
	replace cholesterol_portion = "4.9" 	if image_name == "7809611711120-2018032408070414983image.jpg"
	replace cholesterol_portion = "4.9" 	if image_name == "7809611711120-201803240654151398915218959735843376686128828841650.jpg"
	replace cholesterol_portion = "4.9" 	if image_name == "7802960000785-201803240900158899image.jpg"
	replace cholesterol_portion = "4.9" 	if image_name == "7809611712578-2018032408073020322image.jpg"
	replace cholesterol_portion = "11" 	 	if image_name == "7804647600448-201803240836107276image.jpg"	
	replace cholesterol_portion = "1.7"  	if image_name == "7804661960566-201803241141018640image.jpg"
	replace cholesterol_portion = "1.7"  	if image_name == "7804320319018-2018032411374217958image.jpg"
	replace cholesterol_portion = "1.7"  	if image_name == "7814661960152-20180324114350448image.jpg"
	replace cholesterol_portion = "1.7"  	if image_name == "7501008660751-201803241143107434image.jpg"
	replace cholesterol_portion = "1.7"  	if image_name == "5010677800754-201803241141357887image.jpg"
	replace cholesterol_portion = "1.7"  	if image_name == "8000570552505-2018032411421721496image.jpg"
	replace cholesterol_portion = "1.7"  	if image_name == "7809585502410-20180324113848724image.jpg"
	replace cholesterol_portion = "1.7"  	if image_name == "7802180068046-2018032411370916411image"
}
	/* Carbs */ {
	replace carbs_100 			= "1"	 	if image_name == "3161712996153-201803240843291853image.jpg"
	replace carbs_100 			= "1"	 	if image_name == "3161712996153-2018032408435022458image.jpg"
	replace carbs_100 			= "1"	 	if image_name == "3161712996108-2018032408451517731image.jpg"
	replace carbs_portion 	  	= "1.5" 	if image_name == "7804515003180-2018032411163611922image.jpg"
	replace carbs_portion 	  	= "12.7" 	if image_name == "7613035903173-201806031119157310image.jpg"
	replace carbs_portion 		= "2.7" 	if image_name == "7803410000102-2018032408075930091521900432226-846662098.jpg"
	replace carbs_portion 	  	= "2.7" 	if image_name == "7804601610285-2018032410335616102image.jpg"
	replace carbs_portion 	  	= "2.7" 	if image_name == "7804601610292-20180324103221980image.jpg"
	replace carbs_portion	  	= "46" 		if image_name == "7804647600486-20180414113553680715237273153161054262760.jpg"
	replace carbs_portion	  	= "0.3" 	if image_name == "7310390855108-2018060209031311997image.jpg"
	replace carbs_portion	  	= "0.5" 	if image_name == "7805000300548-201806021600256362image.jpg"
	replace sugar_100  		  	= "0"   	if image_name == "7809611700780-2018032408082417981image.jpg"
	replace sugar_100  	  		= "0"     if image_name == "7809611700742-2018032408084315264image.jpg"
	replace sugar_100  	  		= "0"   	if image_name == "7809611700759-20180414074227144771523713327774304950668.jpg"
	replace sugar_100 			= "0"		if image_name == "7809611700780-2018032408082417981image.jpg"
	replace sugar_100 			= "1.9"		if image_name == "7801970000143-20180324100422109001521907338531-187976785.jpg"
	replace sugar_100 			= "0.5"		if image_name == "7792070001102-201803241125009646image.jpg"
	replace sugar_100  			= "0" 		if image_name == "46000821214-201803240837399643image.jpg"
	replace sugar_100 			= "1" 		if image_name == "3161712996153-2018032408435022458image.jpg"
	replace sugar_100 			= "1" 		if image_name == "3161712996153-201803240843291853image.jpg"
	replace sugar_100 			= "1" 		if image_name == "3161712996108-2018032408451517731image.jpg"
	replace sugar_100         	= "3" 		if image_name == "7802410001607-2018032409340118052image.jpg"
	replace sugar_100 			= "17" 		if image_name == "41500763668-2018032409410711623image.jpg"
	replace sugar_portion 		= "0.2"		if image_name == "70177050580-2018032409584719457image.jpg"
	replace sugar_portion 	  	= "0.6" 	if image_name == "7804646760006-2018032409364729121521905857270134551031.jpg"
	replace sugar_portion 		= "0.6" 	if image_name == "7804646760006-20180324093604202781521905857270134551031.jpg"
	replace sugar_portion 		= "3" 		if image_name == "7801930015606-20180324104955174541521910262414770820596"
	replace sugar_portion 	  	= "9" 		if image_name == "7804648270015-2018032408105213497image.jpg"
	replace sugar_portion 	  	= "9"	 	if image_name == "7804648270237-2018032408122622991image.jpg"
	replace dietfiber_100		= "20" 		if image_name == "7804627650104-2018032411230624271image.jpg"
	replace dietfiber_100 		= "65" 		if image_name == "7805000312282-2018032410222810414image.jpg"
	replace dietfiber_100 		= "65" 		if image_name == "7805000312275-2018032410243022387image.jpg"
	replace dietfiber_portion  	= "1" 		if image_name == "7804633770216-2018032410193517538image.jpg"
	replace dietfiber_portion 	= "1.3" 	if image_name == "7805000312275-2018032410243022387image.jpg"
	replace dietfiber_portion 	= "1.3" 	if image_name == "7805000312282-2018032410222810414image.jpg"
	replace dietfiber_portion 	= "1.7" 	if image_name == "7501073427532-2018032407271915114image.jpg" // dietfiber_portion = "1..7"
}
	/* Sodium */ {
	replace sodium_100  	 	= "66" 	    if image_name == "7809611700759-20180414074227144771523713327774304950668.jpg"
	replace sodium_100  	  	= "50"  	if image_name == "7809611700759-20180414074227144771523713327774304950668.jpg"
	replace sodium_100 		  	= "326"   	if image_name == "7809611700780-2018032408082417981image.jpg"
	replace sodium_100 			= "962"		if image_name == "7801970000143-20180324100422109001521907338531-187976785.jpg"
	replace sodium_100        	= "55"  	if image_name == "2109140000005-20180603080739915215280347510211130006880.jpg"
	replace sodium_100 			= "40" 		if image_name == "7804627650104-2018032411230624271image.jpg"
	replace sodium_100 			= "0"		if image_name == "7792070001102-201803241125009646image.jpg"
	replace sodium_100  		= "1000" 	if image_name == "78742230139-2018032411371376531521913001442253469470.jpg"
	replace sodium_100 			= "1139" 	if image_name == "78742370019-2018032408453822370image.jpg"
	replace sodium_100 			= "1217" 	if image_name == "8514564151143-201804140816542468image.jpg"
	replace sodium_100 			= "1217" 	if image_name == "8414564200431-2018032411271817305image.jpg"
	replace sodium_100 			= "1217" 	if image_name == "8514564101124-2018032411275221570image.jpg"
	replace sodium_100 			= "1217" 	if image_name == "8414564201131-201803241128263500image.jpg"
	replace sodium_100 			= "1520" 	if image_name == "7803111001729-201803240758579495image.jpg"
	replace sodium_100 			= "1538" 	if image_name == "21000602513-2018032407525910683image.jpg"
	replace sodium_100 			= "1538" 	if image_name == "21000602513-2018032407531122613image.jpg"
	replace sodium_100 			= "1589" 	if image_name == "21000602568-2018032407514923123image.jpg"
	replace sodium_100 			= "3740" 	if image_name == "7804660620065-201803240625236746image.jpg"
	replace sodium_100        	= "5300" 	if image_name == "7804617500037-2018032407481514964image.jpg"
	replace sodium_100 		  	= "1480"    if sodium_100 == "1.480.00"
	replace sodium_100 		  	= "1720"    if sodium_100 == "1.720.00"
	replace sodium_100	 	  	= "1758"    if sodium_100 == "1.758.00"
	replace sodium_100 		  	= "1770"    if sodium_100 == "1.770.00"
	replace sodium_100 		  	= "1800"    if sodium_100 == "1.800.00"
	replace sodium_portion 		= "0" 		if image_name == "7801220002217-2018032409201221404image"
	replace sodium_portion 		= "0" 		if image_name == "6901118909107-2018032409211014318image.jpg"
	replace sodium_portion    	= "2.5"    	if image_name == "3046920028363-2018032411132516690image.jpg" ///
											|  image_name == "3046920028363-201803241113322076image.jpg"  //sodium_portion == "2..5"
	replace sodium_portion  	= "65" 		if image_name == "16000407619-2018032408035620552image.jpg"
	replace sodium_portion  	= "110"		if image_name == "2103250000009-201806030933372441315280399393141190916102.jpg"
	replace sodium_portion	  	= "0.1" 	if image_name == "7310390855108-2018060209031311997image.jpg"
	replace sodium_portion	  	= "0.2" 	if image_name == "7805000300548-201806021600256362image.jpg"
}

	/* Calcium	*/ {
	replace calcium_100       = "1312.1" 	if image_name == "7802930000333-20180324105856181015219106795831165366596.jpg"
}
**
										 
** Identify and amend information with "<" 
{
/*There are simpler (and shorter!) ways to correct them, but we may want to identify them.
Also it's a good excercise to find typos and mistakes.*/

* Fats
	replace fat_100 		  	= "0" 	if fat_100 			   == "<0.1" 
	replace fat_100 		  	= "0" 	if fat_100 			   == "<0.5" 
	replace fat_portion 	  	= "0" 	if fat_portion 		   == "<0.1"
	replace fat_portion 	  	= "0" 	if fat_portion 		   == "<0.5"
	replace fat_sat_100 	  	= "0" 	if fat_sat_100 		   == "<0.1"
	replace fat_sat_portion   	= "0" 	if fat_sat_portion 	   == "<0.1"
	replace fat_mono_portion  	= "0" 	if fat_mono_portion    == "<0.5"
	replace fat_poli_100 	  	= "0" 	if fat_poli_100 	   == "<0.1"
	replace fat_poli_100 	  	= "0" 	if fat_poli_100 	   == "<0.5"
	replace fat_poli_portion  	= "0" 	if fat_poli_portion    == "<0.1"
	replace fat_poli_portion  	= "0"   if fat_poli_portion    == "<0.2"
	replace fat_poli_portion  	= "0" 	if fat_poli_portion    == "<0.5"
	replace fat_acids_100 	  	= "0" 	if fat_acids_100 	   == "<0.04"
	replace fat_acids_100 	  	= "0" 	if fat_acids_100 	   == "<0.01"
	replace fat_acids_100 	  	= "0" 	if fat_acids_100 	   == "<0.004"
	replace fat_acids_100 	  	= "0" 	if fat_acids_100 	   == "<0.005"
	replace fat_acids_100 	  	= "0" 	if fat_acids_100 	   == "<0.1"
	replace fat_acids_100 	  	= "0" 	if fat_acids_100 	   == "<0.2"
	replace fat_acids_100 	  	= "0" 	if fat_acids_100 	   == "<0.3"
	replace fat_acids_100 	  	= "0" 	if fat_acids_100 	   == "<0.5"
	replace fat_acids_portion 	= "0" 	if fat_acids_portion   == "<0.0006" 
	replace fat_acids_portion 	= "0" 	if fat_acids_portion   == "<0.001" 
	replace fat_acids_portion 	= "0" 	if fat_acids_portion   == "<0.03"
	replace fat_acids_portion 	= "0" 	if fat_acids_portion   == "<0.01"
	replace fat_acids_portion 	= "0" 	if fat_acids_portion   == "<0.1"
	replace fat_acids_portion 	= "0" 	if fat_acids_portion   == "<0.2"
	replace fat_acids_portion 	= "0" 	if fat_acids_portion   == "<0.3"
	replace fat_acids_portion 	= "0" 	if fat_acids_portion   == "<0.5"
	replace fat_acids_portion 	= "0" 	if fat_acids_portion   == "<0.6"
* Cholesterol
	replace cholesterol_100 	= "0" 	if cholesterol_100 	   == "<5"
	replace cholesterol_100 	= "0" 	if cholesterol_100     == "<0.2"
	replace cholesterol_portion = "0" 	if cholesterol_portion == "<5"
	replace cholesterol_portion = "0" 	if cholesterol_portion == "<0.2"
* Carbs
	replace carbs_100 			= "0" 	if carbs_100 		   == "<0.2"
	replace carbs_100 			= "0" 	if carbs_100           == "<0.9"
	replace carbs_100 			= "0" 	if carbs_100 		   == "<0.90"
	replace carbs_100 			= "0" 	if carbs_100 		   == "<1"
	replace carbs_100 			= "0" 	if carbs_100 		   == "<0.5"
	replace carbs_portion		= "0" 	if carbs_portion 	   == "<0.3"
	replace carbs_portion 		= "0" 	if carbs_portion 	   == "<0.5"
	replace carbs_portion 		= "0" 	if carbs_portion 	   == "<0.27"
	replace carbs_portion 		= "0" 	if carbs_portion       == "<0.14"
	replace sugar_100	 		= "0" 	if sugar_100 		   == "<0.01"
	replace sugar_100 			= "0" 	if sugar_100 		   == "<0.1**" 
	replace sugar_100 			= "0" 	if sugar_100           == "<1"
	replace sugar_100 			= "0" 	if sugar_100           == "<0.50"
	replace sugar_100 			= "4.9" if sugar_100           == "<4.9" // not low enough to app to zero
	replace sugar_100 			= "0" 	if sugar_100  		   == "<0.1"
	replace sugar_100 			= "0" 	if sugar_100           == "<0.2"
	replace sugar_100 			= "0"	if sugar_100      	   == "<0.4"
	replace sugar_100 			= "0"	if sugar_100      	   == "<0.5"
	replace sugar_100 			= "0" 	if sugar_100           == "<0.9"
	replace sugar_100 			= "0" 	if sugar_100           == "<0.90"
	replace sugar_portion 		= "0" 	if sugar_portion       == "<0.01"
	replace sugar_portion 		= "0" 	if sugar_portion       == "<0.03"
	replace sugar_portion 		= "0" 	if sugar_portion 	   == "<0.1"
	replace sugar_portion 		= "0" 	if sugar_portion 	   == "<0.10"
	replace sugar_portion 		= "0" 	if sugar_portion       == "<0.1**"
	replace sugar_portion 		= "0" 	if sugar_portion       == "<0.14"
	replace sugar_portion 		= "0" 	if sugar_portion       == "<0.15"
	replace sugar_portion 		= "0" 	if sugar_portion       == "<0.2"
	replace sugar_portion 		= "0" 	if sugar_portion       == "<0.27"
	replace sugar_portion 		= "0" 	if sugar_portion       == "<0.5"
	replace sugar_portion 		= "0" 	if sugar_portion       == "<0.6"
	replace sugar_portion 		= "0" 	if sugar_portion       == "<0.3" 
	replace sugar_portion 		= "0" 	if sugar_portion       == "<0.9"
	replace sugar_portion 		= "9.8" if sugar_portion       == "<9.8" // not low enough to app to zero
	replace sugar_sacch_100 	= "0" 	if sugar_sacch_100     == "<0.01"
	replace sugar_sacch_portion = "0" 	if sugar_sacch_portion == "<0.025"
	replace dietfiber_100 		= "0" 	if dietfiber_100       == "<0.1"
	replace dietfiber_100 		= "0" 	if dietfiber_portion   == "<0.5"
	replace dietfiber_portion 	= "0" 	if dietfiber_portion   == "<0.1"
	replace dietfiber_portion 	= "0" 	if dietfiber_portion   == "<0.5"
*Proteins
	replace proteins_100 		= "0" 	if proteins_100        == "<0.5"
	replace proteins_portion 	= "0" 	if proteins_portion    == "<0.5"
* Sodium
	replace sodium_100	 		= "0" 	if strpos(sodium_100,"≤") 
	replace sodium_100 			= "0" 	if sodium_100		   == "<0.5"
	replace sodium_100 			= "0" 	if sodium_100 		   == "<1.0"
	replace sodium_100 			= "0" 	if sodium_100          == "<2"
	replace sodium_100 			= "0" 	if sodium_100          == "<2.400"
	replace sodium_100 		    = "0" 	if sodium_100          == "<3.5"
	replace sodium_100 			= "0" 	if sodium_100          == "<18"
	replace sodium_100 			= "<35" if sodium_100          == "menora35"
	replace sodium_100 			= "<35" if sodium_100 		   == "Nocontienemasde35mgporporcion"
	replace sodium_100  		= "0" 	if sodium_100 	       == "<35"
	replace sodium_100 			= "0" 	if sodium_100  		   == "<78"
	replace sodium_100 			= "0" 	if sodium_100 		   == "<7.5"
	replace sodium_portion 		= "0" 	if strpos(sodium_portion,"≤") 
	replace sodium_portion 		= "0" 	if sodium_portion 	   == "<0.2"
	replace sodium_portion 		= "0" 	if sodium_portion      == "<0.5"
	replace sodium_portion 		= "0" 	if sodium_portion      == "<1.0"
	replace sodium_portion 		= "0" 	if sodium_portion      == "<3.000"
	replace sodium_portion 		= "0" 	if sodium_portion      == "<3.5"
	replace sodium_portion 		= "0" 	if sodium_portion      == "<15"
	replace sodium_portion 		= "0" 	if sodium_portion      == "<11"
	replace sodium_portion 		= "<35" if sodium_portion 	   == "menora35"
	replace sodium_portion 		= "<35" if sodium_portion      == "Nocontienemasde35mgporporcion"
	replace sodium_portion 		= "0" 	if sodium_portion 	   == "<35"
	replace sodium_portion 		= "0" 	if sodium_portion      == "<22"
	replace sodium_portion 		= "0" 	if sodium_portion      == "<0.07"
}
**

destring energy* proteins* fat* cholesterol* carbs* sugar* diet* sodium* calcium_100, replace

drop calcium_portion vitB2* iodo* // Calcium portion is in daily %
gen calcium_portion = calcium_100/100*portion_size // Recover calcium portion
order calcium_portion, a(calcium_100)

local nutrient energy proteins fat_sat fat_mono fat_poli fat_acids cholesterol ///
carbs sugar sugar_sacch sugar_lact sugar_gluc sugar_fruct dietfiber sodium calcium 

* Portion missing info
foreach n of local nutrient{
	replace `n'_portion = `n'_100/10 	   if image_name == "7804614520069-2018032408143013656image.jpg"
	replace `n'_portion = `n'_100/10 	   if image_name == "7804614520069-2018032408143720121image.jpg"
	replace `n'_portion = (`n'_100/100)*7  if image_name == "7802410351207-201803240941126657image.jpg"
	replace `n'_portion = (`n'_100/100)*14 if image_name == "7802410100843-2018032409360023884image.jpg"
}

******************************************************************************** 
** 4. RECOVER FIXED FIELD DATA IN EXCEL
******************************************************************************** 

* Save actual data
	tempfile main
	save `main', replace
* Import and save fixed data
	import excel using "${Repo}/00_files/01_source/02_nutrition/fixed_obs_field.xlsx", first clear
	*drop if image_name == ""
	tempfile tempfield
	save `tempfield', replace
* Merge main data with fixed data
	use `main', clear
	merge 1:1 image_name using `tempfield', update replace
	drop _merge

/* NOTE: I don't create different observations for products with more than one 
nutritional label in the same package*/

******************************************************************************** 
** 5. MERGE WITH DATABASE OF PRODUCTS
******************************************************************************** 

* Obtain UPC from image name in Pavan's database
rename image_name temp
split temp, parse("image")
split temp1, parse(".jpg") 
rename temp11 image_name
drop temp*
split image_name, parse(-) gen(temp)
g upc_id_pavan = substr(temp1, 1, length(temp1)-1)
order upc_id_pavan
drop temp* 

** Merge by image_name

* Prepare using data
preserve
	clear 
	use "${Repo}/00_files/02_intermediate/02_nutrition/01_products_raw.dta"

	* Get image name
	split picture, parse("productos/") gen(temp)
	split temp2, parse("image")
	split temp21, parse(".jpg") 
	rename temp211 image_name
	drop picture temp* 

	* Identify scan date
	split image_name, parse("-") gen(temp)
	replace temp2 = substr(temp2,1,8) 
	g date_scan = date(temp2, "YMD")
	format date_scan %td
	drop temp* scan_timestamp

	duplicates drop image_name, force

	tempfile temp
	save `temp', replace
restore


* Merge
	merge 1:1 image_name using `temp'
	drop _merge
* Drop duplicates if same upc_id & same nutritional information
	sort upc_id_pavan name energy_100 proteins_100 fat_100 cholesterol_100 carbs_100 sugar_100 sodium_100
	bys upc_id_pavan energy_100 proteins_100 fat_100 cholesterol_100 carbs_100 sugar_100 sodium_100 (name): g duplicate=cond(_n==_N,0,_n)
	drop if duplicate>0 & upc_id_pavan != ""
**

* Drop observations with no information
replace remarks = "Information not given" if image_name == "7803525999995-201804140919499524image.jpg"
replace remarks = "Information not given" if image_name == "7801970026433-201804140652091390image.jpg"
replace remarks = "Information not given" if image_name == "7792070001102-201803241125009646image.jpg"
replace remarks = "Information not given" if image_name == "7792070001102-201803241125009646image.jpg"
drop if remarks == "Information not given" | remarks == "Blank Image"

* Minor tunings
drop upc_id_pavan scanned duplicate folder_name 
drop if upc_id == "" /*THIS IS WEIRD: some obs have upc_id_pavan but blank upc_id*/
drop if upc_id == "0"
* Drop pictures with no info for 100 gr and no portion size
drop if upc_id == "780500031394"
drop if upc_id == "780500031226"
drop if upc_id == "780500031225"
order item_id product_id upc_id name brand label_* date_scan image_name
ren image_name picture
sort brand name

* Source of data
g source = ""
replace source = "Field"

tempfile main1
save `main1', replace

******************************************************************************** 
** 5.1 FIX UNIT TYPE
******************************************************************************** 

replace type_unit = "KG" if type_unit == "GR"
replace sell_q = "0,8" if upc_id == "780291000405"
replace sell_q = "0,435" if upc_id == "7874208491"
replace sell_q = "0,79" if upc_id == "7874237001"
replace sell_q = "0,79" if upc_id == "7874237000" 
replace sell_q = "0,5" if upc_id == "780340323634"
replace sell_q = "0,05" if upc_id == "761303220312" 
replace sell_q = "0,4" if upc_id == "761303226958" 
replace sell_q = "0,9" if upc_id == "761303249643" 
replace sell_q = "0,21" if upc_id == "7791657090" 
replace sell_q = "0,1" if upc_id == "770205408840"
replace sell_q = "0,2" if upc_id == "780281000620" 

replace type_unit = "LT" if type_unit == "ML"
replace sell_q = "0,5" if upc_id == "780282044112"
replace sell_q = "0,5" if upc_id == "761303129911"

	
******
**** Fix Usuario 10
******


foreach var in sug cal sod fat{
gen K`var' = .
}
** Threshold labels

replace Ksug = 1 if sugar_100     >   22.5 	& sugar_100!=. 									& portion_type == "g"
replace Ksug = 0 if sugar_100    <=   22.5  & sugar_100!=. 									& portion_type == "g"
replace Kcal = 1 if energy_100    >  350  	& energy_100!=. 								& portion_type == "g"
replace Kcal = 0 if energy_100   <=  350  	& energy_100!=. 								& portion_type == "g"
replace Kfat = 1 if  fat_sat_100  >    6   	& fat_sat_100!=. 								& portion_type == "g"
replace Kfat = 0 if (fat_sat_100 <=    6 | fat_100 <= 6 ) & ( fat_100!=. | fat_sat_100!=.) 	& portion_type == "g"
replace Ksod = 1 if sodium_100    >  800   	& sodium_100!=. 								& portion_type == "g"
replace Ksod = 0 if sodium_100   <=  800    & sodium_100!=. 								& portion_type == "g"

replace Ksug = 1 if sugar_100     >    6 	& sugar_100!=. 									& portion_type == "ml"
replace Ksug = 0 if sugar_100    <=    6	& sugar_100!=. 									& portion_type == "ml"
replace Kcal = 1 if energy_100    >  100  	& energy_100!=. 								& portion_type == "ml"
replace Kcal = 0 if energy_100   <=  100  	& energy_100!=. 								& portion_type == "ml"
replace Kfat = 1 if fat_sat_100   >    3   	& fat_sat_100!=. 								& portion_type == "ml"
replace Kfat = 0 if (fat_sat_100 <=    3 | fat_100 <= 3 ) & ( fat_100!=. | fat_sat_100!=.) 	& portion_type == "ml"
replace Ksod = 1 if sodium_100    >  100   	& sodium_100!=. 								& portion_type == "ml"
replace Ksod = 0 if sodium_100   <=  100    & sodium_100!=. 								& portion_type == "ml"

** Enumerators - Walmart Labels

replace label_sugar = Ksug if enumerator == "usuario10" & category_name == "08439 GALLETAS - GONDOLA" | category_name == "08441 GALLETAS - SALADA-SALVIA"
replace label_energy = Kcal if enumerator == "usuario10" & category_name == "08439 GALLETAS - GONDOLA" | category_name == "08441 GALLETAS - SALADA-SALVIA"
replace label_fat = Kfat if enumerator == "usuario10" & category_name == "08439 GALLETAS - GONDOLA" | category_name == "08441 GALLETAS - SALADA-SALVIA"
replace label_sodium = Ksod if enumerator == "usuario10" & category_name == "08439 GALLETAS - GONDOLA" | category_name == "08441 GALLETAS - SALADA-SALVIA"

drop K*

******************************************************************************** 
** 7. FINAL TUNINGS
******************************************************************************** 

sort brand name
drop if upc_id == "0"

label var upc_id 			  "UPC id"
label var name 				  "Product name"
label var brand   			  "Product brand"
label var date_scan           "Date of information"
label var label_sugar         "Sugar Label"
label var label_sodium        "Sodium Label"
label var label_fat_sat       "Saturated Fats Label"
label var label_energy        "Energy (kcals) Label"
label var portion_type 	      "Grs or ml"
label var portion_size        "Size of the portion"
label var energy_100          "Energy (kcal) per 100 grs/ml"
label var energy_portion 	  "Energy (kcal) per portion"
label var proteins_100 		  "Proteins (g) per 100 grs/ml"
label var proteins_portion 	  "Proteins (g) per portion"
label var fat_100 			  "Total Fat (g) per 100 grs/ml"
label var fat_portion 		  "Total Fat (g) per portion"
label var fat_sat_100 	      "Saturated fat (g) per 100 grs/ml"
label var fat_sat_portion     "Saturated fat (g) per portion"
label var fat_mono_100 		  "Monounsaturated fat (g) per 100 grs/ml"
label var fat_mono_portion 	  "Monounsaturated fat (g) per portion"
label var fat_poli_100 		  "Polyunsaturated fat (g) per 100 grs/ml"
label var fat_poli_portion 	  "Polyunsaturated fat (g) per portion"
label var fat_acids_100 	  "Trans Fat (g) per 100 grs/ml"
label var fat_acids_portion   "Trans Fat (g) per portion"
label var cholesterol_100 	  "Cholesterol (mg) per 100 grs/ml"
label var cholesterol_portion "Cholesterol (mg) per portion"
label var carbs_100 		  "Total Carbohydrate (g) per 100 grs/ml"
label var carbs_portion 	  "Total Carbohydrate (g) per portion"
label var sugar_100 		  "Sugar (g) per 100 grs/ml"
label var sugar_portion 	  "Sugar (g) per portion"
label var sugar_sacch_100 	  "Saccharose (g) per 100 grs/ml"
label var sugar_sacch_portion "Saccharose (g) per portion"
label var sugar_lact_100 	  "Lactose (g) per 100 grs/ml"
label var sugar_lact_portion  "Lactose (g) per portion"
label var sugar_gluc_100 	  "Glucose (g) per 100 grs/ml"
label var sugar_gluc_portion  "Glucose (g) per portion"
label var sugar_fruct_100 	  "Fructose (g) per 100 grs/ml"
label var sugar_fruct_portion "Fructose (g) per portion"
label var dietfiber_100       "Dietary Fiber (g) per 100 grs/ml"
label var dietfiber_portion   "Dietary Fiber (g) per portion"
label var sodium_100          "Sodium (mg) per 100 grs/ml"
label var sodium_portion 	  "Sodium (mg) per portion"
label var calcium_100         "Calcium (mg) per 100 grs/ml"
label var calcium_portion     "Calcium (mg) per portion"


save "${Repo}/00_files/02_intermediate/02_nutrition/03_nutritional_info.dta", replace


