/*******************************************************************************
AUTHOR: Nano Barahona, Seb Otero, Cris Otero
CREATION: Jan-18
ACTION: Protocol to clean for sales
SUMMARY: 
Before cleaning
- 143/326 products scanned (44% of products)
- 63% of total sales covered
After cleaning
- 264/326 products scanned (81% of products)
- 94% of total sales covered
********************************************************************************/

clear all
set more off
set scheme s1mono

******************************************************************************** 
** SET PATH AND LOCALS
******************************************************************************** 

if c(username)=="Nano"   		  global Repo "/Users/Nano/Dropbox/Research/FoodLabels/food_labels/04_replication"
else 							  global Repo "."

******************************************************************************** 
** LOAD DATA
******************************************************************************** 

use "${Repo}/00_files/02_intermediate/02_nutrition/02_products_food.dta", clear

********************************************************************************
**			FIXING BRANDS													  **
********************************************************************************

* Combine all NESTLE BRANDS

replace brand = "NESTLE-280" if brand == "MILO-278"
replace brand = "NESTLE-280" if brand == "NESQUIK-454"
replace brand = "NESTLE-280" if brand == "FITNESS-6642"
replace brand = "NESTLE-280" if brand == "AVENA Y MAS-13894"

********************************************************************************
**		1.	DEFINE PRODUCT CATEGORY											  **
********************************************************************************

* In this section we check some products to see whether all of them are labeled under the same category. 
* For example, cookies are both under 08351 CANDY - CHOCOLATES and 08439 GALLETAS - GONDOLA

** You need to look for some products you know, such as TRIX, CHOCAPIC, etc.. and check whether they appear in more than one category.
** If they do, we need to rename the category

order category_name
*br if strpos(name , "TRIX")
*br if strpos(name , "FITNESS")
*br if strpos(name , "CEREAL")

* Only 1 category with cereals 

keep if category_name == "09369 DESAYUNO-CEREAL-BARRA"

* Here we look at the subcategories. For example, we don't want to have cereales in the same category as cereal bars.

* We need to create a new category for BARRAS and start a new do-file for them. That is not done here yet. 

*br   if subcategory_name == "22554 BARRAS"
drop if subcategory_name == "22554 BARRAS"

* We leave avena, granola and colaciones

********************************************************************************
**	2.	IDENTIFY PRODUCTS WITH SAME NUTRITIONAL INFO						  **
********************************************************************************

* Here we go brand by brand identifying which products might have the same nutritional content. 

* Very recommended to use google here. 

tab brand

* Drop brands for which we don't have scanned items, nor fatsecret info (we drop them at the end to recover percentages covered)
gen dropbrand = inlist(brand,"BRUGGEN-2719","ALCAFOOD-6506","MARTINI-267","INCA SUR-7306","SEMIX-15120")

sort brand name

gen nutrition_id = product_id // we start by creating a nutrition id that will be the same for products with the same nutritional info.
gen sell_q_old=sell_q
gen name_old=name
gen fatsecret_id=""
gen fatsecret_id2=""
gen type=""
gen duda=0

order scanned nutrition_id product_id upc_id name name_old brand package type_unit sell_q
sort nutrition_id

* We look for similar products within brands

** ACUENTA *********************************************************************

*br if brand=="ACUENTA-392"
tab type_unit if brand=="ACUENTA-392"

// CEREAL AZUCARADO
replace nutrition_id = "846340" 		if inlist(nutrition_id, "660084")					
replace name="CEREAL AZUCARADO" 		if nutrition_id == "846340"
replace fatsecret_id="noid" 			if nutrition_id == "846340" // no fatsecret match

// CEREAL CHOCOLATADO
replace nutrition_id = "848532" 		if inlist(nutrition_id, "660086")			
replace name="CEREAL CHOCOLATADO" 		if inlist(name,"CEREAL CHOCOLATADO", "CHOCOLATADO ACUENTA")
replace fatsecret_id="224992572812252" 	if nutrition_id == "848532" // acuenta	Cereal Chocolatado

// CEREAL CORNFLAKES
replace nutrition_id = "848530" 		if inlist(nutrition_id, "848530")			
replace name="CORN FLAKES" 				if inlist(name,"CEREAL CORNFLAKES","CORNFLAKE ACUENTA", "CORNFLAKE ACUENTA")
replace fatsecret_id="641657398492055" 	if nutrition_id == "848530" // acuenta	Cereal Cornflakes

// CEREAL ESTRELLAS
replace nutrition_id = "846338" 		if inlist(nutrition_id, "846338")			
replace name="ESTRELLAS" 				if inlist(name,"CEREAL ESTRELLAS AC","CEREAL ESTRELLAS")
replace fatsecret_id="noid" 			if nutrition_id == "846338" // no fatsecret match

// CEREAL ESFERAS CHOCOLATE
replace nutrition_id = "846336" 		if inlist(nutrition_id, "846336")			
replace name="ESFERAS CHOCOLATE" 		if inlist(name,"CEREAL ESFERA CHOCOL","ESFERA CHOCOL AC")
replace fatsecret_id="179054988422372" 	if nutrition_id == "846336" // acuenta	Cereal Bolitas


** ADELGAZUL *******************************************************************

*br if brand=="ADELGAZUL-2576"
tab type_unit if brand=="ADELGAZUL-2576"

// ACTIVO CON PREBIOTICOS
replace nutrition_id = "492753" 		if inlist(nutrition_id, "492753")			
replace name="ACTIVO CON PREBIOTICO" 	if inlist(name,"CEREAL ACTIVO PREV")
replace fatsecret_id="194378076165853" 	if nutrition_id == "492753" 	// no fatsecret match

// FIBRA
replace nutrition_id = "492757" 		if inlist(nutrition_id, "492757")			
replace name="FIBRA" 					if inlist(name,"CEREAL FIBRA")
replace fatsecret_id="146789234016020" 	if nutrition_id == "492757" 	// Cereal Fibra

// FIBRA HOJUELAS CON FRUTA
replace nutrition_id = "492763" 			if inlist(nutrition_id, "492763")			
replace name="FIBRA Y HOJUELAS CON FRUTA" 	if inlist(name,"CEREAL FIBRA/HOJUEL")
replace fatsecret_id="215826538483350" 		if nutrition_id == "492763" // Fibra y Hojuelas con Frutas

// HOJUELAS INTEGRALES
replace nutrition_id = "492751" 		if inlist(nutrition_id, "492751")			
replace name="HOJUELAS INTEGRALES" 		if inlist(name,"CEREAL HOJU/INTEGR")
replace fatsecret_id ="240126267131961" if nutrition_id == "492751" 	// Cereal Hojuelas Integrales
replace fatsecret_id2="200436310756178" if nutrition_id == "492751" 	// Hojuelas Integrales
* These are the same product

// SPORT CON PREBIÓTICOS
replace nutrition_id = "492755" 		if inlist(nutrition_id, "492755")			
replace name="SPORT CON PREBIÓTICOS" 	if inlist(name,"CEREAL SPORT PREV.")
replace fatsecret_id="149713693280299" 	if nutrition_id == "492755" 	// adelgazul	Sport

** COLA CAO ********************************************************************
*br if brand=="COLA CAO-2798"	
tab type_unit if brand=="COLA CAO-2798"

// PILLOWS
replace nutrition_id = "5187" 			if inlist(nutrition_id, "5187")
replace name="PILLOWS" 					if inlist(name,"CEREAL PILLOWS")
replace fatsecret_id="177324471579436" 	if nutrition_id == "5187" 	// Pillows

// MINI PILLOWS
replace nutrition_id = "279037" 		if inlist(nutrition_id, "279025")
replace name="MINI PILLOWS" 			if inlist(name,"CEREAL MINI PILLOWS","CEREAL PILLOWS MINI")
replace fatsecret_id="524290085936925" 	if nutrition_id == "279037" // Mini Pillows
replace fatsecret_id2="272889889043241" if nutrition_id == "279037" // Pillows Mini

// PILLOWS MANJAR * SOLAMENTE EN JUMBO
replace nutrition_id = "145680" 		if inlist(nutrition_id, "145680")
replace name="PILLOWS MANJAR" 			if inlist(name,"CEREAL PILOWS MANJAR")
replace fatsecret_id="noid" 				if nutrition_id == "145680" // Mini Pillows
*drop if nutrition_id == "145680"

** COSTA ***********************************************************************
*br if brand=="COSTA-205"
tab type_unit if brand=="COSTA-205"
replace sell_q="0,021" if inlist(product_id,"707557")
replace type_unit="KG" if inlist(product_id,"707557") 

drop if nutrition_id=="295361"	// Snack bar

// MONO CHOC
replace nutrition_id = "665323" 		if inlist(nutrition_id,"699936","699934","268240","11481","707551","707557") 
replace name="MONO CHOC" 				if nutrition_id == "665323" | nutrition_id == "707557" // same labels
replace fatsecret_id="325527839791397" 	if nutrition_id == "665323" // Monochoc

// MONO BALLS
replace nutrition_id = "272768" if inlist(nutrition_id, "5359","707553")							
replace name="MONO BALLS" 				if nutrition_id == "272768" | nutrition_id=="707553" // slight differences
replace fatsecret_id="497959968883333" 	if nutrition_id == "272768" // Mono Balls

// MONO ROLLS
replace nutrition_id = "381128" if inlist(nutrition_id, "862005","295543", "707555")								
replace name="MONO ROLLS" 				if nutrition_id == "381128" 
replace fatsecret_id="252932769707890" 	if nutrition_id == "381128" // Mono Rolls

replace dropbrand=1 if brand=="COSTA-205" & name!="MONO ROLLS" & name!="MONO CHOC" & name!="MONO BALLS" 
* DELETED HOJUELA INTEGRAL, CARS and OTHERS							

** EN LINEA ********************************************************************
*br if brand=="EN LINEA-7541"
tab type_unit if brand=="EN LINEA-7541"

* THESE PRODUCTS DON'T HAVE LABELS

// HOJUELAS DE MAIZ ENDULZADAS KIDS
replace nutrition_id = "848728" 				if inlist(nutrition_id, "848728","848724")								
replace name="HOJUELAS DE MAIZ ENDULZADAS KIDS" if nutrition_id == "848728" 
replace fatsecret_id="271490048795905" 			if nutrition_id == "848728" //Cereales Hojuelas de Maiz Endulzadas
replace duda=1 if product_id=="848724"

// BOLITAS DE CHOCOLATE
replace nutrition_id = "760960" 				if inlist(nutrition_id, "760960")								
replace name="BOLITAS DE CHOCOLATE" 			if nutrition_id == "760960" 
replace fatsecret_id="870800678706675" 		 	if nutrition_id == "760960" // Cereales Bolitas Sabor Chocolate
replace fatsecret_id2="258811698023988" 		 	if nutrition_id == "760960" // Bolitas Sabor Chocolate

// HOJUELAS SABOR CHOCOLATE
replace nutrition_id = "764989" 				if inlist(nutrition_id, "764989")								
replace name="HOJUELAS SABOR CHOCOLATE" 		if nutrition_id == "764989" 
replace fatsecret_id="173244293168347" 			if nutrition_id == "764989" // Cereales Hojuelas Sabor Chocolate
replace fatsecret_id2="335249333275827"			if nutrition_id == "764989" // Cereales Hojuelas Sabor Chocolate

// CEREAL SABOR FRUTAl KIDS
replace name="CEREAL SABOR FRUTAL KIDS" 		if nutrition_id=="887450"
replace fatsecret_id="270167782935350" 			if nutrition_id=="887450"  // Cereal Sabor Frutal

// INFLADO DE TRIGO
replace nutrition_id = "887454" 				if inlist(nutrition_id, "887454")								
replace name="INFLADO DE TRIGO" 				if nutrition_id == "887454" 
replace fatsecret_id="957287054557189" 			if nutrition_id == "887454" // Cereal Inflado de Trigo

// INFLADO DE ARROZ
replace nutrition_id = "887452" 				if inlist(nutrition_id, "887452")								
replace name="INFLADO DE ARROZ" 				if product_id == "887452" 
replace fatsecret_id="582317447277036" 			if nutrition_id == "887452" // Cereal Inflado de Arroz

** GO OATS *********************************************************************

*br if brand=="GO OATS-15404"
tab type_unit if brand=="GO OATS-15404"
							
// AVENA SABOR CAPUCCINO
replace name="AVENA SABOR CAPUCCINO" 		if nutrition_id == "866832" 
replace fatsecret_id="noid"					if nutrition_id == "866832" 

// AVENA SABOR CHOCOLATE
replace name="AVENA SABOR CHOCOLATE" 		if nutrition_id == "866828" 
replace fatsecret_id="noid"					if nutrition_id == "866828" 

// AVENA SABOR FRUTOS ROJOS
replace name="AVENA SABOR FRUTOS ROJOS" 	if nutrition_id == "866830" 
replace fatsecret_id="noid"					if nutrition_id == "866830" 

// AVENA SABOR MANZANA CANELA
replace name="AVENA SABOR MANZANA CANELA" 	if nutrition_id == "866826" 
replace fatsecret_id="noid"					if nutrition_id == "866826" 

* all products scanned, and none has labels

** GRANVITA *********************************************************************
*br if brand=="GRANVITA-8143"
tab type_unit if brand=="GRANVITA-8143"

// GRANOLA ZERO AZUCAR ARANDANO
replace nutrition_id = "674364" 						if inlist(nutrition_id, "674364")								
replace name="GRANOLA ZERO AZUCAR ARANDANO" 			if product_id == "674364" 
replace fatsecret_id="noid"								if nutrition_id == "674364" 

// GRANOLA ZERO AZUCAR 
replace nutrition_id = "674362" 						if inlist(nutrition_id, "674362")								
replace name="GRANOLA ZERO AZUCAR" 						if product_id == "674362"
replace fatsecret_id="noid"								if nutrition_id == "674362"  

// AVENA INSTANTANEA ZERO AZUCAR  FRESA
replace name="AVENA INSTANTANEA ZERO AZUCAR FRESA" 		 if product_id=="674356"
replace fatsecret_id="noid"								 if nutrition_id == "674356"  

// AVENA INSTANTANEA ZERO AZUCAR  MANZANA
replace name="AVENA INSTANTANEA ZERO AZUCAR MANZANA" 	 if product_id=="674358"
replace fatsecret_id="noid"								 if nutrition_id == "674358"  

// AVENA INSTANTANEA ZERO AZUCAR  NUEZ
replace name="AVENA INSTANTANEA ZERO AZUCAR NUEZ" 		 if product_id=="674360"
replace fatsecret_id="noid"								 if nutrition_id == "674360"  

// AVENA INSTANTANEA ZERO AZUCAR  SABORES
replace name="AVENA INSTANTANEA ZERO AZUCAR SABORES" 	 if product_id=="774696"
replace fatsecret_id="noid"								 if nutrition_id == "774696"  

// AVENA INSTANTANEA ZERO AZUCAR  NATURAL
replace name="AVENA INSTANTANEA ZERO AZUCAR NATURAL" 	 if product_id=="674354"
replace fatsecret_id="noid"								 if nutrition_id == "674354"  

// AVENA INSTANTANEA TRADICIONAL FRESA CREMA
replace name="AVENA INSTANTANEA TRADICIONAL FRESA CREMA" if product_id=="823724"
replace fatsecret_id="noid"								 if nutrition_id == "823724"

// AVENA INSTANTANEA TRADICIONAL MIEL NUEZ
replace name="AVENA INSTANTANEA TRADICIONAL MIEL NUEZ" 	 if product_id=="823726"
replace fatsecret_id="noid"								 if nutrition_id == "823726"

*Se pueden buscar en google la info nutricional

** GREAT VALUE *****************************************************************
*br if brand=="GREAT VALUE-799"
tab type_unit if brand=="GREAT VALUE-799"

// CORN FLAKES
replace name="CORN FLAKES"           if nutrition_id=="884050"
replace fatsecret_id="noid" 		 if nutrition_id == "884050"

// COCOA CRISPY RICE 
replace name="COCOA CRISPY RICE"   	 if nutrition_id=="884044"
replace fatsecret_id="noid"			 if nutrition_id == "884044"

// FRUITY WHIRLS"
replace name="FRUITY WHIRLS"      	 if nutrition_id=="884048" 
replace fatsecret_id="noid"			 if nutrition_id == "884048"

// HONEY NUT TOASTED OAT
replace name="HONEY NUT TOASTED OAT" if nutrition_id=="884046"
replace fatsecret_id="noid"			 if nutrition_id == "884046"

** KELLOGS *********************************************************************
*br if brand=="KELLOGGS-241"
tab type_unit if brand=="KELLOGGS-241"

// ZUCARITAS
replace nutrition_id = "268222" 		if inlist(nutrition_id,"633718","2655","592911","592913","289871") 								
replace name="ZUCARITAS" 				if nutrition_id == "268222" 
replace fatsecret_id="211022636348514" 	if nutrition_id == "268222" 

// FROOT LOOPS
replace nutrition_id = "2759"   		if inlist(nutrition_id, "289523")  
replace name="FROOT LOOPS" 				if nutrition_id == "2759" 
replace fatsecret_id="206705868998883" 	if nutrition_id == "2759" 

// CORN FLAKES
replace nutrition_id = "659387" 		if inlist(nutrition_id, "735670","2647")			    			
replace name="CORN FLAKES" 				if nutrition_id == "659387" 
replace fatsecret_id="noid"				if nutrition_id == "659387"

// CHOCO KRISPIS
replace nutrition_id = "289853" 		if inlist(nutrition_id, "659650", "628386","2699") 			 	
replace name="CHOCO KRISPIS" 			if nutrition_id == "289853" 
replace fatsecret_id="212585084021683" 	if nutrition_id == "289853" 

// CHOCO ZUCARITAS
replace nutrition_id = "289891" 		if inlist(nutrition_id, "289931")  						
replace name="CHOCO ZUCARITAS" 			if nutrition_id == "289891" 
replace fatsecret_id="noid"				if nutrition_id == "289891"

// MUESLIX
replace name="CEREAL MUSLIX" 			if nutrition_id == "574598" 

** LIDER  **********************************************************************

*br if brand=="LIDER-398"
tab type_unit if brand=="LIDER-398"

// ENERGY BALL
replace nutrition_id = "268258" if inlist(nutrition_id,"298649")		
replace name="ENERGY BALL" 		if nutrition_id == "268258"					
replace fatsecret_id="127438398966501"				if nutrition_id == "268258"


// CHOCOLATADOS
replace nutrition_id = "743410" 		if inlist(nutrition_id,"268286","2719","298037","743408","121694","743412")	
replace name="CHOCOLATADOS" 			if nutrition_id == "743410"	
replace fatsecret_id="100546220953057"	if nutrition_id == "743410"
replace duda=1 							if product_id=="121694"

* Same cereal, but with different info	
*replace name="CHOCOLATADOS, BOLSA" 		if nutrition_id == "743412"	
*replace fatsecret_id="100546220953057"	if nutrition_id == "743412"

// CORN FLAKES
replace nutrition_id = "486384" 		if inlist(nutrition_id,"762056", "824658")
replace name="CORN FLAKES" 				if nutrition_id == "486384"	
replace fatsecret_id="214614650477336"	if nutrition_id == "486384"

// CEREAL ATOMICO
replace nutrition_id = "295955" 		if inlist(nutrition_id,"2683")							
replace name="ATOMICO" 					if nutrition_id == "295955"	
replace fatsecret_id="noid" 			if nutrition_id == "295955"

// AVENA INSTANTANEA
replace nutrition_id = "296189" 		if inlist(nutrition_id,"5119")							
replace name="AVENA INSTANTANEA" 		if nutrition_id == "296189"	
replace fatsecret_id="noid" 			if nutrition_id == "296189"

// AVENA TRADICIONAL
replace nutrition_id = "300879" 		if inlist(nutrition_id,"6361")								
replace name="AVENA TRADICIONAL" 		if nutrition_id == "300879"	
replace fatsecret_id="noid" 			if nutrition_id == "300879"

// ZUCARADAS
replace nutrition_id = "824674" 		if inlist(nutrition_id,"824674")								
replace name="ZUCARADAS" 				if nutrition_id == "824674"	
replace fatsecret_id="noid" 			if nutrition_id == "824674"
	
// CEREAL FRUTAL	
replace nutrition_id = "298043" 		if inlist(nutrition_id,"2757", "295939")	
replace name="FRUTAL" 					if nutrition_id == "298043"		
replace fatsecret_id="162884822367898" 	if nutrition_id == "298043"
replace duda=1 if product_id=="295939"

// CEREAL FIT MIEL Y ALMENDRAS 
replace nutrition_id = "906177" 			if inlist(nutrition_id,"906177")							
replace name="CEREAL FIT MIEL & ALMENDRAS"	if nutrition_id == "906177"	
replace fatsecret_id="noid" 				if nutrition_id == "906177"	

// CUADRITOS DE AVENA
replace nutrition_id = "825341" 		if inlist(nutrition_id,"825341")							
replace name="CUADRITOS DE AVENA"		if nutrition_id == "825341"	
replace fatsecret_id="noid" 			if nutrition_id == "825341"	
	
// INFLADOS TRIGO Y MIEL
replace nutrition_id = "486380" 		if inlist(nutrition_id,"662208","486382")				
replace name="INFLADOS, TRIGO Y MIEL"	if nutrition_id == "486380"		
replace fatsecret_id="noid" 			if nutrition_id == "486380"	

// INFLADOS MAIZ Y MIEL
replace nutrition_id = "297367" 		if inlist(nutrition_id,"297353","385675")				
replace name="INFLADOS, MAIZ Y MIEL"	if nutrition_id == "297367"	
replace fatsecret_id="251361329809590" 	if nutrition_id == "297367"	

// INFLADOS ARROZ Y MIEL
replace nutrition_id = "298551" 		if inlist(nutrition_id,"298683","385677")				
replace name="INFLADOS, ARROZ Y MIEL"	if nutrition_id == "298551"	
replace fatsecret_id="319326562465302" 	if nutrition_id == "298551"	

// GRANOLA MIEL Y ALMENDRAS
replace nutrition_id = "905891" 		if inlist(nutrition_id,"905891")			
replace name="GRANOLA MIEL Y ALMENDRAS"	if nutrition_id == "905891"	
replace fatsecret_id="noid"			 	if nutrition_id == "905891"	

// GRANOLA PASAS, MIEL Y ALMENDRAS
replace nutrition_id = "905893" 				if inlist(nutrition_id,"905893")			
replace name="GRANOLA PASAS, MIEL Y ALMENDRAS"	if nutrition_id == "905893"	
replace fatsecret_id="noid" 					if nutrition_id == "905893"	

** NATUR  **********************************************************************
 
*br if brand=="NATUR-220"
tab type_unit if brand=="NATUR-220"
replace sell_q="0,02" if inlist(product_id,"11483")
replace type_unit="KG" if inlist(product_id,"11483") 

// ARROZ
replace nutrition_id = "2739" 			if inlist(nutrition_id,"331604","331606","276612")	
replace name="INFLADOS, ARROZ"			if nutrition_id == "2739"	
replace fatsecret_id="190913091183437" 	if nutrition_id == "2739"	

// MAIZ
replace nutrition_id = "2743" 	if inlist(nutrition_id,"268362","268420","11483")		
replace name="INFLADOS, MAIZ"	if nutrition_id == "2743"	
replace fatsecret_id="925385410012703" 	if nutrition_id == "2743"	

// TRIGO
replace nutrition_id = "2747" 	if inlist(nutrition_id,"268394","268440","11485")	
replace name="INFLADOS, TRIGO"	if nutrition_id == "2747"	
replace fatsecret_id="312887369207500" 	if nutrition_id == "2747"	

** NESTLE  *********************************************************************

*br if brand=="NESTLE-280"
tab type_unit if brand=="NESTLE-280"

// GOLD
replace nutrition_id = "280715" 		if inlist(nutrition_id,"280715") 	
replace name="GOLD"						if nutrition_id == "280715"	
replace fatsecret_id="279863715932438" 	if nutrition_id == "280715"	

// CHEERIOS
replace nutrition_id = "526568" 		if inlist(nutrition_id,"526568") 	
replace name="CHEERIOS"					if nutrition_id == "526568"	
replace fatsecret_id="215913067608996" 	if nutrition_id == "526568"	
replace fatsecret_id2="228989923774056" if nutrition_id == "526568"	

// CHOCAPIC
replace nutrition_id = "910015" 		if inlist(nutrition_id,"914895","898080","2695","5539","630936","268274","630934","272700") 
replace name="CHOCAPIC"					if nutrition_id == "910015"	
replace fatsecret_id="275856417644310" 	if nutrition_id == "910015"	
replace duda=1 if product_id=="630936" | product_id=="272700"

// CHOCAPIC GRANOLA
replace nutrition_id = "859626" 		if inlist(nutrition_id,"859626") 	
replace name="CHOCAPIC GRANOLA"			if nutrition_id == "859626"		
replace fatsecret_id ="311250703998606" if nutrition_id == "859626"	
replace fatsecret_id2="313385696500550" if nutrition_id == "859626"	

// CHOCAPIC MANJAR
replace nutrition_id = "669271" 		if inlist(nutrition_id,"715204") 	
replace name="CHOCAPIC MANJAR"			if nutrition_id == "669271"			
replace fatsecret_id ="103882975464653" if nutrition_id == "669271"	

// CHOCAPIC TROCITOS						
replace nutrition_id = "377499" 		if inlist(nutrition_id,"707183") 		
replace name="CHOCAPIC TROCITOS"		if nutrition_id == "377499"		
replace fatsecret_id ="143043810341058" if nutrition_id == "377499"	

// ESTRELLITAS
replace nutrition_id = "3239" 			if inlist(nutrition_id,"2643","592312") 
replace name="ESTRELLITAS"				if nutrition_id == "3239"		
replace fatsecret_id ="231337373052866" if nutrition_id == "3239"	

// TRIX									
replace nutrition_id = "898082" 		if inlist(nutrition_id,"881658","283821","5871","571859","801390") 	
replace name="TRIX"						if nutrition_id == "898082"		
replace fatsecret_id ="154253701704625" if nutrition_id == "898082"	

// MILO			
replace nutrition_id = "913552" 		if inlist(nutrition_id,"5873","2707","126210","592302","813828") 
replace name="MILO"						if nutrition_id == "913552"		
replace fatsecret_id ="306992230664734" if nutrition_id == "913552"	

// ZUCOSOS
replace nutrition_id = "707185" 		if inlist(nutrition_id,"17217","11489","707189") 	
replace name="ZUCOSOS" 					if nutrition_id == "707185"	
replace fatsecret_id ="338733284077985" if nutrition_id == "707185"	

// CORN FLAKES
replace nutrition_id = "874678" 		if inlist(nutrition_id,"707187") 		
replace name="CORN FLAKES" 				if nutrition_id == "874678"
replace fatsecret_id ="163105999770410" if nutrition_id == "874678"	
	
// NESQUIK
replace nutrition_id = "298641" 		if inlist(nutrition_id,"707199") 
replace name="NESQUIK" 					if nutrition_id == "298641"														
replace fatsecret_id ="118221666322793" if nutrition_id == "298641"	

// FITNESS 
replace nutrition_id = "282821" 		if inlist(nutrition_id,"2789","898084","11575","821792","719460","718682","267986", "874676","900987") 
replace name="FITNESS" 					if nutrition_id == "282821" | nutrition_id=="900987"
replace fatsecret_id ="161878216739821" if nutrition_id == "282821"	| nutrition_id=="900987"
replace fatsecret_id2="245824473663391" if nutrition_id == "282821"	| nutrition_id=="900987"
replace duda=1 if product_id=="718682" | product_id=="267986" | product_id=="874676"

// FITNESS GRANOLA HONEY
replace nutrition_id = "859622" 		if inlist(nutrition_id,"859622")
replace name="FITNESS GRANOLA HONEY"	if nutrition_id=="859622"
replace fatsecret_id="noid" 			if nutrition_id=="859622"	

// FITNESS GRANOLA CRANBERRY
replace nutrition_id = "859624" 		 if inlist(nutrition_id,"859624")
replace name="FITNESS GRANOLA CRANBERRY" if nutrition_id=="859624"
replace fatsecret_id="noid" 			 if nutrition_id=="859624"

// FITNESS YOGHURT
replace nutrition_id = "915382"	 		if inlist(nutrition_id,"267956") 	 										
replace name="FITNESS YOGHURT" 			if nutrition_id == "915382"
replace fatsecret_id ="235887448235461" if nutrition_id == "915382"	
replace fatsecret_id2="280719251413014" if nutrition_id == "915382"	
			
// FITNESS CHOCO					
replace nutrition_id = "915380"  		if inlist(nutrition_id,"823176") 	
replace name="FITNESS CHOCOLATE" 		if nutrition_id == "915380"
replace fatsecret_id ="467587634813569" if nutrition_id == "915380"	
replace fatsecret_id2="751533539183253" if nutrition_id == "915380"	
			
// FITNESS MIEL & ALMENDRAS	
replace nutrition_id = "901216"		 	if inlist(nutrition_id,"499045") 												
replace name="FITNESS MIEL & ALMENDRAS" if nutrition_id == "901216"
replace fatsecret_id ="645737190377006" if nutrition_id == "901216"	
replace fatsecret_id2="516205571855589" if nutrition_id == "901216"	

// FITNESS FRUITS
replace nutrition_id = "901218" 		if inlist(nutrition_id,"283741") 													
replace name="FITNESS FRUITS" 			if nutrition_id == "901218"
replace fatsecret_id ="261690521925772" if nutrition_id == "901218"	
replace fatsecret_id2="248329712007450" if nutrition_id == "901218"	

// FITNESS FIBRA MANZANA												
replace name="FITNESS FIBRA MANZANA" 	if nutrition_id == "699608"
replace fatsecret_id ="145238069555618" if nutrition_id == "699608"	
replace fatsecret_id2="876961235501655" if nutrition_id == "699608"	

// FITNESS FIBRA FRUTILLA												
replace name="FITNESS FIBRA FRUTILLA" 	if nutrition_id == "699606"
replace fatsecret_id ="145238069555618" if nutrition_id == "699606"	
replace fatsecret_id2="876961235501655" if nutrition_id == "699606"	

// AVENA Y MAS MULTIMIX												
replace name="AVENA Y MAS MULTIMIX" 			if nutrition_id == "887474"
replace fatsecret_id="332408011259168" 			if nutrition_id == "887474"	

// AVENA Y MAS HOJUELAS PASAS													
replace name="AVENA Y MAS HOJUELAS PASAS" 		if nutrition_id == "765041"
replace fatsecret_id="127537321885536" 			if nutrition_id == "765041"	

// AVENA Y MAS HOJUELAS ALMENDRAS													
replace name="AVENA Y MAS HOJUELAS ALMENDRAS" 	if nutrition_id == "765045"
replace fatsecret_id="noid" 					if nutrition_id == "765045"	

// AVENA Y MAS GRANOLA FRUTAS												
replace name="AVENA Y MAS GRANOLA FRUTAS" 		if nutrition_id == "765039"
replace fatsecret_id="285361342220486" 			if nutrition_id == "765039"	

// AVENA Y MAS GRANOLA TRADICIONAL												
replace name="AVENA Y MAS GRANOLA TRADICIONAL" 	if nutrition_id == "765043"
replace fatsecret_id="285361342220486" 			if nutrition_id == "765043"	

// AVENA Y MAS COOL MIX CACAO												
replace name="AVENA Y MAS COOL MIX CACAO" 		if nutrition_id == "905465"
replace fatsecret_id="noid" 					if nutrition_id == "905465"	

// AVENA Y MAS COOL MIX MIEL												
replace name="AVENA Y MAS COOL MIX MIEL" 		if nutrition_id == "905467"
replace fatsecret_id="noid" 					if nutrition_id == "905467"	

*DROP VARIEDADES
drop if nutrition_id=="747098" | nutrition_id=="767526"

** QUAKER **********************************************************************
*br if brand=="QUAKER-215"
tab type_unit if brand=="QUAKER-215"
replace sell_q = "0,37" if sell_q == "3,7" & inlist(upc_id,"780200001134","780200001130")
replace sell_q = "0,35" if sell_q == "3,5" & upc_id == "780200001048"

// AVENA TRADICIONAL
replace nutrition_id = "296899" 					if inlist(nutrition_id,"805941")	
replace name="AVENA TRADICIONAL" 					if nutrition_id=="296899"
replace fatsecret_id="337274750324566" 				if nutrition_id=="296899"	

// AVENA INSTANTANEA
replace nutrition_id = "2769" 						if inlist(nutrition_id,"805939")						
replace name="AVENA INSTANTANEA" 					if nutrition_id == "2769" 
replace fatsecret_id="526371983109872" 				if nutrition_id == "2769"	

// AVENA MULTISEMILLAS 
replace nutrition_id = "913856" 					if inlist(nutrition_id,"913856")						
replace name="AVENA MULTISEMILLAS" 					if nutrition_id == "913856" 
replace fatsecret_id="185906453365105" 				if nutrition_id == "913856"	

// AVENA MULTISEMILLAS MANZANA Y PASAS
replace nutrition_id = "845914" 					if inlist(nutrition_id,"845914")						
replace name="AVENA MULTISEMILLAS MANZANA Y PASAS" 	if nutrition_id == "845914" 
replace fatsecret_id="noid" 						if nutrition_id == "845914"	

// AVENA MULTISEMILLAS CHIA LINAZA
replace nutrition_id = "887472" 					if inlist(nutrition_id,"887472")						
replace name="AVENA MULTISEMILLAS CHIA LINAZA" 		if nutrition_id == "887472" 
replace fatsecret_id="noid" 						if nutrition_id == "887472"	

// QUADRITOS
replace nutrition_id = "903783" 					if inlist(nutrition_id,"761952","295181","574000")			
replace name="QUADRITOS" 							if nutrition_id == "903783"
replace fatsecret_id="897632209848721" 				if nutrition_id == "903783"	

// QUADRITOS CANELA
replace nutrition_id = "770898" 					if inlist(nutrition_id,"770898")			
replace name="QUADRITOS CANELA"						if nutrition_id == "770898"
replace fatsecret_id="noid" 						if nutrition_id == "770898"	

// HEARTS
replace nutrition_id = "903781" 					if inlist(nutrition_id,"704571")				
replace name="HEARTS" 								if nutrition_id == "903781"
replace fatsecret_id="326600652456612" 				if nutrition_id == "903781"

// GRANOLA MIEL PASAS
replace nutrition_id = "2595" 	    				if inlist(nutrition_id,"770908")	
replace name="GRANOLA MIEL Y PASAS" 				if nutrition_id == "2595"			
replace fatsecret_id="176511576161544" 				if nutrition_id == "2595"

// GRANOLA MIEL ALMENDRAS
replace nutrition_id = "770904" 	    				if inlist(nutrition_id,"770904")	
replace name="GRANOLA MIEL Y ALMENDRAS" 				if nutrition_id == "770904"			
replace fatsecret_id="176511576161544" 				if nutrition_id == "770904"

// GRANOLA MANZANA ARANDANO		
replace nutrition_id = "770906" 					if inlist(nutrition_id,"627470")	
replace name="GRANOLA MANZANA ARANDANO" 			if nutrition_id == "770906"	
replace fatsecret_id="262561592425399" 				if nutrition_id == "770906"

// GRANOLA MIEL PASAS	
replace name="CEREAL LIFE" 				if nutrition_id == "296865"	

** SELECCION *******************************************************************
*br if brand=="SELECCION-449"		
tab type_unit if brand=="SELECCION-449" 

// MIX BERRIES
replace name="MIX BERRIES"		  	if product_id=="294455"
replace fatsecret_id="noid" 		if product_id=="294455"

// CHOCOLATE ALMENDRA
replace name="CHOCOLATE ALMENDRA" 	if product_id=="294473"
replace fatsecret_id="noid" 		if product_id=="294473"
 
** SELECTA *********************************************************************
*br if brand=="SELECTA-207"
tab type_unit if brand=="SELECTA-207"

// AVENA TRADICIONAL
replace nutrition_id = "859636" 		if inlist(nutrition_id,"268748")
replace name="AVENA TRADICIONAL"		if nutrition_id=="859636"	
replace fatsecret_id="133836919858502" 	if nutrition_id=="859636"	

// AVENA INSTANTANEA	
replace name="AVENA INSTANTANEA" 		if nutrition_id=="859634"
replace fatsecret_id="654373891810322" 	if nutrition_id=="859634"	

// GRANOLA TRADICIONAL
replace name="GRANOLA TRADICIONAL" 		if nutrition_id=="838200"
replace fatsecret_id="173570391183914" 	if nutrition_id=="838200"

// GRANOLA BAJO EN GRASAS
replace name="GRANOLA BAJO EN GRASAS" 	if nutrition_id=="838198"
replace fatsecret_id="170652317764920" 	if nutrition_id=="838198"	

// GRANOLA CHOCOLATE
replace name="GRANOLA CHOCOLATE" 		if nutrition_id=="859630"
replace fatsecret_id="288301733897168" 	if nutrition_id=="859630"

** VIVO ************************************************************************
*br if brand=="VIVO-412"

replace sell_q = "0,6" if inlist(upc_id,"780012017011") // use prices to have an informed guess about this value
replace sell_q = "0,03" if inlist(upc_id,"780012016410","780012017208","780012017107","780012017209") // use prices to have an informed guess about this value
replace type_unit = "KG" if inlist(upc_id,"780012016410","780012017208","780012017107","780012017209") 


// VIVO CHECK CACAO
replace nutrition_id = "834057" 		if inlist(nutrition_id,"834057","824650") | inlist(upc_id,"780012017106")						
replace name="CHECK CACAO" 				if nutrition_id == "834057"
replace fatsecret_id="noid"			 	if nutrition_id == "834057"

// VIVO CHECK YOGURT
replace nutrition_id = "824652" 		if inlist(nutrition_id,"824652","834059","824652")						
replace name="CHECK YOGHURT" 			if nutrition_id == "824652"
replace fatsecret_id="noid"			 	if nutrition_id == "824652"

// VIVO CHECK 3 CEREALES
replace nutrition_id = "834055" 		if inlist(nutrition_id,"834055","665329","702337", "849729") | inlist(upc_id,"780012017107")					
replace name="CHECK 3 CEREALES" 		if nutrition_id == "834055"
replace fatsecret_id="193064453702206" 	if nutrition_id == "834055"
replace duda=1 if product_id=="849729"


// AVENA INSTANTANEA
replace nutrition_id = "849727" 		if inlist(nutrition_id,"834061", "898280","594019")		
replace name="AVENA INSTANTANEA" 		if nutrition_id == "849727"
replace name="AVENA INSTANTANEA" 		if nutrition_id == "594019"		// different level of sodium
replace fatsecret_id="212520354265940" 	if nutrition_id == "849727"
replace fatsecret_id="212520354265940"  if nutrition_id == "594019"

// AVENA 4 SEMILLAS
replace nutrition_id = "838202" 		if inlist(nutrition_id,"838202","708002")						
replace name="AVENA 4 SEMILLAS" 		if nutrition_id == "838202"
replace fatsecret_id="114591491497686" 	if nutrition_id == "838202"
replace duda=1 if product_id=="708002"

// AVENA 4 SEMILLAS + BERRIES
replace nutrition_id = "859628" 			if inlist(nutrition_id,"859628")						
replace name="AVENA 4 SEMILLAS + BERRIES" 	if nutrition_id == "859628"
replace fatsecret_id="noid"			 		if nutrition_id == "859628"

// AVENA CLUSTERS BERRIES
replace nutrition_id = "826085" 			if inlist(nutrition_id,"826085")						
replace name="AVENA CLUSTERS BERRIES" 		if nutrition_id == "826085"
replace fatsecret_id="noid"			 		if nutrition_id == "826085"

// AVENA QUINOA
replace nutrition_id = "823263" 			if inlist(nutrition_id,"823263")						
replace name="AVENA QUINOA"		 			if nutrition_id == "823263"
replace fatsecret_id="noid"			 		if nutrition_id == "823263"

// GRANOLA BERRIES
replace name="GRANOLA BERRIES" 				if inlist(nutrition_id,"834063","700034") | inlist(upc_id,"780012017208")
replace fatsecret_id="154082178407510" 		if nutrition_id == "834063"

// GRANOLA CACAO	
replace name="GRANOLA CACAO" 				if nutrition_id == "594017"
replace fatsecret_id="noid"			 		if nutrition_id == "594017"

// GRANOLA MIEL & ALMENDRAS
replace nutrition_id = "834065" 			if inlist(nutrition_id,"834065","700036") | inlist(upc_id,"780012017209")						
replace name="GRANOLA MIEL & ALMENDRAS" 	if nutrition_id == "834065"
replace fatsecret_id="113073129871510" 		if nutrition_id == "834065"
replace duda=1 if product_id=="700036"

// MUESLI CACAO
replace nutrition_id = "699932" 			if inlist(nutrition_id,"699932")	
replace name="MUESLI CACAO"  				if nutrition_id == "699932"
replace fatsecret_id="noid"			 		if nutrition_id == "699932"

// MUESLI QUINOA & BERRIES
replace nutrition_id = "859632" 			if inlist(nutrition_id,"859632")	
replace name="MUESLI QUINOA & BERRIES"  	if nutrition_id == "859632"
replace fatsecret_id="noid"			 		if nutrition_id == "859632"

// MUESLI 5 CEREALES
replace nutrition_id = "699930" 			if inlist(nutrition_id,"699930")	
replace name="MUESLI 5 CEREALES"  			if nutrition_id == "699930"
replace fatsecret_id="noid"			 		if nutrition_id == "699930"

// LINE 0% AZUCAR
replace nutrition_id = "822108" 			if inlist(nutrition_id,"822108")	
replace name="LINE 0% AZUCAR"  				if nutrition_id == "822108"
replace fatsecret_id="noid"			 		if nutrition_id == "822108"

// LINE YOGURT
replace nutrition_id = "822106" 			if inlist(nutrition_id,"822106")	
replace name="LINE YOGURT"  				if nutrition_id == "822106"
replace fatsecret_id="noid"			 		if nutrition_id == "822106"

// LINE BERRIES
replace nutrition_id = "822110" 			if inlist(nutrition_id,"862007", "822110")	
replace name="LINE BERRIES"  				if nutrition_id == "822110"
replace fatsecret_id="noid"			 		if nutrition_id == "822110"
* https://www.lider.cl/supermercado/product/Vivo-Hojuelas-Vivo-Line-Berries/822110

// BRUNCH FRUTOS ROJOS
replace nutrition_id = "503786" 			if inlist(nutrition_id,"503786")	
replace name="BRUNCH FRUTOS ROJOS"  		if nutrition_id == "503786"
replace fatsecret_id="noid"			 		if nutrition_id == "503786"

// GOOD CHOCOLATE
replace nutrition_id = "905852" 			if inlist(nutrition_id,"905852")	
replace name="GOOD CHOCOLATE"  				if nutrition_id == "905852"
replace fatsecret_id="noid"			 		if nutrition_id == "905852"

// GOOD FRUTAL
replace nutrition_id = "905854"			 	if inlist(nutrition_id,"905854")	
replace name="GOOD FRUTAL"  				if nutrition_id == "905854"
replace fatsecret_id="noid"			 		if nutrition_id == "905854"

tempfile main
save `main', replace

********************************************************************************
**			MERGE NUTRITIONAL INFORMATION									  **
********************************************************************************

* Next, we merge this with the nutritional info digitized by Pavan

use "${Repo}/00_files/02_intermediate/02_nutrition/03_nutritional_info.dta", clear

duplicates drop upc_id , force 
* drop duplicates - this needs to be done more carefully. 

drop label_*

tempfile nutritional
save `nutritional', replace

use `main'

merge 1:1 upc_id using `nutritional' // we merge the main dataset with the nutritional info

drop if _merge==2
drop _merge

********************************************************************************
**			NUTRITION FACT CHECKS											  **
********************************************************************************

replace energy_100=283 	if product_id=="760960"
replace sodium_100=14 	if product_id=="760960"
replace fat_100=4.3 	if product_id=="760960"
replace fat_sat_100=1.4 if product_id=="760960"
replace sugar_100=4.3 	if product_id=="760960"

replace energy_100=374 	 if product_id=="770902"
replace sodium_100=295 	 if product_id=="770902"
replace fat_100=7.9 	 if product_id=="770902"
replace fat_sat_100=2.8  if product_id=="770902"
replace sugar_100=21 	 if product_id=="770902"

replace energy_100=382 	 if product_id=="838202"
replace sodium_100=10 	 if product_id=="838202"
replace fat_100=11.3 	 if product_id=="838202"
replace fat_sat_100=1.84 if product_id=="838202"
replace sugar_100=1.6 	 if product_id=="838202"

replace energy_100=370 	 if product_id=="846340"
replace sodium_100=357 	 if product_id=="846340"
replace fat_100=2   	 if product_id=="846340"
replace fat_sat_100=0.5  if product_id=="846340"
replace sugar_100=37 	 if product_id=="846340"

replace energy_100=296 	 if product_id=="887450"
replace sodium_100=357 	 if product_id=="887450"
replace fat_100=2.2  	 if product_id=="887450"
replace fat_sat_100=.    if product_id=="887450"
replace sugar_100=0.7 	 if product_id=="887450"

* GREAT VALUE CORN FLAKES HAVE A WRONG PIC ASSIGNED
replace energy_100=400 	 if product_id=="884050"
replace sodium_100=365 	 if product_id=="884050"
replace fat_100=0	  	 if product_id=="884050"
replace fat_sat_100=0    if product_id=="884050"
replace sugar_100=11 	 if product_id=="884050"

* GREAT VALUE FRUITY WHIRLS * Rellenar con: https://www.walmart.ca/en/ip/great-value-family-size-fruity-whirls/6000196157597
replace energy_100=400 	 if product_id=="884048"
replace sodium_100=217 	 if product_id=="884048"
replace fat_100=0	  	 if product_id=="884048"
replace fat_sat_100=0    if product_id=="884048"
replace sugar_100=50 	 if product_id=="884048"

* CORN FLAKES LIDER * Rellenar aqui https://www.lider.cl/supermercado/product/Lider-Cereal-Cornflakes-Caja/824658
replace energy_100=361 	 if product_id=="486384"
replace sodium_100=254 	 if product_id=="486384"
replace fat_100=2.1	  	 if product_id=="486384"
replace fat_sat_100=0.5  if product_id=="486384"
replace sugar_100=7.7 	 if product_id=="486384"

* ZUCARADAS * https://www.lider.cl/supermercado/product/Lider-Cereal-Azucarados-Caja/824674
replace energy_100=370 	 if product_id=="824674"
replace sodium_100=357 	 if product_id=="824674"
replace fat_100=2	  	 if product_id=="824674"
replace fat_sat_100=0.5  if product_id=="824674"
replace sugar_100=37 	 if product_id=="824674"

* fixing AVENA INSTANTANEA VIVO (potentially a mistake in the box, or nutr content was changing when picture was taken):
replace sodium_100=4 	 if product_id=="594019"

* fixing FITNESS VIVO (potentially a mistake in the box, or nutr content was changing when picture was taken):
* check here: https://www.lider.cl/supermercado/product/Nestl%C3%A9-Cereal-Fitness-Integral-Caja-330-g/821792 (the box there says something different that the info below)
replace energy_100=349 	 if product_id=="900987"
replace sodium_100=430 	 if product_id=="900987"
replace fat_100=2.2	  	 if product_id=="900987"
replace fat_sat_100=1.1  if product_id=="900987"
replace sugar_100=10 	 if product_id=="900987"

* fixing VIVO CEREAL CHECK
replace energy_100=348 	 if upc_id=="780012017107"
replace fat_100=5.6	  	 if upc_id=="780012017107"
replace fat_sat_100=1.6  if upc_id=="780012017107"
replace sugar_100=3.5 	 if upc_id=="780012017107"
replace sodium_100=399 	 if upc_id=="780012017107"

replace energy_100=344 	 if upc_id=="780012017106"
replace fat_100=5.6	  	 if upc_id=="780012017106"
replace fat_sat_100=1.6  if upc_id=="780012017106"
replace sugar_100=3.5 	 if upc_id=="780012017106"
replace sodium_100=399 	 if upc_id=="780012017106"

* fixing LINE BERRIES VIVO
replace energy_100=348 	 if upc_id=="780012016923"
replace fat_100=1.2	  	 if upc_id=="780012016923"
replace fat_sat_100=0.21  if upc_id=="780012016923"
replace sugar_100=8 	 if upc_id=="780012016923"
replace sodium_100=290 	 if upc_id=="780012016923"

* fixing MONO CHOC AND MONO ROLLS
replace energy_100=403 	 if upc_id=="780012016416"
replace fat_100=8.3	  	 if upc_id=="780012016416"
replace fat_sat_100=4.9  if upc_id=="780012016416"
replace sugar_100=30 	 if upc_id=="780012016416"
replace sodium_100=190 	 if upc_id=="780012016416"

replace energy_100=373 	 if upc_id=="780012016415"
replace fat_100=3.6	  	 if upc_id=="780012016415"
replace fat_sat_100=1.9  if upc_id=="780012016415"
replace sugar_100=22.1 	 if upc_id=="780012016415"
replace sodium_100=250 	 if upc_id=="780012016415"

* fixing LIDER CHOCOLATADO BOLSA CHICA
replace energy_100=332 	 if upc_id=="780263000357"
replace fat_100=3.9	  	 if upc_id=="780263000357"
replace fat_sat_100=1.5  if upc_id=="780263000357"
replace sugar_100=14.8 	 if upc_id=="780263000357"
replace sodium_100=470 	 if upc_id=="780263000357"

* fixing NESTLE FITNESS GRANOLA HONEY
replace energy_100=372 	 if upc_id=="761303575880"
replace fat_100=5.3	  	 if upc_id=="761303575880"
replace fat_sat_100=0.9  if upc_id=="761303575880"
replace sugar_100=21.1 	 if upc_id=="761303575880"
replace sodium_100=343 	 if upc_id=="761303575880"

* We verify that products with the same nutrition_id have the same nutritional info 

gen typo = 0

* We compute the nutritional information for products with the same nutrition_id. 
foreach var in energy sodium fat fat_sat sugar {
bys nutrition_id: egen mean_`var'_100 = mean(`var'_100) 
gen dif_`var' = abs(mean_`var'_100-`var'_100)
replace typo = 1 if dif_`var'>0.05 & dif_`var'!=.  // again we tag products where there is too much variance within nutritional information (products that are fat away to the mean). 
}

order portion_size energy_100 fat_100 fat_sat_100 sugar_100 sodium_100
*br if typo == 1

*look at figures of products with same nutrition_id and different nutritional info and check there were properly ditized. If not, fix it above. It yes, change nutrition_id.

* After checking typos, two products were changed: product_id=594019 and product_id=900987 // Nano unchanged them. Seem to be typos in the box. 

* Finally we compute the nutritional information of each nutrition_id with the mean of it. 

foreach var in energy sodium fat fat_sat sugar {
replace `var'_100 = mean_`var'_100
drop mean_`var'_100
drop dif_`var'
}

* In the following lines we define the labels depending on whether they are solids or liquids. 

foreach var in sug cal sod fat{
gen L`var'=.
gen H`var'=.
}

replace Lsug=1 if sugar_100   >   22.5 	& sugar_100!=. 										& portion_type == "g"
replace Lsug=0 if sugar_100   <=  22.5  & sugar_100!=. 										& portion_type == "g"
replace Lcal=1 if energy_100  >  350  	& energy_100!=. 									& portion_type == "g"
replace Lcal=0 if energy_100  <= 350  	& energy_100!=. 									& portion_type == "g"
replace Lfat=1 if fat_sat_100 > 6    	& fat_sat_100!=. 									& portion_type == "g"
replace Lfat=0 if (fat_sat_100 <=  6 | fat_100 <= 6 ) & ( fat_100!=. | fat_sat_100!=.) 		& portion_type == "g"
replace Lsod=1 if sodium_100  > 800   	& sodium_100!=. 									& portion_type == "g"
replace Lsod=0 if sodium_100  <=  800   & sodium_100!=. 									& portion_type == "g"


replace Lsug=1 if sugar_100   >   6 	& sugar_100!=. 										& portion_type == "ml"
replace Lsug=0 if sugar_100   <=  6		& sugar_100!=. 										& portion_type == "ml"
replace Lcal=1 if energy_100  >  100  	& energy_100!=. 									& portion_type == "ml"
replace Lcal=0 if energy_100  <= 100  	& energy_100!=. 									& portion_type == "ml"
replace Lfat=1 if fat_sat_100 > 3    	& fat_sat_100!=. 									& portion_type == "ml"
replace Lfat=0 if (fat_sat_100 <=  3 | fat_100 <= 3 ) & ( fat_100!=. | fat_sat_100!=.) 		& portion_type == "ml"
replace Lsod=1 if sodium_100  > 100   	& sodium_100!=. 									& portion_type == "ml"
replace Lsod=0 if sodium_100  <=  100   & sodium_100!=. 									& portion_type == "ml"

replace Hsug = 1 if label_sugar==1
replace Hsug = 0 if label_sugar==0
replace Hcal = 1 if label_energy==1
replace Hcal = 0 if label_energy==0
replace Hfat = 1 if label_fat==1
replace Hfat = 0 if label_fat==0
replace Hsod = 1 if label_sodium==1
replace Hsod = 0 if label_sodium==0

* FIX AVENAS
foreach var in sug cal sod fat{
replace L`var'=0 if inlist(name,"AVENA INSTANTANEA","AVENA TRADICIONAL", "AVENA QUINOA") & L`var'!=.
replace L`var'=0 if brand=="GO OATS-15404"   & L`var'!=. 
replace L`var'=0 if inlist(name,"AVENA MULTISEMILLAS MANZANA Y PASAS", "AVENA MULTISEMILLAS", "AVENA MULTISEMILLAS CHIA LINAZA", "AVENA 4 SEMILLAS + BERRIES", "AVENA 4 SEMILLAS")  & L`var'!=.
}

count if Lcal==1 & Hcal == 0
count if Lsod==1 & Hsod == 0
count if Lfat==1 & Hfat == 0
count if Lsug==1 & Hsug == 0

count if Lcal==0 & Hcal == 1
count if Lsod==0 & Hsod == 1
count if Lfat==0 & Hfat == 1
count if Lsug==0 & Hsug == 1

* PRODUCTS THAT ARE ALWAYS INCONSISTENT
* FITNESS

* PRODUCTS THAT ARE SOMETIMES INCONSISTENT
* CHOCAPIC

********************************************************************************
**			COMPLETE LABELS	& PORTION_TYPE									  **
********************************************************************************

bys nutrition_id: egen mode_type = mode(portion_type), max
replace portion_type = mode_type if portion_type==""

count if portion_type != mode_type

** In this section we compute whether products have labels or not according to the nutritional information.

foreach var in sug cal sod fat{
bys nutrition_id: egen meanL`var'= mean(L`var') 
replace L`var'=meanL`var' if L`var'==. & meanL`var'!=.
}

** We first calculate the mean within nutrition_id and check whether it is either 0 or 1. 
** We then compute the labels values for products that were originally not scanned.

foreach var in sug cal sod fat{
replace L`var'=meanL`var' if L`var'!=meanL`var' & L`var'!=. & meanL`var'!=.  
drop meanL`var'
}

gen scannedL =  (Lsug!=. & Lcal!=. & Lsod!=. & Lfat!=.) 

tab scanned // this are products for which we do have nutritional info. (report this number!)
*tab scanned [aw = sales_final] // here we check percentage of sales we have covered. (report this number!)
tab scannedL // this are products for which we do have nutritional info. (report this number!)
*tab scannedL [aw = sales_final] // here we check percentage of sales we have covered. (report this number!)

drop if dropbrand==1


** We rename variables

ren sugar_100 sug_100
ren energy_100 cal_100
ren sodium_100 sod_100
replace fat_sat_100 = fat_100 if  (fat_sat_100 == . & fat_100 < 6 & portion_type == "g") | (fat_sat_100 == . & fat_100 < 3 & portion_type == "ml")
drop fat_100
ren fat_sat_100 fat_100


/* Questions: 
- How to deal with packs? 
- How to deal with the fact that there are new products?
- What if different upc and different nutritional info, but same nutrition id?
	egen aux = max(cal_100), by(nutrition_id)
	g tag = 1 if aux != cal_100
*/


********************************************************************************
**			MERGE PRE-LAW NUTRITIONAL INFORMATION
********************************************************************************

global latest "04/01/2016" // Latest date for pre-law nutritional information

***** 1. INTA

preserve

** Load INTA data

use "${Repo}/00_files/01_source/02_nutrition/INTA_2015_17.dta", clear

** Change item_barcode in order to match with main dataset
replace item_barcode = 7613035469480 if n_product == "NESTLE, AVENA Y MAS FRUTAS GRANOLA,   B"

* fixing typos in data
replace per_calories = 362 if id_unico=="3020881"

** Choose relevant variables
keep item_barcode postdate per_calories per_sugars per_saturated_fat per_sodium

** Rename variables
ren per_calories cal_inta
ren per_saturated_fat fat_inta
ren per_sodium sod_inta
ren per_sugars sug_inta
ren postdate date_inta

tostring item_barcode, replace format(%20.0f) 

** Get rid of verification number
gen upc_id=substr(item_barcode,1,length(item_barcode)-1)
drop item_barcode

** Keep latest observation before the implementation of the policy (we might want to change this)
bys upc_id: egen temp = max(date_inta) if date_inta < date("$latest","MDY") & cal_inta !=.
drop if temp != date_inta
drop temp

duplicates drop upc_id, force

tempfile inta
save `inta', replace

restore

** Creat auxiliar upc_id in order to match it with the using dataset
g upc_id1 = upc_id
replace upc_id = "780221516889" if nutrition_id == "707553" // MONO BALLS - COSTA
replace upc_id = "780012016669" if nutrition_id == "707557" // MONO CHOC - COSTA
replace upc_id = "780400000146" if nutrition_id == "760960" // BOLITAS DE CHOCOLATE - EN LINEA
replace upc_id = "780261500204" if nutrition_id == "859634" // AVENA INSTANTANEA - SELECTA
replace upc_id = "780263500050" if nutrition_id == "279037" // MINI PILLOWS - COLA CAO
replace upc_id = "780263500045" if nutrition_id == "5187"   // PILLOWS - COLA CAO
replace upc_id = "780221516897" if nutrition_id == "381128"   // MONO ROLLS -COSTA
replace upc_id = "9433123835" if nutrition_id == "823726" // AVENA INSTANTANEA TRADICIONAL MIEL NUEZ - GRANVITA
replace upc_id = "750100806740" if nutrition_id == "289853" // CHOCO KRISPIS - KELLOGS
replace upc_id = "779330601303" if nutrition_id == "289891" // CHOCO ZUCARITAS - KELLOGS
replace upc_id = "789600400454" if nutrition_id == "659387" // CORN FLAKES - KELLOGS
replace upc_id = "789600400023" if nutrition_id == "2759" // CORN FLAKES - KELLOGS
replace upc_id = "780222065003" if nutrition_id == "2739" // INFLADOS ARROZ - NATUR
replace upc_id = "780222073853" if nutrition_id == "2743" // INFLADOS MAÍZ - NATUR
replace upc_id = "780222073852" if nutrition_id == "2747" // INFLADOS TRIGO - NATUR
replace upc_id = "761303467869" if nutrition_id == "910015" // CHOCAPIC - NESTLE
replace upc_id = "761303487494" if nutrition_id == "669271" // CHOCAPIC SABOR MANJAR - NESTLE
replace upc_id = "761303513037" if nutrition_id == "874678" // CORN FLAKES - NESTLE
replace upc_id = "761303176385" if nutrition_id == "3239" // ESTRELLITAS - NESTLE
replace upc_id = "761303491325" if nutrition_id == "282821" // FITNESS - NESTLE 
replace upc_id = "761303395767" if nutrition_id == "901218" // FITNESS FRUITS - NESTLE
replace upc_id = "761303395750" if nutrition_id == "901216" // FITNESS MIEL Y ALMENDRAS - NESTLE
replace upc_id = "761303395768" if nutrition_id == "915382" // FITNESS YOGURT - NESTLE
replace upc_id = "761303512028" if nutrition_id == "913552" // MILO - NESTLE
replace upc_id = "761303097960" if nutrition_id == "298641" // NESQUIK - NESTLE
replace upc_id = "761303097964" if nutrition_id == "898082" // TRIX - NESTLE
replace upc_id = "761303514578" if nutrition_id == "707185" // ZUCOSOS - NESTLE
replace upc_id = "780260013314" if nutrition_id == "2769" // AVENA INSTANTANEA - QUAKER
replace upc_id = "780200001050" if nutrition_id == "913856" // AVENA MULTISEMILLA - QUAKER
replace upc_id = "780260013106" if nutrition_id == "296899" // AVENA TRADICIONAL - QUAKER
replace upc_id = "780200000882" if nutrition_id == "903783" // QUADRITOS - QUAKER
replace upc_id = "780200000572" if nutrition_id == "770898" // QUADRITOS CANELA - QUAKER
replace upc_id = "780200001049" if nutrition_id == "903781" // HEARTS - QUAKER
replace upc_id = "780261500202" if nutrition_id == "859636" // SELECTA - AVENA TRADICIONAL
replace upc_id = "780261500311" if nutrition_id == "838198" // GRANOLA BAJO EN GRASAS - SELECTA
replace upc_id = "780261500310" if nutrition_id == "838200" // GRANOLA TRADICIONAL - SELECTA
replace upc_id = "780012017005" if nutrition_id == "838202" // AVENA 4 SEMILLAS - VIVO
replace upc_id = "780012017003" if nutrition_id == "826085" // AVENA CLUSTERS BERRIES - VIVO
replace upc_id = "780012016996" if nutrition_id == "849727" // AVENA INSTANTANEA - VIVO
replace upc_id = "780012016997" if nutrition_id == "503786" // BRUNCH FRUTOS ROJOS - VIVO
replace upc_id = "780012016385" if nutrition_id == "834055" // CHECK 3 CEREALES - VIVO
replace upc_id = "780012016386" if nutrition_id == "834057" // CHECK CACAO - VIVO
replace upc_id = "780012016674" if nutrition_id == "824652" // CHECK YOGHURT - VIVO
replace upc_id = "780012016591" if nutrition_id == "834063" // GRANOLA BERRIES - VIVO
replace upc_id = "780012016592" if nutrition_id == "834065" // GRANOLA MIEL & ALMENDRAS - VIVO


** Merge dataset
merge n:1 upc_id using  `inta' 
drop if _merge==2
drop _merge

replace upc_id = upc_id1
drop upc_id1

** Same nutritional info for all products within nutrition_id
foreach nut in cal sug sod fat {
	egen `nut'_aux = max(`nut'_inta), by(nutrition_id)
	replace `nut'_inta = `nut'_aux
	drop `nut'_aux
	format `nut'_inta %5.0g
}

** Same date for all products within the same nutrition_id
bys nutrition_id: egen temp = max(date_inta) 
replace date_inta = temp
drop temp



***** 2. NUTRITIONISTS DATASET (aka "other")

preserve

** Load data
use "${Repo}/00_files/01_source/02_nutrition/cereals_2015_other.dta", clear
drop if nutrition_id == ""
drop product brand

ren energy_other cal_other
ren fat_other fat_tot_other
ren fat_sat_other fat_other
ren sugar_other sug_other
ren sodium_other sod_other



tempfile other
save `other', replace

restore

** Merge data
merge n:1 nutrition_id using  `other'
drop _merge

***** 3. FATSECRET

preserve 

** Upload Josh's dataset
import delimited "${Repo}/00_files/01_source/02_nutrition/09369_cereals_nutrition_fatsecret.csv", clear

** Rename variables
ren grasasaturada fat_fs
ren calorías cal_fs
ren sodio sod_fs
ren azúcar sug_fs
ren serving portion

** Keep relevant variables
keep nutrition_id date portion date fat_fs cal_fs sod_fs sug_fs

* fix some variables:
* fix lider chocolatado
* fixing LIDER CHOCOLATADO BOLSA CHICA
replace portion = "30 g" if nutrition_id == 743410 & date == "25 abr. 11"
replace cal_fs="111 kcal" 	 if nutrition_id == 743410 & date == "25 abr. 11"
replace fat_fs="0,5 g"	  	 if nutrition_id == 743410 & date == "25 abr. 11"
replace sod_fs="46,8 mg" 	 if nutrition_id == 743410 & date == "25 abr. 11"
replace sug_fs="10,2 g" 	 if nutrition_id == 743410 & date == "25 abr. 11"

* deleting GRANOLA PASAS, MIEL Y ALMENDARAS
replace date = "" if nutrition_id == 905893 
replace portion = "" if nutrition_id == 905893 
replace cal_fs="" 	 if nutrition_id == 905893 
replace fat_fs=""	  	 if nutrition_id == 905893 
replace sod_fs="" 	 if nutrition_id == 905893 
replace sug_fs="" 	 if nutrition_id == 905893 



** Generate portions
replace portion = "100 g" if portion == "100g"
split portion, parse(" ")
replace portion = portion1
drop portion1 portion2
destring portion, replace dpcomma

** Get data for every 100 gr/ml 
foreach nut in cal sug sod fat {
	split `nut'_fs, parse(" ")
	replace `nut'_fs = `nut'_fs1
	drop `nut'_fs1 `nut'_fs2
	destring `nut'_fs, replace dpcomma
	replace `nut'_fs = (`nut'_fs/portion)*100
	format `nut'_fs %5.0g
}

drop portion

** Gen date variable for fatsecret data
split date, parse(" ")
destring date1 date3, replace

rename date1 day
rename date3 year
replace year = year+2000

g month = .
	replace month = 1 if date2 == "ene."
	replace month = 2 if date2 == "feb."
	replace month = 3 if date2 == "mar."
	replace month = 4 if date2 == "abr."
	replace month = 5 if date2 == "may."
	replace month = 6 if date2 == "jun."
	replace month = 7 if date2 == "jul."
	replace month = 8 if date2 == "ago."
	replace month = 9 if date2 == "sep."
	replace month = 10 if date2 == "oct."
	replace month = 11 if date2 == "nov."
	replace month = 12 if date2 == "dec."

g date_fs = mdy(month, day, year)
format date_fs %td
drop date date2 day year month

** Keep latest observation before the implementation of the policy
bys nutrition_id: egen temp1 = max(date_fs) if date_fs < date("$latest","MDY") & cal_fs !=.
format temp1 %td
drop if temp1 != date_fs
drop if date_fs == .
drop temp1

duplicates drop nutrition_id, force

tostring nutrition_id, replace

tempfile fat_secret
save `fat_secret', replace

restore

** Merge data
merge n:1 nutrition_id using  `fat_secret'
drop _merge

replace sug_inta = 25.5 if nutrition_id == "2595" // fixing GRANOLA MIEL Y PASAS manually using fatsecret data that matches Camila's (Camila's had a missing for sugar)


********************************************************************************
**			CREATE PRE POLICY NUTRITIONAL INFORMATION
********************************************************************************

// Order of priority of pre-law data: 1. INTA, 2. OTHER, 3. FATSECRET
// If doesn't show up in 1, 2 or 3, impute post policy information

** Rename variables
ren cal_100 cal_post
ren sug_100 sug_post
ren fat_100 fat_post
ren sod_100 sod_post

** Create pre-law nutritional info
g cal_pre = .
g sug_pre = .
g sod_pre = .
g fat_pre = .

** Sources of pre-law data
local source post fs other inta

** Source of pre-law data
local i = 0
g source_pre = .
foreach j in `source'{
	replace source_pre = `i' if cal_`j' !=. | sod_`j' !=.| sug_`j'!=.| fat_`j' !=.
	local i = `i'+ 1
	}

* Takes the information from the relevant source of pre-law data
local i = 0
foreach j in `source'{
	foreach nut in cal sug sod fat {
		replace `nut'_pre = `nut'_`j' if source_pre == `i'
	}
	local i = `i'+ 1
}

** Create pre-law nutritional info date
rename date_scan date_post
g date_pre = .
foreach j in `source'{
	replace date_pre = date_`j' if date_`j' != .
}

format date_* %td
recast2 float cal_* sug_* sod_* fat_*, force

lab def source_pre1 0 "post" 1 "fatsecret" 2 "other" 3 "inta"
lab values source_pre source_pre1



********************************************************************************
**			CREATE 2020 NUTRITIONAL INFORMATION
********************************************************************************

preserve
import delimited "${Repo}/00_files/01_source/02_nutrition/nutrition_cereals_2020.csv", encoding(UTF-8) clear
tostring nutrition_id, replace
tempfile temp_2020
save `temp_2020', replace
restore

merge n:1 nutrition_id using `temp_2020' 



********************************************************************************
**			SAVE RESULTS													  **
********************************************************************************

** We keep only relevant information and save the output.

order upc_id product_id nutrition_id name brand portion_type package type_unit sell_q scannedL Lcal Lsug Lsod Lfat Hcal Hsug Hsod Hfat cal_post cal_pre cal_late sug_post sug_pre sug_late sod_post sod_pre sod_late fat_post fat_pre fat_late source_pre date_*
keep  upc_id product_id nutrition_id name brand portion_type package type_unit sell_q scannedL Lcal Lsug Lsod Lfat Hcal Hsug Hsod Hfat cal_post cal_pre cal_late sug_post sug_pre sug_late sod_post sod_pre sod_late fat_post fat_pre fat_late source_pre date_* 

duplicates drop

save  "${Repo}/00_files/02_intermediate/02_nutrition/04_cereals_nutrition.dta", replace

