/*******************************************************************************
AUTHOR: Nano Barahona
CREATION: Jan-2020
ACTION: Cleans census data
SUMMARY:

********************************************************************************/

clear all
set more off
set scheme s1mono

******************************************************************************** 
** SET PATH AND LOCALS
******************************************************************************** 

if c(username)=="Nano"   		  global Repo "/Users/Nano/Dropbox/Research/FoodLabels/food_labels/04_replication"
else 							  global Repo "."

******************************************************************************** 
** LOAD DATA 
******************************************************************************** 


use "${Repo}/00_files/01_source/03_censo/POBLACION.DTA", clear

gen nhog=nhogp

drop p21b p22b p23b p25b p38b 

merge m:1 folio  nviv using "${Repo}/00_files/01_source/03_censo/VIVIENDA.DTA"  // agregar caracteristicas de los hogares
keep if _merge==3
drop _merge

merge m:1 folio  nviv nhog using "${Repo}/00_files/01_source/03_censo/HOGAR.DTA"  // agregar caracteristicas de los hogares
keep if _merge==3
drop _merge

merge m:1 folio  nviv using "${Repo}/00_files/01_source/03_censo/IDGEO.dta"
keep if _merge==3
drop _merge

merge m:1 com dto area zona mz using "${Repo}/00_files/01_source/03_censo/GEOCODE.DTA"
keep if _merge==3
drop _merge


merge m:1 region prov com  using "${Repo}/00_files/01_source/03_censo/DPA.DTA"
drop if area==2
drop _merge

// algunas manzanas no son reportadas en los datos micros debido a que tienen 5 o menos hogares (por secreto estadistico)
drop if mz>=999
replace mz=999 if mz==99999
replace localidad=999 if localidad==99999


// label variables
label var dpar "parentesco"
label var p19 "sexo"
label var p20c "edad"
label var p21a "nacionalidad"
label var p24 "pueblo_originario"
label var p27 "sabe_leer"
label var p28 "educacion"
label var p35 "estado_civil"
label var p36 "estado_laboral"

label var v01 "ocupacion_vivienda"
label var v02 "tipo_vivienda"
label var v03a "material_paredes"
label var v03b "material_techo"
label var v03c "material_piso"
label var v04 "dormitorios"
label var v05 "origen_agua"
label var v06 "alcantarilla"
label var v07 "electricidad"
label var v08 "eliminacion_basura"

label var h11 "propiedad_vivienda"
label var h13a "telefono"
label var h13b "auto"
label var h13c "servicio_domestico"
label var h13d "internet"
label var h14 "dormitorios"



egen most_educated = max(p28), by(folio  nviv nhog)
gen temp = p28 if dpar==1 
egen education_head = max(temp), by(folio  nviv nhog)
drop temp
egen literate = min(p27), by(folio  nviv nhog)
gen numero_personas = 1


collapse (sum) numero_personas (mean) most_educated education_head literate v01 v02 v03a v03b v03c v04 v05 v06 v07 v08 h11 h13a h13b h13c h13d h14 region prov com dto area zona mz localidad entidad sector block_x block_y totm , by(folio  nviv nhog)


* total quantities
gen n_individuals = numero_personas
gen n_households = 1
gen n_house_single = (v02==1)
gen n_house_paired = (v02==2)
gen n_house_building = (v02==3 | v02==4)
gen n_house_other = (v02>4)
gen n_walls_hormigon = (v03a==1)
gen n_walls_cemento = (v03a==2)
gen n_walls_madera_otros = (v03a>2)
gen n_roof_great = (v03b<=2)
gen n_roof_ok = (v03b>2)
gen n_piso_great = (v03c==1)
gen n_piso_good = (v03c==2)
gen n_piso_ok = (v03c==3)
gen n_piso_bad = (v03c>3)
gen n_water_system = (v05==1)
gen n_wc_system = (v06==1)
gen n_electricity_system = (v07==1)
gen n_garbage_system = (v08==1)
gen n_own_house = (h11<=2)
gen n_rented_house = (h11==3 | h11==4)
gen n_borrowed_house = (h11>4)
gen n_phone = (h13a==1)
gen n_car = (h13b==1)
gen n_domestic_service = (h13c==1)
gen n_internet = (h13d==1)
gen n_literate = (literate == 1)
gen n_highschool = (most_educated<=7)
gen n_technical_third = (most_educated==8)
gen n_college = (most_educated==9)
gen n_gradschool = (most_educated>9)
gen n_head_elementary = (education_head<=5)
gen n_head_highschool = (education_head==7 | education_head==6)
gen n_head_technical_third = (education_head==8)
gen n_head_college = (education_head==9)
gen n_head_gradschool = (education_head>9)


* average quantities
gen av_individuals_perhousehold = n_individuals
gen av_dormitorios_percapita = (h14/numero_personas) if h14<99


collapse (sum) n_* (mean) av_* (first) block_x block_y, by(region prov com dto area zona mz ) 


save "${Repo}/00_files/02_intermediate/03_consumers/temp/census_manzana.dta", replace


use "${Repo}/00_files/01_source/04_casen/casen2011stata_06092012.dta", clear


collapse (mean) ytothaj [aw=expc_r2] , by(comuna)
ren ytothaj income
replace income = income/800
tempfile temp
save `temp', replace

use "${Repo}/00_files/02_intermediate/03_consumers/temp/census_manzana.dta", clear

collapse (sum) n_* (mean) av_* , by(com) 


global shares house_single house_paired house_building house_other walls_hormigon walls_cemento walls_madera_otros roof_great roof_ok piso_great piso_good ///
piso_ok piso_bad water_system wc_system electricity_system garbage_system own_house rented_house borrowed_house phone car domestic_service internet literate highschool ///
technical_third college gradschool head_elementary head_highschool head_technical_third head_college head_gradschool 


foreach var in $shares {
gen sh_`var' = n_`var'/n_households
}

ren com comuna

merge 1:1 comuna using `temp'
keep if _merge==3

lasso linear income sh_* av* 
predict yhat


use "${Repo}/00_files/02_intermediate/03_consumers/temp/census_manzana.dta", clear

global shares house_single house_paired house_building house_other walls_hormigon walls_cemento walls_madera_otros roof_great roof_ok piso_great piso_good ///
piso_ok piso_bad water_system wc_system electricity_system garbage_system own_house rented_house borrowed_house phone car domestic_service internet literate highschool ///
technical_third college gradschool head_elementary head_highschool head_technical_third head_college head_gradschool 


foreach var in $shares {
gen sh_`var' = n_`var'/n_households
}

predict yhat

egen yrank = rank(yhat)
egen maxrank = max(yrank)
replace yrank = yrank/maxrank

ren com comuna
merge m:1 comuna using `temp'


order block_x block_y yrank
keep block_x block_y yrank

drop if block_x <-100 | block_x == .


ren block_x lon_direc 
ren block_y lat_direc

save "${Repo}/00_files/02_intermediate/03_consumers/temp/censusgeocode2income.dta", replace

export delimited using "${Repo}/00_files/02_intermediate/03_consumers/temp/censusgeocode2income.csv", novarnames replace
