/*******************************************************************************
AUTHOR: Cris Otero
CREATION: Feb-17
ACTION: Geocode distance to Supermarket
********************************************************************************/

clear all
set more off
set scheme s1mono

******************************************************************************** 
** SET PATH AND LOCALS
******************************************************************************** 

if c(username)=="Nano"   		  global Repo "/Users/Nano/Dropbox/Research/FoodLabels/food_labels/04_replication"
else 							  global Repo "."


*** Info of location of stores

* geo coordinates of stores
import excel "${Repo}/00_files/01_source/01_walmart/Informacion Locales.xlsx", sheet("Hoja1") firstrow clear
ren Store_Nbr store_id
merge 1:1 store_id using "${Repo}/00_files/01_source/01_walmart/locales_comunas.dta"
drop if _merge==2

*tostring store_id, replace
keep store_id latitud longitud nom_comuna
drop if latitud == "NULL" | latitud == "0.0000000" // check this

g aux1 = substr(latitud,1,3)
g aux2 = substr(latitud,4,7)
g lat_walmart = aux1 + "." + aux2
destring lat_walmart, replace

g aux3 = substr(longitud,1,3)
g aux4 = substr(longitud,4,7)
g lon_walmart = aux3 + "." + aux4
destring lon_walmart, replace

ren nom_comuna comuna_walmart

drop aux* latitud longitud

tempfile store_info
save `store_info', replace


*** Panel data

use "${Repo}/00_files/02_intermediate/01_panel/MasterConsumerPanelData_Cereals.dta", clear

drop upc_id trx_id sales_raw discount_amt sales_final quantity quant_weight week category week8

/* 
* Total sales by individual by store by day
* (includes only cereals?)
destring sales_final, replace
bys rut_doc store_id day: egen sales_day = total(sales_final)
*/

* Keep one observation per individual-store-day
duplicates drop rut_doc store_id day, force

* # of days an individual visits a store
bys rut_doc: egen aux1 = total(1)
bys rut_doc store_id: egen aux2 = total(1)
bys rut_doc: egen aux3 = max(aux2)
gen share_mode = aux3/aux1


* Identify and keep only most visited store by individual
keep if aux2 == aux3
duplicates drop rut_doc store_id, force

* Flag cases where mode = 1
g flag = 1 if aux3 == 1
replace flag = 0 if aux3 != 1

* Drop cases with more than one mode
duplicates drop rut_doc, force

keep rut_doc store_id flag share_mode
ren rut_doc rut
destring rut, replace
drop if rut == 0

** Merge store info
merge m:1 store_id using `store_info'
keep if _merge != 2
drop _merge

sort rut
duplicates drop

** Geolocation of address
preserve
	import delimited "${Repo}/00_files/01_source/01_walmart/direccion_georeferenciada.csv", encoding(UTF-8) clear

	ren lat lat_direc 
	ren lon lon_direc

	tempfile direc_location
	save `direc_location', replace
restore

** Merge direc location
merge 1:m rut using `direc_location'
keep if _merge == 3
drop _merge

geodist lat_direc lon_direc lat_walmart lon_walmart, gen(dist_walmart_direc)

order rut lat_direc lon_direc name gender fulladdress formataddress id store_id comuna_walmart lat_walmart lon_walmart flag share_mode dist_walmart_direc

** Prepare data to merge to Censo
bys rut (lat_direc lon_direc): gen repeated_rut = _n
save "${Repo}/00_files/02_intermediate/03_consumers/temp/consumerpanel_direc.dta", replace

keep rut lat_direc lon_direc repeated_rut

export delimited using "${Repo}/00_files/02_intermediate/03_consumers/temp/consumerpanel_direc.csv", novarnames replace


