/*******************************************************************************
AUTHOR: Cris Otero
CREATION: Feb-17
ACTION: Geocode distance to Supermarket
********************************************************************************/

clear all
set more off
set scheme s1mono

******************************************************************************** 
** SET PATH AND LOCALS
******************************************************************************** 

if c(username)=="Nano"   		  global Repo "/Users/Nano/Dropbox/Research/FoodLabels/food_labels/04_replication"
else 							  global Repo "."



** Merge data to census location and income estimation
import delimited using "${Repo}/00_files/02_intermediate/03_consumers/temp/consumerpanel_direc_censo.csv", encoding(UTF-8) clear
keep rut lat_censo lon_censo income repeated_rut
duplicates drop
tempfile censo_location
save `censo_location', replace 

use "${Repo}/00_files/02_intermediate/03_consumers/temp/consumerpanel_direc.dta", clear
merge 1:1 rut repeated_rut using `censo_location'
drop _merge

geodist lat_direc lon_direc lat_censo lon_censo, gen(dist_census_direc)


** Keep address closest to walmart
gen census_toofar = (dist_census_direc > 15)
gen walmart_toofar = (dist_walmart_direc > 30)
bys rut (dist_walmart_direc dist_census_direc): gen closest = (_n==1)
keep if closest == 1

** Calculate age 
gen date1=rut*3.34/1000000+1932.26
replace date1=ceil(date1)
gen age = 2017-date1

** Dummy for gender
gen female = (gender=="MUJ")

** Create bins
egen income_bins = cut(income), group(6)
replace income_bins = income_bins+1
egen age_bins = cut(age), group(6)
replace age_bins = age_bins+1
replace female = female+1

** Save data 
ren rut rut_doc
keep rut_doc age age_bins female income income_bins dist_walmart_direc dist_census_direc census_toofar walmart_toofar lat_direc lon_direc
order rut_doc age age_bins female income income_bins dist_walmart_direc dist_census_direc census_toofar walmart_toofar 


save "${Repo}/00_files/02_intermediate/03_consumers/consumer_characteristics.dta", replace


cap rm "${Repo}/00_files/02_intermediate/03_consumers/temp/census_manzana.dta"
cap rm "${Repo}/00_files/02_intermediate/03_consumers/temp/censusgeocode2income.csv"
cap rm "${Repo}/00_files/02_intermediate/03_consumers/temp/censusgeocode2income.dta"
cap rm "${Repo}/00_files/02_intermediate/03_consumers/temp/consumerpanel_direc_censo.csv"
cap rm "${Repo}/00_files/02_intermediate/03_consumers/temp/consumerpanel_direc.csv"
cap rm "${Repo}/00_files/02_intermediate/03_consumers/temp/consumerpanel_direc.dta"


