/*******************************************************************************
AUTHOR: Nano Barahona
CREATION: Aug-2019
ACTION: Clean beliefs answers from survey
SUMMARY:

********************************************************************************/

*********************************************************************************************************
clear all
set more off
*set scheme s1mono
set scheme s1color

if c(username)=="Nano"   		  global Repo "/Users/Nano/Dropbox/Research/FoodLabels/food_labels/04_replication"
else 							  global Repo "."

*********************************************************************************************************
*** LOAD DATA																	   					 ****
*********************************************************************************************************

import delimited "${Repo}/00_files/01_source/05_beliefs/beliefs_final.csv", delimiter(comma) varnames(1) encoding(utf8) clear 

drop if _n<=2

keep if m1=="1"


*********************************************************************************************************
*** ORDER OF QUESTIONS															   					 ****
*********************************************************************************************************

gen block1 = ""
gen block2 = ""

local varlist1 = "FL_330 FL_332 FL_612 FL_854 FL_1096 FL_1300 FL_1504"
local varlist2 = "fl_25_do fl_333_do fl_613_do fl_855_do fl_1097_do fl_1301_do fl_1505_do"

forv j = 1/7 {
	local var1 = word("`varlist1'", `j')
	local var2 = word("`varlist2'", `j')
	cap split `var2', parse("|") gen(temp)
	forv i=1/2 {
		cap replace block`i' = temp`i' if fl_331_do == "`var1'"
		cap drop temp`i'
	}
}


gen Part1 = ""
gen Part2 = ""

local varlist1 = "FL_29 FL_30 FL_31 FL_32 FL_334 FL_435 FL_536 FL_715 FL_816 FL_856 FL_957 FL_1098 FL_1199 FL_1302 FL_1403 FL_1506 FL_1607"
local varlist2 = "fl_26_do fl_27_do fl_57_do fl_61_do fl_336_do fl_437_do fl_538_do fl_717_do fl_818_do fl_858_do fl_959_do fl_1100_do fl_1201_do fl_1304_do fl_1405_do fl_1508_do fl_1609_do"

forv i=1/2 {
forv j = 1/17 {
	local var1 = word("`varlist1'", `j')
	local var2 = word("`varlist2'", `j')
	replace Part`i' = `var2' if block`i' == "`var1'"
}
}

drop block*

*********************************************************************************************************
*** RESHAPE DATA																   					 ****
*********************************************************************************************************

keep durationinseconds locationlatitude locationlongitude responseid p* t* m* f* Part* x* y*
drop fl*

ren durationinseconds duration
ren locationlatitude latitude
ren locationlongitude longitude
ren responseid id

forv i=1/100 {
	if `i'<10 {
		local question = "00"+"`i'"
	}
	else if `i'<100 {
		local question = "0"+"`i'"
	}
	else {
		local question = "`i'"
	}
	foreach bloque in "a" "b" "c" "d" "e" {
		forv j=2/3 {
			cap ren p`j'_`bloque'`question'_1 p`j'_`bloque'`question'
		}
		foreach post in "firstclick" "lastclick" "pagesubmit" "clickcount" {
			cap ren t_`bloque'`question'_`post' `post'_`bloque'`question'
		}
	}
	
}


order id duration latitude longitude finished progress

reshape long p1_a p2_a p3_a p1_b p2_b p3_b firstclick_b lastclick_b pagesubmit_b clickcount_b ///
p1_c p2_c p3_c firstclick_c lastclick_c pagesubmit_c clickcount_c ///
p1_d p2_d p3_d firstclick_d lastclick_d pagesubmit_d clickcount_d ///
p1_e p2_e p3_e firstclick_e lastclick_e pagesubmit_e clickcount_e ///
 , i(id) j(product,s)

reshape long p1_ p2_ p3_ firstclick_ lastclick_ pagesubmit_ clickcount_ , i(id product) j(block,s)

ren m1 agreement
ren m2 understand
ren f1 instruction_comments
ren f2 comments
ren p1_ known
ren p2_ expected
ren p3_ probability
ren firstclick_ click1
ren lastclick_ click2
ren pagesubmit_ time
ren clickcount_ nclicks

order known expected probability time agreement understand comments instruction_comments nclicks click1 click2, last

foreach var in product duration latitude longitude known expected probability time agreement understand nclicks click1 click2 {
	destring `var', replace
}

drop if known==. 
 
compress
 
drop finished progress
drop click1 click2 nclicks


replace block = upper(block)
tostring product, gen(temp)
gen question = ""
replace question = block + "00" + temp if product<10
replace question = block + "0" + temp if product>=10 & product<100
replace question = block + temp if product>=100
drop temp


*********************************************************************************************************
*** ORDER OF QUESTIONS															   					 ****
*********************************************************************************************************

gen position = .
forv j=1/2 {
split Part`j', parse("|") gen(temp)
forv i = 1/10 {
replace temp`i' = substr(temp`i',1,4)
replace position = 10*(`j'-1)+`i' if question==temp`i'
}
drop temp*
}
drop Part*



*********************************************************************************************************
*** RESPONDANT CHARACTERISTICS													   					 ****
*********************************************************************************************************

ren x001 gender
ren x002 age
ren x003 income
ren y001 buy_cereal
ren y002_1 val_price
ren y002_2 val_brand
ren y002_3 val_health
ren y002_4 val_taste
destring gender, replace
destring age, replace
destring income, replace
destring buy_cereal, replace
destring val_price, replace
destring val_brand, replace
destring val_health, replace
destring val_taste, replace

lab def genderlab 1 "Female" 2 "Male" 3 "Other"
lab def agelab 1 "10-18" 2 "18-24" 3 "25-34" 4 "35-44" 5 "45-54" 6 "55-64" 7 "65+"
lab def incomelab 1 "0-125k" 2 "125k-195k" 3 "195k-235k" 4 "235k-280k" 5 "280k-340k" 6 "340k-415k" 7 "415k-510k" 8 "510k-625k" 9 "625k-850k" 10 "850k+"
lab def buylab 1 "every month" 2 "few times a year" 3 "almost never"


lab value gender genderlab
lab value age agelab
lab value income incomelab
lab value buy_cereal buylab

replace duration = duration/60

gen latBA = -34.608
gen lonBA = -58.371
gen latLP = -34.921
gen lonLP = -57.954


geodist latBA lonBA latitude longitude , gen(distance_BA)

gen city = (distance_BA<1.5)+2*(distance_BA>=1.5 & distance_BA<55)+3*(distance_BA>=55)
lab def BAlab 1 "Buenos Aires city" 2 "Buenos Aires provincia" 3 "Other"
lab value city BAlab


order id question product block duration latitude longitude gender age distance_BA city income buy_cereal val_* known expected probability position time agreement understand comments instruction_comments

keep id question product block duration latitude longitude gender age distance_BA city income buy_cereal val_* known expected probability position time agreement understand comments instruction_comments


*********************************************************************************************************
*** MERGE TO TRUE VALUES														   					 ****
*********************************************************************************************************

preserve

import excel "${Repo}/00_files/01_source/05_beliefs/products_cereals.xlsx", sheet("Sheet1") firstrow allstring clear
keep num nutrition_id name brand_name
destring num, replace
drop if num==.
ren num product
expand 2, generate(temp)
gen block = ""
replace block="B" if temp==0
replace block="C" if temp==1
drop temp
tempfile tempcereal
save `tempcereal', replace

restore

merge n:1 product block using `tempcereal' , update
drop if _merge==2
drop _merge

preserve

use "${Repo}/00_files/02_intermediate/02_nutrition/04_cereals_nutrition.dta", clear
keep nutrition_id cal_post cal_pre sug_post sug_pre Lcal Lsug
duplicates drop
save `tempcereal', replace

restore

merge n:1 nutrition_id using `tempcereal' , update
drop if _merge==2
drop _merge

gen truth = 30 if block=="A"
replace truth = sug_pre if block=="B" | block=="D"
replace truth = cal_pre if block=="C" | block=="E"
gen truth_post = 30 if block=="A"
replace truth_post = sug_post if block=="B" | block=="D"
replace truth_post = cal_post if block=="C" | block=="E"
gen label = 1 if block=="A"
replace label = Lsug if block=="B" | block=="D"
replace label = Lcal if block=="C" | block=="E"
 
 
*********************************************************************************************************
*** MERGE TO FINELINE															   					 ****
*********************************************************************************************************

do "${Repo}/02_build/02_model/aux/01_new_fineline.do"
drop if _merge==2
drop _merge

ren new_fineline fineline

*********************************************************************************************************
*** SAVE INDIVIDUAL DATA														   					 ****
*********************************************************************************************************

order id nutrition_id name brand_name fineline question product block duration latitude longitude gender age distance_BA city income buy_cereal val_* known expected  truth truth_post probability label Lcal Lsug position time agreement understand comments instruction_comments

keep id nutrition_id name brand_name fineline question product block duration latitude longitude gender age distance_BA city income buy_cereal val_* known expected truth truth_post probability label Lcal Lsug position time agreement understand comments instruction_comments

save "${Repo}/00_files/02_intermediate/04_beliefs/01_individualBeliefs.dta", replace


*********************************************************************************************************
*** COLLAPSE TO PRODUCT LEVEL													   					 ****
*********************************************************************************************************

use "${Repo}/00_files/02_intermediate/04_beliefs/01_individualBeliefs.dta", clear

drop if known==-99 | expected==-99 | probability==-99


gen observations = 1

gen right = 0
replace right = 100 if abs(expected-truth)/5 < 1 & block=="B"
replace right = 100 if abs(expected-truth)/15 < 1 & block=="C"
replace right = 100 if abs(expected-truth)/2 < 1 & block=="D"
replace right = 100 if abs(expected-truth)/10 < 1 & block=="E"

*** clean outliers ****
gen errorabs = abs(expected-truth)
egen belief = mean(expected), by(question)
gen errorbelief = abs(expected-belief)
egen av_error = mean(errorbelief), by(id block)
foreach bloque in "B" "C" "D" "E" {
_pctile av_error if block=="`bloque'", p(95)
local p_cut = r(r1)
gen temp`bloque' = (av_error>=`p_cut') & block == "`bloque'"
egen is`bloque' = max(block=="`bloque'"), by(id)
egen outlier`bloque' = max(temp`bloque'), by(id)
replace outlier`bloque'=. if is`bloque'==0
}

drop if outlierB==1 | outlierC==1 | outlierD==1

***********************


cap tempfile cleanedData
save `cleanedData', replace


collapse (mean) known expected truth truth_post probability right time label (first) nutrition_id name brand_name product block fineline (semean) expectedSE = expected (sum) observations  , by(question)


ren known known_
ren expected mu_
ren expectedSE muse_
ren probability p_
ren right tp_
ren time time_
ren label l_
ren observations obs_
ren truth w_
ren truth_post w_post_

drop question 

preserve
* cereals
keep if block=="B" | block=="C"
replace block = "sug" if block=="B"
replace block = "cal" if block=="C"
reshape wide w_ w_post_ mu_ p_ tp_ known_ time_ muse_ l_ obs_ , i(product) j(block) string
drop product
order nutrition_id name brand_name fineline
gen sigma_sug = -5/invnormal((1-p_sug/100)/2)  // sigma = -x/inv_phi((1-p)/2)
gen sigma_cal = -15/invnormal((1-p_cal/100)/2)
save "${Repo}/00_files/02_intermediate/04_beliefs/02_cereals_beliefs_final.dta", replace
restore


*********************************************************************************************************
*** COLLAPSE DATA FOR MODEL SPLITTING BY INCOME GROUP							   					 ****
*********************************************************************************************************

use `cleanedData', clear

egen mu_homo_ = mean(expected), by(question)
egen mu_homo_sd_ = sd(expected), by(question)
egen obs_homo_ = total(1), by(question)
egen p_homo_ = mean(probability), by(question)

* define bins
gen income_bins = .
replace income_bins = 1 if inlist(income,1,2,3,4,5)
replace income_bins = 2 if inlist(income,6,7,8,9,10)

gen age_bins = .
replace age_bins = 1 if inlist(age,2,3,4)
replace age_bins = 2 if inlist(age,5,6,7)

drop if income_bins==.

collapse (mean) expected probability (first) nutrition_id name brand_name product block fineline (sum) observations (first) mu_homo_ mu_homo_sd_ obs_homo_  p_homo_ (sd) mu_sd_ = expected , by(income_bins question)

ren expected mu_
ren probability p_
ren observations obs_

gen mu_bayes_ = ((mu_homo_ * obs_homo) /(mu_homo_sd_^2) + (mu_ * obs_) /(mu_sd_^2))/(obs_homo/(mu_homo_sd_^2)+obs_/(mu_sd_^2))

drop question mu_homo_sd_ mu_sd_

preserve
* cereals
keep if block=="B" | block=="C"
replace block = "sug" if block=="B"
replace block = "cal" if block=="C"
reshape wide mu_ p_ obs_ mu_homo_ obs_homo_  p_homo_ mu_bayes_ , i(product income_bins) j(block) string
drop product
order nutrition_id name brand_name fineline
gen sigma_sug = -5/invnormal((1-p_sug/100)/2)  // sigma = -x/inv_phi((1-p)/2)
gen sigma_cal = -15/invnormal((1-p_cal/100)/2)
gen sigma_homo_sug = -5/invnormal((1-p_homo_sug/100)/2)  // sigma = -x/inv_phi((1-p)/2)
gen sigma_homo_cal = -15/invnormal((1-p_homo_cal/100)/2)
keep nutrition_id income_bins mu_cal mu_sug sigma_sug sigma_cal obs_cal obs_sug p_sug p_cal mu_homo_sug mu_homo_cal mu_bayes_sug mu_bayes_cal sigma_homo_sug sigma_homo_cal
save "${Repo}/00_files/02_intermediate/04_beliefs/03_cereals_beliefs_model_income.dta", replace
restore


