/*******************************************************************************
AUTHOR: Nano Barahona
CREATION: Feb-2020
ACTION: Clean advertising data
SUMMARY:

********************************************************************************/

clear all
set more off
set scheme s1mono

******************************************************************************** 
** SET PATH AND LOCALS
******************************************************************************** 

if c(username)=="Nano"   		  global Repo "/Users/Nano/Dropbox/Research/FoodLabels/food_labels/04_replication"
else 							  global Repo "."

******************************************************************************** 
** LOAD DATA AND MERGE SCANNED AND STORE DATA
******************************************************************************** 

** clean data 2016 **

import excel "${Repo}/00_files/01_source/06_advertising/2016-2017 BREAKFAST CEREALS.xlsx", sheet("BREAKFAST CEREALS 2016") firstrow clear

keep f_idspot Hora Dur fecha_emision_publicidad nombre_canal univers_rate f_nombre hora_inicio_spot hora_termino_spot f_extranjera producto_marca_1REV producto_marca producto_marca_1REV2_PROD producto_marca_1REV2_1_PROD producto_marca_1REV2_2_PROD producto_marca_1REV2_3_PROD producto_marca_2REV_PROD producto_marca_2_1REV_PROD producto_marca_2_2REV_PROD


drop producto_marca_1REV2_3_PROD producto_marca_2REV_PROD producto_marca_2_1REV_PROD producto_marca_2_2REV_PROD

ren producto_marca_1REV prod1 
ren producto_marca prod2 
ren producto_marca_1REV2_PROD prod3
ren producto_marca_1REV2_1_PROD prod4
ren producto_marca_1REV2_2_PROD prod5

reshape long prod , i(f_idspot) j(product_number)
ren prod product_name

drop if product_name == ""
drop if product_name == "Agua mineral Pure life de Nestlé"
drop if product_name == "Agua nestlé Pure Life"
drop if product_name == "Agua svelty nestle"
drop if product_name == "Barra de cereal de frutilla Quaker"
drop if product_name == "Bombones Bon o bon negro"
drop if product_name == "Bon o bon negro"
drop if product_name == "Café Nescafé de Nestlé"
drop if product_name == "Caldos Maggi de Nestlé"
drop if product_name == "Chocolate Sahnenuss, Nestle"
drop if product_name == "Helado tres sabores casata 1 litro Ne"
drop if product_name == "Helado tres sabores casata 1 litro Nestlé"
drop if product_name == "Productos de avena grano entero Quaker (barra"
drop if product_name == "Súper 8 nestlé"
drop if product_name == "Yogurth semidescremado con Chocapic"
drop if product_name == "Yogurth semidescremado con Chocapic de N"
drop if product_name == "aceite santa isabel"
drop if product_name == "barra de cereal frutilla quaker"
drop if product_name == "barra de cereal quaker"
drop if product_name == "barras de cereal frutilla quaker"
drop if product_name == "barras de cereal quaker"
drop if product_name == "chocolate sanhe nuss nestle"
drop if product_name == "galletas de manzana quaker"
drop if product_name == "galletas manzana quaker"
drop if product_name == "chocolate sahne nuss nestle"

sort product_name

gen nutrition_id1 = ""

replace nutrition_id1 = "913856" if inlist(product_name,"Avena Multisemillas Quaker","Avena multisemillas Quaker","Avena multisemillas de quaker","avena multisemillas quaker","avena mutisemillas quaker")
replace nutrition_id1 = "296899" if inlist(product_name,"Avena de grano entero Quaker","Productos de avena grano entero Quake","avena grano entero quaker")
replace nutrition_id1 = "2769" if product_name == "Avena instantánea quaker"
replace nutrition_id1 = "282821" if inlist(product_name,"Caja de Cereal Fitness de Nestle","Caja de cereal Fitness de Nestle")
replace nutrition_id1 = "913552" if inlist(product_name,"Caja de Cereal Milo de Nestle","Cereal Milo de Nestlé")
replace nutrition_id1 = "298641" if inlist(product_name,"Caja de Cereal nesquik","Caja de cereal nesquik")
replace nutrition_id1 = "910015" if product_name == "Caja de Chocapic Nestle"
replace nutrition_id1 = "765043" if inlist(product_name,"Cereal Nestle Avena y más Grano","Cereal Nestlé con grano integra")
replace nutrition_id1 = "903783" if inlist(product_name,"Cereal Quadritos de Quaker","Cereales Quadritos Quaker")
replace nutrition_id1 = "898082" if inlist(product_name,"Cereal Trix de nestlé","Cereal trix")
replace nutrition_id1 = "770904" if inlist(product_name,"Granola quaker","granola quaker")

ren nutrition_id1 nutrition_id 

keep if inlist(nombre_canal,"Canal 13","Chv","Mega","TNac") 

replace hora_inicio_spot = itrim(hora_inicio_spot)
split hora_inicio_spot, gen(inicio)
split inicio1, gen(init_time) parse(":")

replace hora_termino_spot = itrim(hora_termino_spot)
split hora_termino_spot, gen(final)
split final1, gen(finish_time) parse(":")

forv i=1/3 {
	destring finish_time`i', replace
	destring init_time`i', replace
}

replace finish_time1 = finish_time1+12 if final2=="PM" & finish_time1!=12
replace finish_time1 = finish_time1-12 if final2=="AM" & finish_time1==12
gen finish_time = 60*60*finish_time1 + 60*finish_time2 + finish_time3

replace init_time1 = init_time1+12 if inicio2=="PM" & init_time1!=12
replace init_time1 = init_time1-12 if inicio2=="AM" & init_time1==12
gen init_time = 60*60*init_time1 + 60*init_time2 + init_time3

gen length = finish_time-init_time
egen unique_ad_product = tag(f_idspot nutrition_id)
keep if unique_ad_product == 1
egen prods_per_add = total(1), by(f_idspot)
gen length_per_prod = length/prods_per_ad
gen ads_per_prod = 1/prods_per_add
ren unique_ad_product total_ads
gen length_rating = length_per_prod*univers_rate

collapse (sum) total_ads ads_per_prod length_per_prod length length_rating , by(nutrition_id)

gen post = 0

tempfile tv_ads_2016
save `tv_ads_2016', replace


** clean data 2016 **

import excel "${Repo}/00_files/01_source/06_advertising/2016-2017 BREAKFAST CEREALS.xlsx", sheet("BREAKFAST CEREALS 2017") firstrow clear

keep f_idspot fecha_emision_publicidad nombre_canal univers_rate f_nombre hora_inicio_spot hora_termino_spot f_promalim1 f_marca1 f_nombre1 f_denom1 f_sabor1 f_promalim2 f_marca2 f_nombre2 f_denom2 f_sabor2 f_promalim3 f_marca3 f_nombre3 f_denom3 f_sabor3 f_promalim4 f_marca4 f_nombre4 f_denom4 f_sabor4 f_promalim5 f_marca5 f_nombre5 f_denom5 f_sabor5

forv i = 1/5 {
	gen prod`i' = f_marca`i' + "-" + f_nombre`i' + "-" + f_sabor`i'
}

reshape long prod , i(f_idspot) j(product_number)
ren prod product_name

drop if product_name == "0-0-0"
drop if product_name == "Quaker-Barra de cereal-frutilla"
drop if product_name == "Quaker-Barra de granola-Sabor frutilla"
drop if product_name == "Quaker-Barras colacion-de frutilla"
drop if product_name == "Quaker-Cereal-Barras colacion"
drop if product_name == "Quaker-Galletas con frutas rellenas con yogurt-Sabor frutilla"
drop if product_name == "Quaker-barra de cereal-frutilla"
drop if product_name == "Quaker-barra de colacion-0"
drop if product_name == "Quaker-barras colacion-0"
drop if product_name == "Quaker-barras de cereal-0"
drop if product_name == "Quaker-barras de cereal-frutilla"
drop if product_name == "Quaker-barras de colacion-0"
drop if product_name == "Quaker-barras de granola-0"
drop if product_name == "Quaker-mini galletas-0"
drop if product_name == "Supremo-Te-Celyan premium"
drop if product_name == "Supremo-Te-Ceylan canela"
drop if product_name == "Supremo-Te-Ceylan oro"
drop if product_name == "Supremo-Te-Ceylan premium"
drop if product_name == "Supremo-Te-Rojo"
drop if product_name == "Supremo-Té-0"
drop if product_name == "Supremo-Té-Ceylán canela"
drop if product_name == "Supremo-Té-Línea premium"
drop if product_name == "quaker-galletas con frutas rellenas con yogurt-vainilla"
drop if product_name == "quaker-galletas con frutas rellenas con yogurt-frutilla"
drop if product_name == "Quaker-Barra de Cereal-Frutilla"
drop if product_name == "Quaker-Galletas con frutas rellenas con yogurt-Sabor vainilla"
drop if product_name == "quaker-galletas con frutas y rellenas con yogurt-frutilla"
drop if product_name == "quaker-galletas con frutas y rellenas con yogurt-vainilla"
drop if product_name == ""
drop if product_name == ""
drop if product_name == ""
drop if product_name == ""
drop if product_name == ""

sort product_name
gen nutrition_id1 = ""

replace nutrition_id1 = "765041" if inlist(product_name,"Avena-Avena y mas-0","Nestle-Avena mas flakes-con pasas","Nestle-Avena y mas flakes-con pasas","Nestle-Avena y mas-Flakes")
replace nutrition_id1 = "849727" if inlist(product_name,"Carozzi-Avena Vivo-0","Carozzi-Cereal Vivo-Avena","Vivo-Avena instantanea-0","carozzi-avena instantanea vivo-0","carozzi-vivo avena instantanea-0","vivo-avena instantanea-0","vivo-avena-0","Vivo-Avena instantánea-0","carozzi-avena vivo instantanea-0")
replace nutrition_id1 = "910015" if inlist(product_name,"Nestle-CEREAL CHOCAPIC-0","Nestle-CEREAL CHOCAPIC-CHOCOLATE","Nestle-Cereal-Chocapic","Nestle-Chocapic-0","Nestle-cercal chocapic-0","Nestle-cereal chocapic-0","Nestle-cereales chocapic-0","Nestle-cereales-chocapic","Nestle-chocapic-0")
replace nutrition_id1 = "282821" if inlist(product_name,"Nestle-CEREAL FITNESS-0","Nestle-Cereal integral Fitness-0","Nestle-Cereal-Fitness","Nestle-Fitness-0","Nestle-cereal fitness-0","Nestle-cereales fitness-0","Nestle-cereales-fitnss","Nestle-fitness-0")
replace nutrition_id1 = "859626" if inlist(product_name,"Nestle-cercal chocapic-granola")
replace nutrition_id1 = "296899" if inlist(product_name,"Quaker-Avena de grano entero-0","Quaker-avena de grano entero-0","quaker-avena de grano entero-0","quaker-avena entera de grano-0")
replace nutrition_id1 = "2769" if inlist(product_name,"Quaker-Avena instantanea-0","Quaker-Cereal-Avena instantanea","Quaker-avena instantane-0","Quaker-avena instantanea-0","Quaker-avena-0","quaker-avena instantanea-0","Quaker-Avena instantánea-0")
replace nutrition_id1 = "903783" if inlist(product_name,"Quaker-Cereal Quadritos-0","quaker-cerales quadritos-0","quaker-cereal quadritos y avena-0")


ren nutrition_id1 nutrition_id 

keep if inlist(nombre_canal,"C13","CHV","Mega","TVN") 

gen length = hora_termino_spot-hora_inicio_spot
replace length = length-600 if length>600
replace length = -length if length<0

destring univers_rate, replace force
egen temp = mean(univers_rate), by(nombre_canal)
replace univers_rate = temp if univers_rate == .

egen unique_ad_product = tag(f_idspot nutrition_id)
keep if unique_ad_product == 1
egen prods_per_add = total(1), by(f_idspot)
gen length_per_prod = length/prods_per_ad
gen ads_per_prod = 1/prods_per_add
ren unique_ad_product total_ads
gen length_rating = length_per_prod*univers_rate

collapse (sum) total_ads ads_per_prod length_per_prod length length_rating , by(nutrition_id)

gen post = 1


tempfile tv_ads_2017
save `tv_ads_2017', replace

** merge and save ads data **

append using `tv_ads_2016'

compress

save "${Repo}/00_files/02_intermediate/05_advertising/01_cereals_tvAds.dta", replace
