
/*******************************************************************************
AUTHOR: Nano Barahona
CREATION: Feb-2019
ACTION: Estimate first stage and others using Stata
SUMMARY:

********************************************************************************/

clear all
set more off
set scheme s1mono
set graphics off

******************************************************************************** 
** SET PATH AND LOCALS
******************************************************************************** 

if c(username)=="Nano"   		  global Repo "/Users/Nano/Dropbox/Research/FoodLabels/food_labels/04_replication"
else 							  global Repo "."

global output "${Repo}/00_files/06_figures/01_descriptive"

******************************************************************************** 
** LOAD DATA
******************************************************************************** 

use "${Repo}/00_files/03_data/03_marketLevel_cereals_model.dta", clear 


*********************************************************************************************************
*********************************************************************************************************
*** DEFINE PROGRAMS																   					 ****
*********************************************************************************************************
*********************************************************************************************************

*********************************************************************************************************
*** PLOT DIFF IN DIFF															   					 ****
*********************************************************************************************************

** This function plots the coefficients of a dif-in-dif
** The name of the program is "plotCoefficients"

cap program drop plotCoefficients
program define plotCoefficients

args plotname beta cov policy lastweek penetration base aggr funtit ytit2 balanced weighted treat jointweeks numcl numob catname numtr numctr seasonal

preserve

clear

set obs 1

gen id = 1

local base1 = `base'-1
local base2 = `base'+1

if `base' > 1 {
forv i = 1/`base1' {
	gen beta`i' = `beta'[1,`i']
	gen var`i' = `cov'[`i',`i']
	gen betamax`i'= beta`i'+1.96*sqrt(var`i')
	gen betamin`i'= beta`i'-1.96*sqrt(var`i')
}
}

	gen beta`base' = 0
	gen var`base' = 0
	gen betamax`base'= beta`base'+1.96*sqrt(var`base')
	gen betamin`base'= beta`base'-1.96*sqrt(var`base')
	

forv i = `base2'/`lastweek' {
	gen beta`i' = `beta'[1,`i'-1]
	gen var`i' = `cov'[`i'-1,`i'-1]
	gen betamax`i'= beta`i'+1.96*sqrt(var`i')
	gen betamin`i'= beta`i'-1.96*sqrt(var`i')
}

if `seasonal'>0 {
local base3 = `base2'+1
forv i = `base3'/`lastweek' {
	local i2 = `lastweek'-`i'+`base3'
	local i3 = `lastweek'-`i'+`base3'-1
	replace beta`i2' = beta`i3'
	replace betamax`i2' = betamax`i3'
	replace betamin`i2' = betamin`i3'
}
	replace beta`base2' = beta`base1'
	replace betamax`base2' = betamax`base1'
	replace betamin`base2' = betamin`base1'
forv i = `seasonal'/`base1' {
	local i2 = `base1'-`i'+`seasonal'
	local i3 = `base1'-`i'+`seasonal'-1
	replace beta`i2' = beta`i3'
	replace betamax`i2' = betamax`i3'
	replace betamin`i2' = betamin`i3'
}
replace beta`seasonal' = 0
replace var`seasonal' = 0
replace betamax`seasonal'= beta`seasonal'+1.96*sqrt(var`seasonal')
replace betamin`seasonal'= beta`seasonal'-1.96*sqrt(var`seasonal')
}

reshape long beta var betamax betamin , i(id) j(week)

qui: sum beta if week<=`penetration'
local meanpre = r(mean)
replace beta = beta-`meanpre'
replace betamax = betamax-`meanpre'
replace betamin = betamin-`meanpre'

local policy3 = `policy'+0.5
local penetration3 = `penetration'+0.5
local lastweek3 = `lastweek'+1

if `balanced' == 1 {
local isbal = "Balanced panel."
}
if `weighted' == 1 {
local isweight = "Weighted by pre-policy revenues."
}
if `weighted' == 2 {
local isweight = "Weighted by pre-policy revenues (sqrt)."
}
if `weighted' == 3 {
local isweight = "Weighted by pre-policy revenues (log)."
}
if `weighted' == 4 {
local isweight = "Weighted by market size."
}
if "`plotname'"=="03" | strpos("`plotname'","03s")>0 {
local controls = "Controlling for prices."
}
if `seasonal'>0 {
local seasonnote = "Deseasonalized."
}


if inlist("`ytit2'","p","d") {
twoway (rcap betamin betamax week , lcolor(gs8)) (scatter beta week, msize(medlarge) mcolor(gs4) m(square)), ///
yline(0) xtitle(`jointweeks' week intervals, size(large)) ytitle(`funtit'(`ytit2') ({&beta}{subscript:k}), size(large)) /// 
name(a`catname'_`plotname'`ytit2'`balanced'`weighted'`treat'_d, replace) legend(order(2 "any label" ) size(medlarge) region(lw(none))) ///
xscale(range(0 `lastweek3')) xlab(1 "Jun-15" 5 "Jan-16" 10 "Oct-16" 15 "Jul-17" 19 "Mar-18" ,labsize(large)) ///
ylab(,labsize(vlarge)) xline(`policy3' `penetration3') ///
title("`catname'", size(vlarge)) subtitle(, size(large)) ///
yscale(range(-0.2 0.1)) ylabel(-0.2(0.1)0.1) ///
text(-0.21 `penetration3' "first labels appear" -0.21 `policy3' "all labels in place",  placement(nw) orient(vertical) size(medium)) 
}
else {
twoway (rcap betamin betamax week , lcolor(gs8)) (scatter beta week, msize(medlarge) mcolor(gs4) m(square)), ///
yline(0) xtitle(`jointweeks' week intervals, size(large)) ytitle(`funtit'(`ytit2') ({&beta}{subscript:k}), size(large)) /// 
name(a`catname'_`plotname'`ytit2'`balanced'`weighted'`treat'_d, replace) legend(order(2 "any label" ) size(medlarge) region(lw(none))) ///
xscale(range(0 `lastweek3')) xlab(1 "Jun-15" 5 "Jan-16" 10 "Oct-16" 15 "Jul-17" 19 "Mar-18",labsize(large)) ///
ylab(,labsize(vlarge)) xline(`policy3' `penetration3') ///
title("`catname'", size(vlarge)) subtitle( , size(large)) ///
yscale(range(-0.6 0.4)) ylabel(-0.6(0.2)0.4) ///
text(-0.63 `penetration3' "first labels appear" -0.63 `policy3' "all labels in place",  placement(nw) orient(vertical) size(medium)) 
}

*note(Notes: `numob' observations and `numcl' products (`numctr'/`numtr'). `isbal' `isweight' `controls' `seasonnote', size(vsmall))
gr export "${output}/`plotname'.pdf", replace

restore 

end



*********************************************************************************************************
*** PLOT DIFF IN DIFF BELIEFS 													   					 ****
*********************************************************************************************************

** This function plots the coefficients of a dif-in-dif
** The name of the program is "plotCoefficients"

cap program drop plotCoefficientsBeliefs
program define plotCoefficientsBeliefs

args plotname beta cov betaold covold policy lastweek penetration base aggr funtit ytit2 balanced weighted treat jointweeks numcl numob catname numctr numtr numtr2 leg1 leg2 spec

preserve

clear

set obs 1

gen id = 1

local base1 = `base'-1
local base2 = `base'+1

if `base' > 1 {
forv i = 1/`base1' {
	local j = `i'+`lastweek'-1
	gen beta`i' = `beta'[1,`i']
	gen var`i' = `cov'[`i',`i']
	gen betamax`i'= beta`i'+1.96*sqrt(var`i')
	gen betamin`i'= beta`i'-1.96*sqrt(var`i')
	gen gamma`i' = `betaold'[1,`i']
	gen varg`i' = `covold'[`i',`i']
	gen gammamax`i'= gamma`i'+1.96*sqrt(varg`i')
	gen gammamin`i'= gamma`i'-1.96*sqrt(varg`i')
	gen alpha`i' = `beta'[1,`j']
	gen vara`i' = `cov'[`j',`j']
	gen alphamax`i'= alpha`i'+1.96*sqrt(vara`i')
	gen alphamin`i'= alpha`i'-1.96*sqrt(vara`i')
}
}

	gen beta`base' = 0
	gen var`base' = 0
	gen betamax`base'= beta`base'+1.96*sqrt(var`base')
	gen betamin`base'= beta`base'-1.96*sqrt(var`base')
	gen gamma`base' = 0
	gen varg`base' = 0
	gen gammamax`base'= gamma`base'+1.96*sqrt(varg`base')
	gen gammamin`base'= gamma`base'-1.96*sqrt(varg`base')
	gen alpha`base' = 0
	gen vara`base' = 0
	gen alphamax`base'= alpha`base'+1.96*sqrt(vara`base')
	gen alphamin`base'= alpha`base'-1.96*sqrt(vara`base')	

forv i = `base2'/`lastweek' {
	local j = `i'+`lastweek'-2
	gen beta`i' = `beta'[1,`i'-1]
	gen var`i' = `cov'[`i'-1,`i'-1]
	gen betamax`i'= beta`i'+1.96*sqrt(var`i')
	gen betamin`i'= beta`i'-1.96*sqrt(var`i')
	gen gamma`i' = `betaold'[1,`i'-1]
	gen varg`i' = `covold'[`i'-1,`i'-1]
	gen gammamax`i'= gamma`i'+1.96*sqrt(varg`i')
	gen gammamin`i'= gamma`i'-1.96*sqrt(varg`i')
	gen alpha`i' = `beta'[1,`j']
	gen vara`i' = `cov'[`j',`j']
	gen alphamax`i'= alpha`i'+1.96*sqrt(vara`i')
	gen alphamin`i'= alpha`i'-1.96*sqrt(vara`i')
}

reshape long beta var betamax betamin alpha vara alphamax alphamin gamma varg gammamax gammamin , i(id) j(week)

local policy3 = `policy'+0.5
local penetration3 = `penetration'+0.5
local lastweek3 = `lastweek'+1

qui: sum beta if week<=`penetration'
local meanpre = r(mean)
replace beta = beta-`meanpre'
replace betamax = betamax-`meanpre'
replace betamin = betamin-`meanpre'
qui: sum alpha if week<=`penetration'
local meanpre = r(mean)
replace alpha = alpha-`meanpre'
replace alphamax = alphamax-`meanpre'
replace alphamin = alphamin-`meanpre'
qui: sum gamma if week<=`penetration'
local meanpre = r(mean)
replace gamma = gamma-`meanpre'
replace gammamax = gammamax-`meanpre'
replace gammamin = gammamin-`meanpre'

if `balanced' == 1 {
local isbal = "Balanced panel."
}
if `weighted' == 1 {
local isweight = "Weighted by pre-policy revenues."
}
if "`plotname'"=="08" {
local controls = "Controlling for prices."
}

gen dif = beta-alpha

gen week2 = week


twoway (rcap gammamin gammamax week , lcolor(gs8%10)) (scatter gamma week, msize(medlarge) mcolor(gs4%10) m(square))  ///
 (scatter beta week, msize(medlarge) mcolor("0 112 189") lstyle(foreground) mlcolor(black)  m(circle))  /// 
 (scatter alpha week2, msize(medlarge) mcolor("237 176 32") lstyle(foreground) mlcolor(black)  m(diamond)) , /// 
yline(0) xtitle(`jointweeks' week intervals, size(large)) ytitle(`funtit'(`ytit2') ({&beta}{subscript:k}), size(large)) /// 
name(a`catname'_`plotname'`ytit2'`balanced'`weighted'`treat'`spec'_d, replace) legend(order(3 "`leg1'" 4 "`leg2'" ) size(medlarge) region(lw(none))) ///
xscale(range(0 `lastweek3')) xlab(1 "Jun-15" 5 "Jan-16" 10 "Oct-16" 15 "Jul-17" 19 "Mar-18",labsize(large)) ///
ylab(,labsize(vlarge)) xline(`policy3' `penetration3') ///
title( , size(vlarge)) subtitle( , size(large)) ///
yscale(range(-0.6 0.4)) ylabel(-0.6(0.2)0.4) ///
text(-0.63 `penetration3' "first labels appear" -0.63 `policy3' "all labels in place",  placement(nw) orient(vertical) size(medium)) 

gr export "${output}/`plotname'.pdf", replace

restore 

end


*********************************************************************************************************
*** PLOT FIXED EFFECTS															   					 ****
*********************************************************************************************************

** This function plots the fixed effects coefficients of a regression
** The name of the program is "plotFE"

cap program drop plotFE
program define plotFE

args plotname beta cov policy lastweek penetration base aggr funtit ytit2 balanced weighted treat jointweeks numcl numob catname numtr numctr seasonal

preserve

clear

set obs 1

gen id = 1

gen beta1 = 0
gen var1 = 0
gen betamax1= beta1+1.96*sqrt(var1)
gen betamin1= beta1-1.96*sqrt(var1)

forv i = 2/`lastweek' {
	gen beta`i' = `beta'[1,`i'-1]
	gen var`i' = `cov'[`i'-1,`i'-1]
	gen betamax`i'= beta`i'+1.96*sqrt(var`i')
	gen betamin`i'= beta`i'-1.96*sqrt(var`i')
}

reshape long beta var betamax betamin , i(id) j(week)

local meanpre = -`beta'[1,`lastweek']
replace beta = beta-`meanpre'
replace betamax = betamax-`meanpre'
replace betamin = betamin-`meanpre'

local policy3 = `policy'+0.5
local penetration3 = `penetration'+0.5
local lastweek3 = `lastweek'+1


twoway (rcap betamin betamax week , lcolor(gs8)) (scatter beta week, msize(medium) mcolor(gs4)), ///
 xtitle(`jointweeks' week intervals, size(large)) ytitle(`funtit'(`ytit2') ({&beta}{subscript:t}), size(large)) /// 
name(a`catname'_f, replace) legend(order(2 "any label" ) size(medlarge) region(lw(none))) ///
xscale(range(0 `lastweek3')) xlab(1 "Jun-15" 5 "Jan-16" 10 "Oct-16" 15 "Jul-17" 19 "Mar-18",labsize(large)) ///
ylab(,labsize(vlarge)) xline(`policy3' `penetration3') ///
title("`catname'", size(vlarge)) subtitle( , size(large)) ///
yscale(range(4 4.5)) ylabel(4(0.1)4.5) ///
text(3.98 `penetration3' "first labels appear" 3.98 `policy3' "all labels in place",  placement(nw) orient(vertical) size(medium)) 

gr export "${output}/`plotname'.pdf", replace

restore 

end


*********************************************************************************************************
*** SPREAD																		   					 ****
*********************************************************************************************************

** This function fills up data by categoru

program define spread, sortpreserve

	version 8.0
	syntax varlist [if] [in], by(varlist) [Zero]
	marksample touse, novarlist
	tempvar var_last
	preserve
	foreach var of local varlist {
		capture confirm numeric variable `var'
		if (!_rc) {
			local sign "-"
			local missmark "."
		}
		else {
			local sign ""
			local missmark `""""'
		}
		gsort `by' `sign'`var', mfirst
		quietly by `by': generate `var_last' = `var'[_N] if `touse'
		capture assert `var_last'==`var' if `var'~=`missmark' & `touse'
		if _rc {
			display as error "`var' not unique within `by'"
			exit 9
		}
		if "`zero'"=="zero" quietly count if (`var'!=`var_last' | `var_last'>=.) & `touse'
		else quietly count if `var'!=`var_last' & `touse'
		local changes = r(N)
		quietly replace `var' = `var_last' if `touse'
		if "`zero'"=="zero"	quietly replace `var' = 0 if `var'>=. & `touse'
		local s = cond(`changes'==1,"","s")
		display as text "(`changes' real change`s' made)"
		drop `var_last'
	
	}

	restore, not

end 


*********************************************************************************************************
*********************************************************************************************************
*** FIGURES																		   					 ****
*********************************************************************************************************
*********************************************************************************************************


gen trunsales = round(sales_final)*(1-post)

egen unique_nutrition = tag(nutrition_id)
egen unique_nutrition_post = tag(nutrition_id post)
count if unique_nutrition_post==1 & post==0
local nutrs = r(N)

spread mu_cal mu_sug , by(nutrition_id)

cap tempfile temp_main
save `temp_main', replace

local thres_cal_1_g = 350
local thres_cal_2_g = 300
local thres_cal_3_g = 275

local thres_sug_1_g = 22.5
local thres_sug_2_g = 15
local thres_sug_3_g = 10


local posy = 0.88

local none = "none"



local maxy_cal_g = 2.15*10^9
local maxy_sug_g = 1.75*10^9


foreach nut in cal sug {
local laby_`nut'_g = `maxy_`nut'_g' // *`posy'
}



local binw_cal_g = 5
local binw_sug_g = 1.25

local labw_cal_g = 50
local labw_sug_g = 10

local minw_cal_g = 200
local minw_sug_g = 0

local maxw_cal_g = 500
local maxw_sug_g = 50

local name_cal = "Caloric"
local name_sug = "Sugar"

local type_cal = "kcal"
local type_sug = "g"


egen counter = group(nutrition_id)
sum counter
local maxcount = r(max)-1


local nut = "cal"
local types = "g"
local categ = "cereals"
local categ = ""


********************************************************************************
**			NUTRITIONAL INFO DISTRIBUTION
********************************************************************************



foreach nut in sug cal  {

preserve

drop if exempted==1

replace `nut'_pre = `nut'_pre-0.01 if `nut'_pre==`thres_`nut'_1_g'
replace `nut'_post = `nut'_post-0.01 if `nut'_post==`thres_`nut'_1_g'


forv l = 0/`maxcount' { 
	qui: sum exempted if counter==`l'+1
	local exmp = r(mean)
	if `exmp'==1 {
    local fig2016_`nut' `fig2016_`nut'' (histogram `nut'_pre [fw = trunsales] if counter>`l' , freq fcolor("237 176 32") fintensity(60)  width(`binw_`nut'_`types'') start(`minw_`nut'_`types'') )  
		}
	else {
	local fig2016_`nut' `fig2016_`nut'' (histogram `nut'_pre [fw = trunsales] if counter>`l' , freq fcolor("237 176 32")  width(`binw_`nut'_`types'') start(`minw_`nut'_`types'') ) 
	}
}
graph twoway `fig2016_`nut'' , /// , ///
 legend(off) subtitle( , size(large)) title("`categ'", size(vlarge)) yscale(range(0 `maxy_`nut'_`types'')) xscale(range(`minw_`nut'_`types'' `maxw_`nut'_`types'')) ///
 xlab(`minw_`nut'_`types''(`labw_`nut'_`types'')`maxw_`nut'_`types'',labsize(vlarge)) ///
xline(`thres_`nut'_1_`types'')  name(b1_`nut', replace) ytitle(Density,size(large)) xlab(,labsize(vlarge)) ylab(`none',labsize(vlarge)) xtitle("`name_`nut'' concentration (`type_`nut''/100`types')", size(large)) ///
text(`laby_`nut'_`types'' `thres_`nut'_1_`types'' "Threshold",  placement(se) orient(vertical) size(medium)) 

gr export "${output}/figureA1_`nut'_2016.pdf", replace

forv l = 0/`maxcount' { 
	qui: sum exempted if counter==`l'+1
	local exmp = r(mean)
	if `exmp'==1 {
    local fig2018_`nut' `fig2018_`nut'' (histogram `nut'_post [fw = trunsales] if counter>`l' , freq fcolor("0 112 189") fintensity(40)  width(`binw_`nut'_`types'') start(`minw_`nut'_`types'') )    
	}
	else {
	local fig2018_`nut' `fig2018_`nut'' (histogram `nut'_post [fw = trunsales] if counter>`l' , freq fcolor("0 112 189")  width(`binw_`nut'_`types'') start(`minw_`nut'_`types'') )  
	}
}
graph twoway `fig2018_`nut''  , ///
 legend(off) subtitle( , size(large)) title("`categ'", size(vlarge)) yscale(range(0 `maxy_`nut'_`types'')) xscale(range(`minw_`nut'_`types'' `maxw_`nut'_`types''))  ///
 xlab(`minw_`nut'_`types''(`labw_`nut'_`types'')`maxw_`nut'_`types'',labsize(vlarge)) ///
xline(`thres_`nut'_1_`types'')  name(b2_`nut', replace) ytitle(Density,size(large)) xlab(,labsize(vlarge)) ylab(`none',labsize(vlarge)) xtitle("`name_`nut'' concentration (`type_`nut''/100`types')", size(large)) ///
text(`laby_`nut'_`types'' `thres_`nut'_1_`types'' "Threshold",  placement(se) orient(vertical) size(medium)) 

gr export "${output}/figureA1_`nut'_2018.pdf", replace


restore

}


********************************************************************************
**			DIFF IN DIFF
********************************************************************************



use `temp_main', clear

ren p price

egen id = group(nutrition_id store_id)
duplicates tag id , gen(dups)

local jointweeks = 8
local clust = "nutrition_id"
local lastweek = floor((152-1)/8)+1
local policy= floor((61-1)/8)+1          //the policy starts in week 61 and weeks are: floor((week-1)/`jointweeks')+1
local penetration = floor((44-1)/8)+1
local reference = `penetration'+1
*local reference = `penetration'
local treat = "cal"
local aggr = "nutr"
local categ = "cereals"
local categ = ""

egen z_l_cal = max(l_cal_prob), by(nutrition_id )

forv x=1/`lastweek'{
gen TT`x'_l_`treat'=(week==`x')*l_`treat'
gen ZZ`x'_l_`treat'=(week==`x')*z_l_`treat'
}
gen TP_`treat' = post*l_`treat'

** we drop the dummy before policy implementation
local y = `reference'
drop TT`y'_l_`treat'


gen log_price = log(price)
gen log_quantity = log(quantity)

local function = "log_outcome"


gen temp = sales_final*(week<=`penetration')
egen weight_sales1 = total(temp), by(id) 


gen positive_weights = (weight_sales1>0)
egen unique_clus = tag(`clust' positive_weights)
	
xi: areg log_price TP* 	i.week		[aw = 	weight_sales1]	if week<=`penetration' | week>`policy'			, a(id) cl(`clust')
	
xi: areg log_price TT*l_`treat' 	i.week		[aw = 	weight_sales1]			, a(id) cl(`clust')
mat beta10 = e(b)
mat cov10  = e(V)
local numcl =  e(N_clust) 
local numob =  e(N)

count if unique_clus==1 & l_`treat'==1 & positive_weights==1
local numtr = r(N)

count if unique_clus==1 & l_`treat'==0 & positive_weights==1
local numctr = r(N)


plotCoefficients "figureB1a" "beta10" "cov10" `policy' `lastweek' `penetration' `reference' `aggr' "log" "p" 0 1 `treat' `jointweeks' `numcl' `numob' "`categ'" `numtr' `numctr' 0


xi: areg log_quantity TP* 	i.week	log_price	[aw = 	weight_sales1]	if week<=`penetration' | week>`policy'		, a(id) cl(`clust')
	
xi: areg log_quantity TT*l_`treat' 	i.week	log_price	[aw = 	weight_sales1]			, a(id) cl(`clust')
mat beta10 = e(b)
mat cov10  = e(V)
local numcl =  e(N_clust) 
local numob =  e(N)


plotCoefficients "figure1a" "beta10" "cov10" `policy' `lastweek' `penetration' `reference' `aggr' "log" "q" 0 1 `treat' `jointweeks' `numcl' `numob' "`categ'" `numtr' `numctr' 0





*********************************************************************************************************
*** DIFF-IN-DIFF BELIEFS														   					 ****
*********************************************************************************************************



use `temp_main', clear


ren p price

egen id = group(nutrition_id store_id)
duplicates tag id , gen(dups)

local jointweeks = 8
local clust = "nutrition_id"
local lastweek = floor((152-1)/8)+1
local policy= floor((61-1)/8)+1          
local penetration = floor((44-1)/8)+1
local reference = `penetration'+1
*local reference = `penetration'
local treat = "cal"
local aggr = "nutr"
local categ = "cereals"
local categ = ""

gen logq = log(quantity)
gen positive_weights = (weight_sales>0)
egen unique_clus = tag(nutrition_id)

_pctile mu_cal_raw if unique_clus==1 &l_cal==1 & positive_weights==1 , p(48)
local median_mu = r(r1)

_pctile cal_post if unique_clus==1 & l_cal==1 & positive_weights==1 , p(48)
local median_cal = r(r1)

forv spec = 3/4 {

preserve

if `spec'==1 {
gen group0 = (l_cal == 1 )
gen group1 = (l_cal == 1 & l_sug == 0)
gen group2 = (l_cal == 1 & l_sug == 1)
local leg1 = "calorie label"
local leg2 = "both labels"
}
else if `spec'==2 {
gen group0 = (l_cal == 1 )
gen group1 = (l_cal == 1 & healthy == 1)
gen group2 = (l_cal == 1 & healthy == 0)
local leg1 = "healthy"
local leg2 = "regular"
}
else if `spec'==3 {
gen group0 = (l_cal == 1 )
gen group1 = (l_cal == 1 & mu_cal_raw <= `median_mu')
gen group2 = (l_cal == 1 & mu_cal_raw >  `median_mu')
local leg1 = "labeled: low-calorie belief"
local leg2 = "labeled: high-calorie belief"
local figname = "figure1b"
}
else if `spec'==4 {
gen group0 = (l_cal == 1 )
gen group1 = (l_cal == 1 & cal_post <= `median_cal')
gen group2 = (l_cal == 1 & cal_post >  `median_cal')
local leg1 = "labeled: low-caloric content"
local leg2 = "labeled: high-caloric content"
local figname = "figureC1"
}

forv x=1/`lastweek'{
gen TT`x'_L0=(week==`x')*(group0 == 1 )
gen TT`x'_L1=(week==`x')*(group1 == 1 )
gen TT`x'_L2=(week==`x')*(group2 == 1 )
}
gen TP_`treat'_1 = post*l_`treat'*(group1 == 1 )
gen TP_`treat'_2 = post*l_`treat'*(group2 == 1 )

** we drop the dummy before policy implementation
local y = `reference'
drop TT`y'_L0
drop TT`y'_L1
drop TT`y'_L2

count if unique_clus==1 & (group1 == 1) & positive_weights==1 
local numtr = r(N)

count if unique_clus==1 & (group2 == 1) & positive_weights==1 
local numtr2 = r(N)

count if unique_clus==1 & (group1 == 0 & group2 == 0) & positive_weights==1 
local numctr = r(N)

gen log_price = log(price)


xi: areg logq TT*L0 	i.week	log_price	[aw = 	weight_sales]		, a(id) cl(nutrition_id)
mat beta20 = e(b)
mat cov20  = e(V)

xi: areg logq TT*L1 TT*L2 	i.week	log_price	[aw = 	weight_sales]		, a(id) cl(nutrition_id)
mat beta10 = e(b)
mat cov10  = e(V)
local numcl =  e(N_clust) 
local numob =  e(N)

disp ""
disp "specification: `spec'"
disp ""
xi: areg logq TP* 	i.week	log_price	[aw = 	weight_sales]	if week<=`penetration' | week>`policy'			, a(id) cl(nutrition_id)
test TP_cal_1=TP_cal_2

plotCoefficientsBeliefs "`figname'" "beta10" "cov10" "beta20" "cov20" `policy' `lastweek' `penetration' `reference' "nutr" "log" "q" 0 1 "any" `jointweeks' `numcl' `numob' "cereals" `numctr' `numtr' `numtr2' "`leg1'" "`leg2'" `spec'


restore



}



*********************************************************************************************************
*** MODEL VALIDATION - MARKUPS													   					 ****
*********************************************************************************************************

use `temp_main', clear

gen e_cal = (mu_cal)*(post==0) + (mu_cal_post)*(post==1)
gen e_sug = (mu_sug)*(post==0) + (mu_sug_post)*(post==1)

gen markup = p-c
gen markup_prop = markup/p

sum markup_prop if post == 0, det

sum markup_prop if post == 0 [aw = sales_final ], det

sum markup_prop if post == 0 & name=="CHOCAPIC" [aw = sales_final ], det


twoway (kdensity markup_prop if markup_prop<1 & post==0, lwidth(1) lcolor("237 176 32")) ///
 (kdensity markup_prop if markup_prop<1 & post==1, lwidth(1) lcolor("0 112 189") lpattern(longdash)) , ///
name(a01_`nutrient'_`nut', replace)  xline(`thres') xtitle("Markups ([p{subscript:jt}-c{subscript:jt}]/p{subscript:jt})", size(large)) ytitle( "Density" ,size(large))  ///
xlab(, labsize(large) ) ylab(,labsize(large))  ///
legend(order(1 "Pre-policy period" 2 "Post-policy period") rows(1)  region(lw(none)) size(large))
gr export "${output}/figureA2.pdf", replace


*********************************************************************************************************
*** WILLIGNESS TO PAY SUG/CAL	 												   					 ****
*********************************************************************************************************


import delimited "${Repo}/00_files/07_outputs/01_demand/05_numbers_to_plot.csv", clear



twoway (kdensity wtp_low_sug if wtp_low_sug<80, range(0 60) lwidth(1) lcolor("237 176 32")) ///
 (kdensity wtp_high_sug if wtp_high_sug<80, range(0 60) lwidth(1) lcolor("0 112 189") lpattern(longdash)) , ///
name(a01a_wtpsug, replace)  xtitle("Willingness to pay to decrease sugar content (%)", size(large)) ytitle( "Density" ,size(large))  ///
xlab(, labsize(large) ) ylab(,labsize(large))  ///
legend(order(1 "low-SES" 2 "high-SES") rows(1)  region(lw(none)) size(large))
gr export "${output}/figure4a.pdf", replace

twoway (kdensity wtp_low_cal if wtp_low_cal<30, range(0 30) lwidth(1) lcolor("237 176 32")) ///
 (kdensity wtp_high_cal if wtp_high_cal<30, range(0 30) lwidth(1) lcolor("0 112 189") lpattern(longdash)) , ///
name(a01a_wtpcal, replace)  xtitle("Willingness to pay to decrease caloric content (%)", size(large)) ytitle( "Density" ,size(large))  ///
xlab(, labsize(large) ) ylab(,labsize(large))  ///
legend(order(1 "low-SES" 2 "high-SES") rows(1)  region(lw(none)) size(large))
gr export "${output}/figure4b.pdf", replace



********************************************************************************
**			MODEL VALIDATION - SUPPLY
********************************************************************************


use `temp_main', clear

gen e_cal = (mu_cal)*(post==0) + (mu_cal_post)*(post==1)
gen e_sug = (mu_sug)*(post==0) + (mu_sug_post)*(post==1)

gen l_cal_pre = (cal_pre>350)*(1-exempted)
gen l_sug_pre = (sug_pre>22.5)*(1-exempted)

gen bunch_cal = (l_cal==0 & l_cal_pre==1)
gen bunch_sug = (l_sug==0 & l_sug_pre==1)

gen LL_cal = bunch_cal*log(prob_bunch_cal_model) + (1-bunch_cal)*log(1-prob_bunch_cal_model)
gen LL_sug = bunch_sug*log(prob_bunch_sug_model) + (1-bunch_sug)*log(1-prob_bunch_sug_model)

keep if post==0

collapse (sum) sales_final trunsales (mean) prob_bunch* bunch_cal bunch_sug (first) product name l_cal l_sug l_cal_pre l_sug_pre cal_pre sug_pre cal_post sug_post exempted brand_name change_cost_model both_periods mu_cal mu_sug , by(nutrition_id)

egen tot_weght = total(trunsales)

foreach var in "" {
foreach nut in "sug" "cal" {
forv bun = 0/1 {

sum prob_bunch_`nut'_model`var' [aw=trunsales] if l_`nut'_pre==1 & bunch_`nut'==`bun' & exempted==0



}
}
gen MSE`var' = (prob_bunch_cal_model`var'-bunch_cal)^2 + (prob_bunch_sug_model`var'-bunch_sug)^2
gen MSE`var'2 = trunsales*((prob_bunch_cal_model`var'-bunch_cal)^2 + (prob_bunch_sug_model`var'-bunch_sug)^2)
egen MSE`var'_unit = total(MSE`var')
egen MSE`var'_weight = total(MSE`var'2)
replace MSE`var'_unit = MSE`var'_unit/73
replace MSE`var'_weight = MSE`var'_weight/tot_weght
}



gen delta_cal = cal_post - cal_pre 
gen delta_sug = sug_post - sug_pre

reg delta_cal delta_sug [aw=trunsales] if bunch_sug==1 & bunch_cal ==0, r
reg delta_sug delta_cal [aw=trunsales] if bunch_cal==1 & bunch_sug ==0, r


** Probability of bunching vs distance to threshold


foreach nut in "cal" "sug" {

preserve

local xvar = "`nut'_pre"
local yvar = "prob_bunch_`nut'_model"

gen grupo = .
replace grupo = 1 if l_`nut'_pre == 0
replace grupo = 2 if l_`nut'_pre == 1 & l_`nut' == 1
replace grupo = 3 if l_`nut'_pre == 1 & l_`nut' == 0

expand 3
sort nutrition_id grupo
replace `yvar'=. if mod(_n,3) > 0

recode grupo (1=2) (2=3) (3=1) if mod(_n,3) == 1
recode grupo (1=3) (2=1) (3=2) if mod(_n,3) == 2

local ymin = 0
local ymax = 1
local ybin = 0.2

if "`nut'" == "cal" {
	local color = "blue"
	local nutlab = "caloric"
	local nutlab2 = "calories"
}
else if "`nut'" == "sug" {
	local color = "red"
	local nutlab = "sugar"
	local nutlab2 = "sugar"
}

if "`nut'"=="cal" {
local xmin1 = 339
local xmin  = 350
local xmax  = 470
local xbin  = 50
local xline = 350
}
else if "`nut'"=="sug"{
local xmin1 = 20
local xmin  = 20
local xmax  = 50
local xbin  = 10
local xline = 22.5
}
local place = "ne"
local ytext_`nut' = 0
drop if `xvar' < `xline'


twoway  /// 
(scatter `yvar' `xvar' if grupo==2 , msymbol(o) mcolor("0 112 189") lstyle(foreground) mlcolor(black) msize(vlarge)  ) ///
(scatter `yvar' `xvar' if grupo==3 , msymbol(d) mcolor("237 176 32") lstyle(foreground) mlcolor(black) msize(vlarge)  ) ///
, legend(order(1 "Not bunching" 2 "Bunching") rows(1) size(medlarge) region(lw(none)) ) name(ddrel_`nut', replace) xline(`xline') /// 
xlab(`xmin'(`xbin')`xmax',labsize(vlarge)) ylab(`ymin'(`ybin')`ymax',labsize(vlarge)) xscale(range(`xmin1' `xmax')) yscale(range(`ymin' 1.05)) ///
xtitle("Pre-policy `nutlab' content", size(large)) ytitle("Probability of bunching in `nutlab2'",size(large))  ///
text(`ytext_`nut'' `xline' "Policy threshold" ,  placement(`place') orient(vertical) size(medium)) 
gr export "${output}/figure5_`nut'.pdf", replace

restore



}


** Probability of bunching vs prior beliefs

foreach nut in "cal" "sug" {

preserve

local xvar = "mu_`nut'"
local yvar = "prob_bunch_`nut'_model"

gen grupo = .
replace grupo = 1 if l_`nut'_pre == 0
replace grupo = 2 if l_`nut'_pre == 1 & l_`nut' == 1
replace grupo = 3 if l_`nut'_pre == 1 & l_`nut' == 0

expand 3
sort nutrition_id grupo
replace `yvar'=. if mod(_n,3) > 0

recode grupo (1=2) (2=3) (3=1) if mod(_n,3) == 1
recode grupo (1=3) (2=1) (3=2) if mod(_n,3) == 2

if "`nut'"=="cal" {
local xmin1 = 250
local xmax1 = 400
local xmin = 225
local xmax = 425
local xbin = 50
local xline = 350
}
else if "`nut'"=="sug"{
local xmin = 0
local xmax = 45
local xmin1 = 0
local xmax1 = 40
local xbin = 10
local xline = 22.5
}

local ymin = 0
local ymax = 1
local ybin = 0.2




if "`nut'" == "cal" {
	local color = "blue"
	local nutlab = "caloric"
	local nutlab2 = "calories"
}
else if "`nut'" == "sug" {
	local color = "red"
	local nutlab = "sugar"
	local nutlab2 = "sugar"
}

twoway  /// 
(scatter `yvar' `xvar' if grupo==2, msymbol(o) mcolor("0 112 189") lstyle(foreground) mlcolor(black) msize(vlarge)  ) ///
(scatter `yvar' `xvar' if grupo==3 , msymbol(d) mcolor("237 176 32") lstyle(foreground) mlcolor(black) msize(vlarge)  ) ///
, legend(order(1 "Not bunching" 2 "Bunching") rows(1) size(medlarge) region(lw(none)) ) name(dd_`nut', replace) xline(`xline') /// 
xlab(`xmin1'(`xbin')`xmax1',labsize(vlarge)) ylab(`ymin'(`ybin')`ymax',labsize(vlarge)) xscale(range(`xmin' `xmax')) yscale(range(`ymin' 1.05)) ///
xtitle("Prior beliefs about `nutlab' content", size(large)) ytitle("Probability of bunching in `nutlab2'",size(large)) 
gr export "${output}/figureA5_`nut'.pdf", replace


restore


}




*********************************************************************************************************
*** MODEL VALIDATION - BELIEFS													   					 ****
*********************************************************************************************************


use `temp_main', clear

drop mu_cal_post
drop mu_sug_post

replace mu_cal_raw = mu_cal
replace mu_sug_raw = mu_sug

gen is_in_pre_period = 1-post
collapse (sum) sales_final trunsales (max) is_in_pre_period (first) *post *pre mu* sigma* exempted healthy name brand fineline_name brand_name l_cal l_sug , by(nutrition_id)


local bcalmax = 400
local bcalmin = 250
local bsugmax = 40
local bsugmin = 0

local tcalmax = 500
local tcalmin = 250
local tsugmax = 50
local tsugmin = 0

local calint = 50
local sugint = 10

local cal_line = 350
local sug_line = 22.5

foreach nut in "cal" "sug" {

foreach spec in  "post_prior" {  

local types = "g"

if "`spec'"=="post_prior" {
local xvar = "`nut'_post"
local yvar = "mu_`nut'_raw"
if "`nut'"=="cal" {
local xtit = "True caloric concentration"
local ytit = "Beliefs about caloric concentration"
local xmin = `tcalmin'
local xmax = `tcalmax'
local ymin = `bcalmin'
local ymax = `bcalmax'
local xint = ``nut'int'
local yint = ``nut'int'
local xline = ``nut'_line'
local yline = ``nut'_line'
}
else if "`nut'"=="sug" {
local xtit = "True sugar concentration"
local ytit = "Beliefs about sugar concentration"
local xmin = `tsugmin'
local xmax = `tsugmax'
local ymin = `bsugmin'
local ymax = `bsugmax'
local xint = ``nut'int'
local yint = ``nut'int'
local xline = ``nut'_line'
local yline = ``nut'_line'
}
local i1 = 1
local i2 = 1
local diag = ""
}


corr `yvar' `xvar'
local rho = round(100*r(rho))/100
local rhox = `xmin'+0.01*(`xmax'-`xmin')
local rhoy = `ymax'-0.05*(`ymax'-`ymin')

preserve
gen grupo = .
replace grupo = 1 if l_cal == 0 & l_sug == 0
replace grupo = 2 if l_cal == 1 & l_sug == 0
replace grupo = 3 if l_cal == 1 & l_sug == 1
expand 3
sort nutrition_id grupo
replace `nut'_post=. if mod(_n,3) > 0
replace `nut'_pre=. if mod(_n,3) > 0
replace mu_`nut'=. if mod(_n,3) > 0
replace `xvar'=. if mod(_n,3) > 0
replace `yvar'=. if mod(_n,3) > 0

recode grupo (1=2) (2=3) (3=1) if mod(_n,3) == 1
recode grupo (1=3) (2=1) (3=2) if mod(_n,3) == 2

gsort - sales_final

drop if fineline_name=="AVENA"

twoway   /// 
(scatter `yvar' `xvar' if grupo==1 & is_in_pre_period , msymbol(s) mcolor(gs12) lstyle(foreground) mlcolor(black) msize(vlarge)  ) ///
(scatter `yvar' `xvar' if grupo==2 & is_in_pre_period , msymbol(o) mcolor("0 112 189") lstyle(foreground) mlcolor(black) msize(vlarge)  ) ///
(scatter `yvar' `xvar' if grupo==3 & is_in_pre_period , msymbol(d) mcolor("237 176 32") lstyle(foreground) mlcolor(black) msize(vlarge)  )  `diag' ///
, legend(order(1 "no label" 2 "calorie label" 3 "both labels") rows(1) size(medlarge) region(lw(none)) ) name(d_`nut'_`spec'_pre, replace) xline(`xline') yline(`yline')  ///
xlab("`xmin'(`xint')`xmax'" ,labsize(large)) ylab("`ymin'(`yint')`ymax'" ,labsize(large)) xscale(range(`xmin' `xmax')) yscale(range(`ymin' `ymax')) xtitle("`xtit'", size(large)) ytitle("`ytit'",size(large)) 
gr export "${output}/figureA4_`nut'.pdf", replace



restore



}


}


********************************************************************************
**			MODEL VALIDATION - TASTE VS BELIEFS
********************************************************************************



use `temp_main', clear


gen l_cal_pre = (cal_pre>350)*(1-exempted)
gen l_sug_pre = (sug_pre>22.5)*(1-exempted)

gen bunch_cal = (l_cal==0 & l_cal_pre==1)
gen bunch_sug = (l_sug==0 & l_sug_pre==1)

gen delta_cal = cal_post-cal_pre
gen delta_sug = sug_post-sug_pre
gen delta_Ecal = mu_cal_post-mu_cal
gen delta_Esug = mu_sug_post-mu_sug

preserve
keep if post==0

collapse (sum) sales_final trunsales (mean) prob_bunch* bunch_cal bunch_sug delta_cal delta_sug  delta_Ecal  delta_Esug ///
(first) product name l_cal l_sug l_cal_pre l_sug_pre cal_pre sug_pre cal_post sug_post exempted brand_name both_periods mu_cal mu_sug mu_cal_post mu_sug_post , by(nutrition_id)


gen grupo = .
replace grupo = 1 if l_cal == 0 & l_sug == 0
replace grupo = 2 if l_cal == 1 & l_sug == 0
replace grupo = 3 if l_cal == 1 & l_sug == 1
expand 3
sort nutrition_id grupo
replace delta_cal=. if mod(_n,3) > 0
replace delta_sug=. if mod(_n,3) > 0
replace delta_Ecal=. if mod(_n,3) > 0
replace delta_Esug=. if mod(_n,3) > 0

recode grupo (1=2) (2=3) (3=1) if mod(_n,3) == 1
recode grupo (1=3) (2=1) (3=2) if mod(_n,3) == 2

foreach nut in "cal" "sug" {
	
if "`nut'" == "cal" {
	local nutlab = "caloric"
	local nutlab2 = "calories"
	local scale = "range(-100 100)"
	local scale2 = "-100(50)100"
}
else if "`nut'" == "sug" {
	local nutlab = "sugar"
	local nutlab2 = "sugar"
	local scale = "range(-20 20)"
	local scale2 = "-20(10)20"
}
	
twoway ///
(scatter delta_`nut' delta_E`nut' if grupo==1, msymbol(s) mcolor(gs12) lstyle(foreground) mlcolor(black) msize(vlarge)  ) ///
(scatter delta_`nut' delta_E`nut' if grupo==2, msymbol(o) mcolor("0 112 189") lstyle(foreground) mlcolor(black) msize(vlarge)  ) ///
(scatter delta_`nut' delta_E`nut' if grupo==3, msymbol(d) mcolor("237 176 32") lstyle(foreground) mlcolor(black) msize(vlarge)  ) ///
, legend(order(1 "no label" 2 "cal label" 3 "both labels") rows(1)  size(medlarge) region(lw(none))) name(f1_`nut', replace) yscale(`scale') xscale(`scale') xline(0) yline(0)  ///
xlab(`scale2',labsize(vlarge)) ylab(`scale2',labsize(vlarge)) xtitle("Change in beliefs about `nutlab' content",size(large)) ytitle("Change in real `nutlab' content", size(large)) //  
gr export "${output}/figureC2_`nut'.pdf", replace

}


restore





/*


*********************************************************************************************************
*********************************************************************************************************
*** NUMBERS																		   					 ****
*********************************************************************************************************
*********************************************************************************************************


*********************************************************************************************************
*** COST PARAMETERS																   					 ****
*********************************************************************************************************



sum c  if post == 0  [aw = weight_sales ], det

preserve
egen tag_weights = tag(product store individual_bins)
replace weight_sales = tag_weights*weight_sales

collapse (mean) sug_post sug_pre cal_post cal_pre lambda_c_cond lambda_s_cond change_cost_model (sum) sales_final weight_sales, by(product)

sum lambda_c_cond  [aw = weight_sales ], det
sum lambda_s_cond  [aw = weight_sales ], det

gen delta_cal = cal_post-cal_pre
gen delta_sug = sug_post-sug_pre

gen delta_cal_model = 350-cal_pre
gen delta_sug_model = 22.5-sug_pre

sum delta_cal if lambda_c_cond!=. [aw = weight_sales ], det
sum delta_sug if lambda_s_cond!=.  [aw = weight_sales ], det

sum delta_cal_model if lambda_c_cond!=. [aw = weight_sales ], det
sum delta_sug_model if lambda_s_cond!=.  [aw = weight_sales ], det

replace change_cost_model = . if change_cost_model==0
sum change_cost_model  [aw = weight_sales ], det
sum change_cost_model  , det

restore

egen id = group(nutrition_id store)
gen bunched = ((sug_pre>22.5)&(sug<=22.5)&(1-exempted)) | ((cal_pre>350)&(cal<=350)&(1-exempted))

xi: areg  c  bunched i.week [aw = weight_sales ]	,  cl(market) absorb(id)


/*
s
*/


********************************************************************************
**			CHANGE OF INGREDIENTS
********************************************************************************


use "/Users/Nano/Dropbox/Research/FoodLabels/FoodLabels_shared/01_build/02_data/nutrition/cereals_nutrition.dta", clear

split n_product , p(",")

drop if ano<=2015

replace n_product2 = "CEREAL MONO CHOC" if inlist(n_brand,"COSTA") & inlist(n_product2,"MONOCHOC","MONO CHOC","MONO CHOC BAJO EN SODIO")
replace n_product2 = "CEREAL CHOCAPIC" if inlist(n_brand,"NESTLE") & inlist(n_product2,"CHOCAPIC HOT WHEELS","CHOCAPIC LA ERA DEL HIELO","CHOCAPIC","CHOCAPIC HOTWHEELS")


gen maltitol = strpos(ingredients_list1, "MALTITOL")>0
gen sucralosa = strpos(ingredients_list1, "SUCRALOSA")>0
gen stevia = strpos(ingredients_list1, "STEVIA")>0

foreach var in "maltitol" "sucralosa" "stevia" {
	di "`var'"
	egen max_`var' = max(`var'), by(n_product1 n_product2)
	
}

duplicates drop n_product1 n_product2, force

keep if inlist(n_brand,"COSTA","LIDER","NESTLE","QUAKER","SELECTA","VIVO")

replace n_product2 = trim(n_product2)

keep if inlist(n_product2,"CEREAL MONO CHOC","AVENA Y MAS FLAKES PASAS","CEREAL CHOCAPIC","ESTRELLITAS","FITNESS","FITNESS FRUITS","FITNESS MIEL Y ALMENDRAS","GRANOLA AVENA MIEL Y PASAS") |  inlist(n_product2,"HEARTS","GRANOLA BAJA EN GRASAS CEREALS & FRUITS","GRANOLA TRADICIONAL CEREALS & FRUITS","AVENA CLUSTERS BERRIES","BRUNCH FRUTOS ROJOS") |  inlist(n_product2,"CHECK 3 CEREALES","CHECK CACAO","CHECK YOGHURT","GRANOLA CACAO","MUESLI 5 CEREALES","MUESLI CACAO")

foreach var in "maltitol" "sucralosa" "stevia" {
	di "`var'"
	sum max_`var' 
	
}




*********************************************************************************************************
*********************************************************************************************************
*** TEMPORAL																	   					 ****
*********************************************************************************************************
*********************************************************************************************************


******************************************************************************** 
** SET PATH AND LOCALS
******************************************************************************** 

if c(username)=="Nano"   		  global Dropbox "/Users/Nano/Dropbox/Research/FoodLabels/FoodLabels_shared"
if c(username)=="sotero" 		  global Dropbox "/Users/sotero/Dropbox (Personal)/Research/Chile/FoodLabels/FoodLabels_shared"
if c(username)=="Nine" 			  global Dropbox "/Users/nine/Dropbox/FoodLabels/FoodLabels_shared"
if c(username)=="cristobalotero"  global Dropbox "/Users/cristobalotero/Dropbox/Research/Food labels/FoodLabels_shared"

local ver="02_product" // 01_nutrition/02_product

global output "${Dropbox}/02_analysis/03_output/16_priceAndPackage/`ver'"

******************************************************************************** 
** LOAD DATA
******************************************************************************** 


use "${Dropbox}/03_model/04_model_v4/01_cereals/01_data/04_marketLevel_cereals_nobins.dta", clear 
keep week store_id nutrition_id quantity sales_final sales_raw p quantity_unit
foreach var in quantity sales_final sales_raw p quantity_unit {
	ren `var' `var'_old
}
gen av_package_size = quantity_old/quantity_unit_old
tempfile old_data
save `old_data', replace

use "${Dropbox}/03_model/04_model_v4/01_cereals/01_data/04_marketLevel_cereals_nobins.dta", clear 
keep l_sug l_cal   nutrition_id 
duplicates drop
tempfile nut_data
save `nut_data', replace

use "${Dropbox}/01_build/02_data/nutrition/categories/09369_cereals_nutrition.dta", clear  
keep product_id nutrition_id name brand sell_q
destring sell_q, replace dpcomma
egen package_size = mean(sell_q), by(product_id)
drop sell_q
duplicates drop
drop if product_id == "824656" &	nutrition_id=="834055"
drop if product_id == "824654" & 	nutrition_id=="824654"
tempfile prod_data
save `prod_data', replace


if "`ver'"=="01_nutrition" {
use "${Dropbox}/01_build/02_data/cereals/05_cereals_nutr_8.dta", clear 
}
if "`ver'"=="02_product" {
use "${Dropbox}/01_build/02_data/cereals/05_cereals_prod_8.dta", clear 
merge n:1 product_id using `prod_data'
keep if _merge==3
drop _merge
}


*********************************************************************************************************
*********************************************************************************************************
*** CLEAN DATA																	   					 ****
*********************************************************************************************************
*********************************************************************************************************

******************************************************************************** 
** IMPORT NUTRITION ID INFORMATION AND DEFINE PRODUCT CHARACTERISTICS
******************************************************************************** 

preserve
use "${Dropbox}/01_build/02_data/nutrition/categories/09369_cereals_nutrition", clear
merge 1:1 upc_id using "${Dropbox}/01_build/02_data/nutrition/products_raw"
keep if _merge==3
gen new_fineline = ""
replace new_fineline = "AVENA" if (inlist(fineline,1155,2125,2150) | inlist(nutrition_id,"293841"))
replace new_fineline = "HOJUELAS" if inlist(fineline, 1165) | inlist(nutrition_id,"486384","293841","282821","492751","492753","492755","492757","492763","765041") ///
										| inlist(nutrition_id,"822108","765045","903783","825341","834055","903781","906175","887474")
replace new_fineline = "AZUCARADO" if inlist(fineline,2025) | inlist(nutrition_id,"268222","295955","3239"."707185","707185","2759","298043","715184","298569","437421") ///
										| inlist(nutrition_id,"822106","822110","824652","770898","699608","699606","526568","898082","915382") ///
										| inlist(nutrition_id,"901216","824656","845912","848728","884046","884048","887450","905467","905854") ///
										| inlist(nutrition_id,"906177","901218") 
replace new_fineline = "CHOCOLATE" if inlist(fineline,2050) | inlist(nutrition_id,"279037","289853","289891","381128","743410","848532","910015","913552","760960") ///
										| inlist(nutrition_id,"764989","770902","707557","707553","915380","834057","905465","905852") ///
										| inlist(nutrition_id,"272768","665323") 
replace new_fineline = "DILATADO" if inlist(fineline,2075) | inlist(nutrition_id,"2739","2743","2747","297367","298551","486380","454600")
replace new_fineline = "GRANOLA" if inlist(fineline,4950,1195) | inlist(nutrition_id,"834065","765039","765043","826085","824654","700034")
gen healthy = inlist(fineline,1185,1195,1205,1975,4950,1195,1155,2125,2150,6050)
replace healthy = 0 if inlist(nutrition_id,"298043")
replace healthy = 1 if inlist(nutrition_id,"282821","822110","824652","834055","834057","834065","848728","903783","915382")
duplicates drop nutrition_id name brand Lcal Lsug Lsod Lfat cal_post cal_pre sug_post sug_pre sod_post sod_pre fat_post fat_pre new_fineline healthy, force
keep nutrition_id new_fineline
cap tempfile temp
save `temp', replace
restore

merge n:1 nutrition_id using `temp'
keep if _merge==3
drop _merge

merge n:1 nutrition_id using "${Dropbox}/01_build/02_data/beliefs/categories/09369_cereals_beliefs_final"
keep if _merge==3
drop _merge brand_name fineline known_cal w_cal w_post_cal p_cal time_cal l_cal muse_cal obs_cal known_sug w_sug w_post_sug p_sug time_sug l_sug muse_sug obs_sug


drop if brand == "GO OATS-15404"

destring store_id, replace
gen p = sales_final/(quantity*10*650)

/*
merge 1:1 nutrition_id store_id week using `old_data'
order store_id week nutrition_id p p_old quantity* sales_raw* sales_final*
*/

merge n:1 nutrition_id using `nut_data'
drop _merge

gen policy= floor((61-1)/8)+1         
gen penetration = floor((44-1)/8)+1
gen post = week>policy

gen trunsales = round(sales_final)*(1-post)

egen unique_nutrition = tag(nutrition_id)
egen unique_nutrition_post = tag(nutrition_id post)
count if unique_nutrition_post==1 & post==0
local nutrs = r(N)

spread mu_cal mu_sug , by(nutrition_id)

merge n:1 nutrition_id store_id week using `old_data'
drop if _merge==2
drop _merge

cap tempfile temp_main
save `temp_main', replace




********************************************************************************
**			DIFF IN DIFF
********************************************************************************



use `temp_main', clear

ren p price

egen id = group(nutrition_id store_id)
duplicates tag id , gen(dups)

local jointweeks = 8
local clust = "nutrition_id"
local lastweek = floor((152-1)/8)+1
local policy= floor((61-1)/8)+1          //the policy starts in week 61 and weeks are: floor((week-1)/`jointweeks')+1
local penetration = floor((44-1)/8)+1
local reference = `penetration'+1
*local reference = `penetration'
local treat = "cal"
local aggr = "nutr"
local categ = "cereals"
local categ = ""

forv x=1/`lastweek'{
gen TT`x'_l_`treat'=(week==`x')*l_`treat'
}
gen TP_`treat' = post*l_`treat'

** we drop the dummy before policy implementation
local y = `reference'
drop TT`y'_l_`treat'

local maxweights = 1
if "`ver'"=="02_product" {
local maxweights = 2
}

foreach outcome in "sales_final" "quantity" "price" "av_package_size"  { 

** We calculate the main outcomes:
gen log_outcome = log(`outcome')

local function = "log_outcome"

forv balanced = 0/1 {


forv weighted = 0/`maxweights' {


if "`function'" == "log_outcome" {
local funtit = "log"
}
else if "`function'" == "asinh_outcome" {
local funtit = "asinh"
}
if "`outcome'" == "sales_final" {
local ytit2 = "revenue"
}
else if "`outcome'" == "quantity" {
local ytit2 = "q"
}
else if "`outcome'" == "price" {
local ytit2 = "p"
}
else if "`outcome'" == "av_package_size" {
local ytit2 = "size"
}
else if "`outcome'" == "discounts" {
local ytit2 = "d"
}


preserve 


if `balanced'== 1 {
keep if dups>=`lastweek'-1
}

if `weighted' == 1 {
gen temp = sales_final*(week<=`penetration')
egen weight_sales1 = total(temp), by(id) 
if `balanced'== 0 & inlist("`outcome'","quantity") {
hist weight_sales1 , name(z`balanced'`weighted'_weights,replace)
}
}
else if `weighted' == 0 {
gen weight_sales1 = 1
}
else if `weighted' == 2 {
gen weight_sales1 = package_size
if `balanced'== 0 & inlist("`outcome'","quantity") {
hist weight_sales1 , name(z`balanced'`weighted'_weights,replace)
}
}


di ""
di "outcome: `outcome', balanced: `balanced', weights: `weighted'"
di ""

gen positive_weights = (weight_sales1>0)
egen unique_clus = tag(`clust' positive_weights)
	
xi: areg `function' TP* 	i.week		[aw = 	weight_sales1]	if week<=`penetration' | week>`policy'			, a(id) cl(`clust')
	
xi: areg `function' TT*l_`treat' 	i.week		[aw = 	weight_sales1]			, a(id) cl(`clust')
mat beta10 = e(b)
mat cov10  = e(V)
local numcl =  e(N_clust) 
local numob =  e(N)

count if unique_clus==1 & l_`treat'==1 & positive_weights==1
local numtr = r(N)

count if unique_clus==1 & l_`treat'==0 & positive_weights==1
local numctr = r(N)


plotCoefficients "02" "beta10" "cov10" `policy' `lastweek' `penetration' `reference' `aggr' `funtit' `ytit2' `balanced' `weighted' `treat' `jointweeks' `numcl' `numob' "`categ'" `numtr' `numctr' 0


if inlist("`outcome'","quantity") {

di "03_`outcome'_`weighted'_`balanced'"

replace price = log(price)

xi: areg `function' TP* 	i.week	price	[aw = 	weight_sales1]	if week<=`penetration' | week>`policy'		, a(id) cl(`clust')
	
xi: areg `function' TT*l_`treat' 	i.week	price	[aw = 	weight_sales1]			, a(id) cl(`clust')
mat beta10 = e(b)
mat cov10  = e(V)
local numcl =  e(N_clust) 
local numob =  e(N)


plotCoefficients "03" "beta10" "cov10" `policy' `lastweek' `penetration' `reference' `aggr' `funtit' `ytit2' `balanced' `weighted' `treat' `jointweeks' `numcl' `numob' "`categ'" `numtr' `numctr' 0







/*
egen week_market = group(week store_id)
xi: areg `function' TT*l_`treat' 	i.nutrition_id	price	[aw = 	weight_sales1]			, a(week_market) cl(`clust')
mat beta10 = e(b)
mat cov10  = e(V)
local numcl =  e(N_clust) 
local numob =  e(N)


plotCoefficients "03b_delete" "beta10" "cov10" `policy' `lastweek' `penetration' `reference' `aggr' `funtit' `ytit2' `balanced' `weighted' `treat' `jointweeks' `numcl' `numob' "`categ'" `numtr' `numctr' 0
*/



}

restore
	
}
	
}

drop log_outcome

}




********************************************************************************
**			NUMBER OF PRODUCTS
********************************************************************************

use `temp_main', clear

local jointweeks = 8
local clust = "nutrition_id"
local lastweek = floor((152-1)/8)+1
local policy= floor((61-1)/8)+1          //the policy starts in week 61 and weeks are: floor((week-1)/`jointweeks')+1
local penetration = floor((44-1)/8)+1
local reference = `penetration'+1
local treat = "cal"
local aggr = "nutr"
local categ = "cereals"
local categ = ""


egen number_of_products = tag(nutrition_id store week)
gen temp = sales_final if post==0 
egen weight_sales1 = total(temp), by(store)

collapse (sum) number_of_products (mean)  weight_sales1 , by(store week)

gen log_outcome = log(number_of_products)



xi: areg log_outcome	i.week		[aw = 	weight_sales1]		, a(store) cl(store) 
mat beta10 = e(b)
mat cov10  = e(V)
local numcl =  e(N_clust) 
local numob =  e(N)


plotFE "04" "beta10" "cov10" `policy' `lastweek' `penetration' `reference' `aggr' "log" "number of products" 0 0 0 `jointweeks' `numcl' `numob' "`categ'" 0 0 0



********************************************************************************
**			PACKAGE SIZE SUPPLY
********************************************************************************

use `temp_main', clear

egen id = group(nutrition_id store_id)
duplicates tag id , gen(dups)

local jointweeks = 8
local clust = "nutrition_id"
local lastweek = floor((152-1)/8)+1
local policy= floor((61-1)/8)+1          //the policy starts in week 61 and weeks are: floor((week-1)/`jointweeks')+1
local penetration = floor((44-1)/8)+1
local reference = `penetration'+1
local base = 5
local treat = "cal"
local aggr = "nutr"
local categ = "cereals"
local categ = ""

replace av_package_size = package_size

collapse (mean) av_package_size l_sug l_cal policy penetration (first) nutrition_id id dups post, by(week product_id store_id)

forv x=1/`lastweek'{
gen TT`x'_l_`treat'=(week==`x')*l_`treat'
}
gen TP_`treat' = post*l_`treat'

** we drop the dummy before policy implementation
local y = `base'
drop TT`y'_l_`treat'



local outcome = "av_package_size"

gen log_outcome = log(`outcome')

local function = "log_outcome"

forv balanced = 0/1 {


forv weighted = 0/0 {


if "`function'" == "log_outcome" {
local funtit = "log"
}
if "`outcome'" == "av_package_size" {
local ytit2 = "size"
}


preserve 


if `balanced'== 1 {
keep if dups>=`lastweek'-1
}

gen weight_sales1 = 1



di ""
di "outcome: `outcome', balanced: `balanced', weights: `weighted'"
di ""

gen positive_weights = (weight_sales1>0)
egen unique_clus = tag(`clust' positive_weights)
	
xi: areg `function' TP* 	i.week		[aw = 	weight_sales1]	if week<=`penetration' | week>`policy'			, a(id) cl(`clust')
	
xi: areg `function' TT*l_`treat' 	i.week		[aw = 	weight_sales1]			, a(id) cl(product_id)
mat beta10 = e(b)
mat cov10  = e(V)
local numcl =  e(N_clust) 
local numob =  e(N)

count if unique_clus==1 & l_`treat'==1 & positive_weights==1
local numtr = r(N)

count if unique_clus==1 & l_`treat'==0 & positive_weights==1
local numctr = r(N)


plotCoefficients "05" "beta10" "cov10" `policy' `lastweek' `penetration' `base' `aggr' `funtit' `ytit2' `balanced' `weighted' `treat' `jointweeks' `numcl' `numob' "`categ'" `numtr' `numctr' 0

restore

}
}


