
%% PREAMBLE

clc
clear all
close all
rng(2020)
tic

path = './';
addpath([path,'03_estimation/99_functions/'])
addpath([path,'03_estimation/01_demand/'])

fprintf('\n------------------------------------------------------------\n');
fprintf(' DEMAND MODEL ESTIMATION ');
fprintf('\n------------------------------------------------------------\n');

global J  X Z market market_product muw_fixed sigma_mu vp_ind vf_ind bins_weights_micro ind_dummies_micro market_bin f ns sigma_ratio wmatrix wbar post product ...
    product_bins exempted l individual_bins X s s_g vp_ind vf_ind logitvar maxiters delta_tol f ns ind_dummies_micro bins_weights_micro market_x market_y index


ktropts = optimset('TolFun',1E-09,'TolX',1E-24,'TolCon',1E-24); 


%% LOAD DATA AND GENERATE RELEVANT VARIABLES
disp(' ')
disp('Step 1: Loading the data...')

a01_loadData;

disp(['Data loaded after: ', num2str(toc/60), ' minutes.'])

%% DEFINE FIXED EFFECTS

fe = [xi_j_micro(:,1:length(xi_j_micro(1,:))-2),xi_t_micro(:,1:length(xi_t_micro(1,:))-2),xi_s_micro(:,1:length(xi_s_micro(1,:))-2),ind_dummies_micro(:,1:length(ind_dummies_micro(1,:))-1),ones(length(p),1)];
fe = licols(fe);

%% DEFINE INSTRUMENTS

X = [repmat(p,[1,2]).*ind_dummies_micro,fe];
Z = [repmat(p_z,[1,2]).*expand(ind_dummies_micro,[1,length(p_z(1,:))]),repmat(z_Ew,[1,2]).*expand(ind_dummies_micro,[1,length(z_Ew(1,:))]),repmat(z_i,[1,2]).*expand(ind_dummies_micro,[1,length(z_i(1,:))]),fe]; 
Z = licols(Z);
wmatrix = inv(Z'*Z);

disp(['Instruments and fixed effects created after: ', num2str(toc/60), ' minutes.'])

%% ESTIMATION

disp(' ')
disp('Step 2: Estimating RCNL model...')

x01 = [-1.38,-1.68,-3.36,-3.4,-5.17,-5.15];
x02 = [0.03,-0.56,1.65];  
x03 = -log(1/(0.96)-1);
x04 = tan(pi*(0.37)/(5*2)); 
x05 = [0.06,0.2,-0.21,0.03,0.3];


objFun = @(x) a02_ComputeDistanceVector(x(1:6),x(7:9),x(10),x(11),x(12:16));
x0 = [x01,x02,x03,x04,x05];

xl = [-Inf*ones(1,6),-2*ones(1,3),-Inf,-Inf,-ones(size(x05))];
xu = [ones(1,6),2*ones(1,3),4.6,Inf,ones(size(x05))];

[xsol,~] = knitromatlab(objFun,x0,[],[],[],[],xl,xu,[],[],ktropts,[path,'03_estimation/99_functions/knitroOpts.opt']);

x01 = xsol(1:6);
x02 = xsol(7:9);
x03 = xsol(10);
x04 = xsol(11);
x05 = xsol(12:16);

[G,dG,betahat,delta,moments,dmoments,e,V,si,sig] = a02_ComputeDistanceVector(x01,x02,x03,x04,x05,1);

%% SAVING OUTPUT

disp(' ')
disp('Step 3: Saving output...')

rho_hat = 1./(1+exp(-[x03,x03]));
mu_hat = 5*(2/pi)*atan(x04);
mu_hat = [mu_hat,sigma_ratio*mu_hat];
mu_param = std(cal_pre)*mu_hat(1);

alpha_hat = [x01(1),x01(2)];
phi_cal_hat = [x01(3),x01(4)];
phi_sug_hat = [x01(5),x01(6)];
alpha_i = -exp(sum([x01(1),x01(2)].*ind_dummies_micro,2)-(x02(1)*vp_ind(:,2)'));
phic_i  = -exp(sum([x01(3),x01(4)].*ind_dummies_micro,2)-(x02(2)*vp_ind(:,3)'));
phis_i  = -exp(sum([x01(5),x01(6)].*ind_dummies_micro,2)-(x02(3)*vp_ind(:,4)'));
alpha_mean = [exp(x01(1)+x02(1)/2),exp(x01(2)+x02(1)/2)];
phic_mean = [exp(x01(3)+x02(2)/2),exp(x01(4)+x02(2)/2)];
phis_mean = [exp(x01(5)+x02(3)/2),exp(x01(6)+x02(3)/2)];
sigma_alpha = [sqrt(exp(x02(1)^2-1)*exp(2*x01(1)+x02(1)^2)),sqrt(exp(x02(1)^2-1)*exp(2*x01(2)+x02(1)^2))];
sigma_phic = [sqrt(exp(x02(2)^2-1)*exp(2*x01(3)+x02(2)^2)),sqrt(exp(x02(2)^2-1)*exp(2*x01(4)+x02(2)^2))];
sigma_phis = [sqrt(exp(x02(3)^2-1)*exp(2*x01(5)+x02(3)^2)),sqrt(exp(x02(3)^2-1)*exp(2*x01(6)+x02(3)^2))];
Der_Vp = [alpha_mean(1),0,0,0,0,0,alpha_mean(1)/2,0,0; ...
         0,alpha_mean(2),0,0,0,0,alpha_mean(2)/2,0,0; ... 
         0,0,phic_mean(1),0,0,0,0,phic_mean(1)/2,0; ... 
         0,0,0,phic_mean(2),0,0,0,phic_mean(2)/2,0; ... 
         0,0,0,0,phis_mean(1),0,0,0,phis_mean(1)/2; ... 
         0,0,0,0,0,phis_mean(2),0,0,phis_mean(2)/2; ... 
         (1/(2*sigma_alpha(1)))*exp(2*x01(1)+x02(1)^2)*2,0,0,0,0,0,(x02(1)/(sigma_alpha(1)))*(2*sigma_alpha(1)^2+exp(2*x01(1)+x02(1)^2)),0,0; ...
         0,(1/(2*sigma_alpha(2)))*exp(2*x01(2)+x02(1)^2)*2,0,0,0,0,(x02(1)/(sigma_alpha(2)))*(2*sigma_alpha(2)^2+exp(2*x01(2)+x02(1)^2)),0,0; ...
         0,0,(1/(2*sigma_phic(1)))*exp(2*x01(3)+x02(2)^2)*2,0,0,0,0,(x02(2)/(sigma_phic(1)))*(2*sigma_phic(1)^2+exp(2*x01(3)+x02(2)^2)),0; ...
         0,0,0,(1/(2*sigma_phic(2)))*exp(2*x01(4)+x02(3)^2)*2,0,0,0,(x02(2)/(sigma_phic(2)))*(2*sigma_phic(2)^2+exp(2*x01(4)+x02(2)^2)),0; ...
         0,0,0,0,(1/(2*sigma_phis(1)))*exp(2*x01(5)+x02(3)^2)*2,0,0,0,(x02(3)/(sigma_phis(1)))*(2*sigma_phis(1)^2+exp(2*x01(5)+x02(3)^2)); ...
         0,0,0,0,0,(1/(2*sigma_phis(2)))*exp(2*x01(6)+x02(3)^2)*2,0,0,(x02(3)/(sigma_phis(2)))*(2*sigma_phis(2)^2+exp(2*x01(6)+x02(3)^2)); ...
         ];
Der_Vs = eye(7);
Der_Vs(2,2) = std(cal_pre);
Der_V = [Der_Vp, zeros(12,7); zeros(7,9),Der_Vs];
params = [alpha_mean';phic_mean';phis_mean';sigma_alpha';sigma_phic';sigma_phis';rho_hat(1);mu_param;abs(x05)'];
V_params = Der_V*V*Der_V';
sd_params = sqrt(diag(V_params));
stars_param = (abs(params./sd_params)>1.64)+(abs(params./sd_params)>1.96)+(abs(params./sd_params)>2.58);


Sigma_hat = [x02,x05];
indiv_shares_hat = si;

start = 1; 

xi_j_hat = [betahat(start:2:start+2*(J-2)),betahat(start+1:2:start+1+2*(J-2));0,0];
xi_t_hat = [betahat(start+1+2*(J-2)+1:2:start+1+2*(J-2)+1+2*(T-2)),betahat(start+1+2*(J-2)+2:2:start+1+2*(J-2)+1+2*(T-2)+1);0,0];
xi_s_hat = [betahat(start+1+2*(J-2)+1+2*(T-2)+2:2:start+1+2*(J-2)+1+2*(T-2)+2+2*(S-2)),betahat(start+1+2*(J-2)+1+2*(T-2)+3:2:start+1+2*(J-2)+1+2*(T-2)+2+2*(S-2)+1);0,0];
beta0_hat = [betahat(start+1+2*(J-2)+1+2*(T-2)+2+2*(S-2)+2)+betahat(start+1+2*(J-2)+1+2*(T-2)+2+2*(S-2)+3),betahat(start+1+2*(J-2)+1+2*(T-2)+2+2*(S-2)+3)];
xi_hat = e;
mean_utility = delta;

sigma_mu_hat = sigma_mu;

[Ew_hat,~,beliefs,muw_hat] = a03_calculatePosteriors(mu_hat,muw,sigma_mu);

save([path,'00_files/04_estimates/01_demand/01_demandparams'],'alpha_hat','phi_cal_hat','phi_sug_hat','Sigma_hat','rho_hat','sigma_mu_hat','xi_j_hat','xi_t_hat','xi_s_hat','beta0_hat','muw_hat','xi_hat','data','names','Ew_hat','vp_ind','vf_ind','indiv_shares_hat','params','stars_param','sd_params')

%% SUMMARY STATISTICS

disp(' ')
disp('Step 4: Print tables...')

% number of total customers
num_customers_panel_cereal = 524327;
num_customers_panel_cereal_clean = 468142;
num_customers_panel_cereal_type = [229647;238495];
num_years = 17*8/52;

% kg per cereal consumed
tot_kg_type = accumarray(individual_bins,portion_size_bin.*market_size_bin.*s);
tot_kg_percapyear = sum(tot_kg_type)/sum(num_customers_panel_cereal_type)/num_years;
tot_kg_percapyear_type = (tot_kg_type./num_customers_panel_cereal_type)/num_years;
tot_shares = accumarray(product,portion_size_bin.*market_size_bin.*s)/sum(portion_size_bin.*market_size_bin/J);
tot_shares = [tot_shares;1-sum(tot_shares)];

% dollars spent
tot_dollars_type = accumarray(individual_bins,portion_size_bin.*market_size_bin.*s.*p*10);
tot_dollars_percapyear = sum(tot_dollars_type)/sum(num_customers_panel_cereal_type)/num_years;
tot_dollars_percapyear_type = (tot_dollars_type./num_customers_panel_cereal_type)/num_years;

% weights
market_product_bins = findgroups(market,product,individual_bins);
market_product = findgroups(market,product);
product_type = findgroups(individual_bins,product);
temp = accumarray(market_product,portion_size_bin.*market_size_bin);
weights = portion_size_bin.*market_size_bin./temp(market_product);
temp = accumarray(market_bin,weights,[],@mode);
weights_unif = temp(market_bin);
prod_weights = accumarray(product,10*portion_size_bin.*market_size_bin.*s.*p.*(1-post))/sum(accumarray(product,10*portion_size_bin.*market_size_bin.*s.*p.*(1-post)));

% share of low income by market
temp = accumarray(market_bin,market_size_bin,[],@mode);
temp2 = accumarray(market_bin,market,[],@mode);
temp3 = accumarray(market_bin,individual_bins,[],@mode);
temp4 = accumarray(temp2,temp);
temp4 = temp4(temp2);
share_poor = temp(temp3==1)./temp4(temp3==1);
market_ids = temp2(temp3==1);
tot_shares_poor = accumarray(product(ismember(market,market_ids(share_poor>0.7))),portion_size_bin(ismember(market,market_ids(share_poor>0.7))).*market_size_bin(ismember(market,market_ids(share_poor>0.7))).*s(ismember(market,market_ids(share_poor>0.7))))/sum(portion_size_bin(ismember(market,market_ids(share_poor>0.7))).*market_size_bin(ismember(market,market_ids(share_poor>0.7)))/J);
tot_shares_poor = [tot_shares_poor;1-sum(tot_shares_poor)];
tot_shares_rich = accumarray(product(ismember(market,market_ids(share_poor<0.2))),portion_size_bin(ismember(market,market_ids(share_poor<0.2))).*market_size_bin(ismember(market,market_ids(share_poor<0.2))).*s(ismember(market,market_ids(share_poor<0.2))))/sum(portion_size_bin(ismember(market,market_ids(share_poor<0.2))).*market_size_bin(ismember(market,market_ids(share_poor<0.2)))/J);
tot_shares_rich = [tot_shares_rich;1-sum(tot_shares_rich)];

% elasticities
alpha_micro = -alpha_i;
rho_micro   = repmat(sum(rho_hat.*ind_dummies_micro,2),[1,ns]);
s_wide = fillPanel(si,0);
s_wide(:,J+1) = (1-sum(s_wide,2));
s_g_wide = fillPanel(sig,0);
p_wide = fillPanel(repmat(p,[1,ns]),0);
alpha_wide = fillPanel(alpha_micro,NaN);
rho_wide = fillPanel(rho_micro,NaN);
rho_wide(:,J+1) = mode(rho_wide,2);
weights_wide = fillPanel(repmat(weights,[1,ns]),0).*fillPanel(bins_weights_micro,0);
weights_wide_unif = fillPanel(repmat(weights_unif,[1,ns]),NaN).*fillPanel(bins_weights_micro,NaN);
weights_wide_unif(:,J+1) = mode(weights_wide_unif,2);
weights_wide_unif(isnan(weights_wide_unif))=0;
weights_wide(:,J+1) = weights_wide_unif(:,J+1);
market_wide = expand(repmat(extractData(market_bin, market),[1,J+1]),[ns,1]);

[median_elast_mat,median_diversion_mat] = a07_calculateElast(s_wide,s_g_wide,p_wide,weights_wide_unif,alpha_wide,rho_wide,market_wide,market_ids);
[median_elast_poor,median_diversion_poor] = a07_calculateElast(s_wide,s_g_wide,p_wide,weights_wide_unif,alpha_wide,rho_wide,market_wide,market_ids(share_poor>0.7)); 
[median_elast_rich,median_diversion_rich] = a07_calculateElast(s_wide,s_g_wide,p_wide,weights_wide_unif,alpha_wide,rho_wide,market_wide,market_ids(share_poor<0.2)); 

median_elast = median(diag(median_elast_mat)); % This number goes to paper
median_elast_1 = median(diag(median_elast_poor)); % This number goes to paper
median_elast_2 = median(diag(median_elast_rich)); % This number goes to paper


% print tables
a08_printTables


% willingness to pay
ns = 10000;
v = linspace(ns/10,9*ns/10,ns)'/ns;
v = norminv(v);
v1 = zeros(ns,14);
for i=1:4
    v1(:,i) = v(randperm(length(v)));
end

vp_ind = v1(:,1:4);

alpha_het = -exp(alpha_hat-x02(1)*vp_ind(:,2));
phi_cal_het = -exp(phi_cal_hat-x02(2)*vp_ind(:,3));
phi_sug_het = -exp(phi_sug_hat-x02(3)*vp_ind(:,4));

p_mean = sum(10*portion_size_bin.*market_size_bin.*s.*p.*(1-post).*p)/sum(10*portion_size_bin.*market_size_bin.*s.*p.*(1-post));
will_to_pay_cal = mean(phi_cal_het./alpha_het)*sqrt(weightedcov(extractData(product,cal_pre),prod_weights))/p_mean;
will_to_pay_sug = mean(phi_sug_het./alpha_het)*sqrt(weightedcov(extractData(product,sug_pre),prod_weights))/p_mean;
will_to_pay_cal_het = (phi_cal_het./alpha_het)*sqrt(weightedcov(extractData(product,cal_pre),prod_weights))/p_mean;
will_to_pay_sug_het = (phi_sug_het./alpha_het)*sqrt(weightedcov(extractData(product,sug_pre),prod_weights))/p_mean;
will_to_pay_cash_cal = 10*tot_kg_percapyear_type'.*mean(phi_cal_het./alpha_het)*sqrt(weightedcov(extractData(product,cal_pre),prod_weights));
will_to_pay_cash_sug = 10*tot_kg_percapyear_type'.*mean(phi_sug_het./alpha_het)*sqrt(weightedcov(extractData(product,sug_pre),prod_weights));

will_to_pay_cal_het = 100*will_to_pay_cal_het;
will_to_pay_sug_het = 100*will_to_pay_sug_het;

av_will_to_pay_cal = mean(will_to_pay_cal_het(:)); % This number goes to paper
av_will_to_pay_sug = mean(will_to_pay_sug_het(:)); % This number goes to paper

will_to_pay_cheerios_sug = mean(phi_sug_het(:)./alpha_het(:))*(3.25-0.5)*5.5;  % This number goes to paper

xrage_cal = [0,30];
xrage_sug = [0,80];

xrage=xrage_cal;

figure('visible','on')
hold on
range=[min(min(will_to_pay_cal_het(:,1))*0.9,min(will_to_pay_cal_het(:,1))*1.1),max(max(will_to_pay_cal_het(:,1))*0.9,max(will_to_pay_cal_het(:,1))*1.1)];
pdk = fitdist(will_to_pay_cal_het(:,1),'Kernel','BandWidth',(range(2)-range(1))/30);
x = linspace(min(xrage(1),min(will_to_pay_cal_het(:,1))),max(xrage(2),max(will_to_pay_cal_het(:,1))),500);
ypdf = pdf(pdk,x);
h1=plot(x,ypdf,'Color',[0.9290 0.6940 0.1250],'LineWidth',5);
range=[min(min(will_to_pay_cal_het(:,2))*0.9,min(will_to_pay_cal_het(:,2))*1.1),max(max(will_to_pay_cal_het(:,2))*0.9,max(will_to_pay_cal_het(:,2))*1.1)];
pdk = fitdist(will_to_pay_cal_het(:,2),'Kernel','BandWidth',(range(2)-range(1))/30);
x = linspace(min(xrage(1),min(will_to_pay_cal_het(:,2))),max(xrage(2),max(will_to_pay_cal_het(:,2))),500);
ypdf = pdf(pdk,x);
h2=plot(x,ypdf,'Color',[0 0.4470 0.7410],'LineWidth',5,'LineStyle','--');
xlim([min(xrage(1),min(min(will_to_pay_cal_het))) max(xrage(2),max(max(will_to_pay_cal_het)))])
xlabel('Willigness to pay to decrease calorie content (\%)', 'Interpreter', 'latex', 'FontSize', 26);
ylabel('Density', 'Interpreter', 'latex', 'FontSize', 26);
set(gca,'FontSize',18,'TickLabelInterpreter','latex')
legend([h1,h2],{'low-SES','high-SES'}, 'Interpreter', 'latex', 'FontSize', 20,'Location','SouthOutside','Orientation','Horizontal','NumColumns',2);
set(gcf, 'Units', 'Inches', 'Position', [0, 0, 8.25, 6], 'PaperUnits', 'Inches', 'PaperSize', [8.25, 5.6])
print([path,'00_files/06_figures/02_estimation/figure4b.pdf'] , '-dpdf')

xrage=xrage_sug;

figure('visible','on')
hold on
range=[min(min(will_to_pay_sug_het(:,1))*0.9,min(will_to_pay_sug_het(:,1))*1.1),max(max(will_to_pay_sug_het(:,1))*0.9,max(will_to_pay_sug_het(:,1))*1.1)];
pdk = fitdist(will_to_pay_sug_het(:,1),'Kernel','BandWidth',(range(2)-range(1))/30);
x = linspace(min(xrage(1),min(will_to_pay_sug_het(:,1))),max(xrage(2),max(will_to_pay_sug_het(:,1))),500);
ypdf = pdf(pdk,x);
h1=plot(x,ypdf,'Color',[0.9290 0.6940 0.1250],'LineWidth',5);
range=[min(min(will_to_pay_sug_het(:,2))*0.9,min(will_to_pay_sug_het(:,2))*1.1),max(max(will_to_pay_sug_het(:,2))*0.9,max(will_to_pay_sug_het(:,2))*1.1)];
pdk = fitdist(will_to_pay_sug_het(:,2),'Kernel','BandWidth',(range(2)-range(1))/30);
x = linspace(min(xrage(1),min(will_to_pay_sug_het(:,2))),max(xrage(2),max(will_to_pay_sug_het(:,2))),500);
ypdf = pdf(pdk,x);
h2=plot(x,ypdf,'Color',[0 0.4470 0.7410],'LineWidth',5,'LineStyle','--');
xlim([min(xrage(1),min(min(will_to_pay_sug_het))) max(xrage(2),max(max(will_to_pay_sug_het)))])
xlabel('Willigness to pay to decrease sugar content (\%)', 'Interpreter', 'latex', 'FontSize', 26);
ylabel('Density', 'Interpreter', 'latex', 'FontSize', 26);
set(gca,'FontSize',18,'TickLabelInterpreter','latex')
legend([h1,h2],{'low-SES','high-SES'}, 'Interpreter', 'latex', 'FontSize', 20,'Location','SouthOutside','Orientation','Horizontal','NumColumns',2);
set(gcf, 'Units', 'Inches', 'Position', [0, 0, 8.25, 6], 'PaperUnits', 'Inches', 'PaperSize', [8.25, 5.6])
print([path,'00_files/06_figures/02_estimation/figure4a.pdf'] , '-dpdf')


T1 = table(median_elast,median_elast_1,median_elast_2,av_will_to_pay_cal,av_will_to_pay_sug,will_to_pay_cheerios_sug);
T1.Properties.VariableNames = {'median own elast','median own elast (lowSES)','median own elast (highSES)','wtp calories (%)','wtp sugar (%)','wtp cheerios ($)'};
writetable(T1,[path,'00_files/07_outputs/01_demand/04_numbers_to_draft.csv'],'Delimiter',',','QuoteStrings',true)

T2 = table(will_to_pay_sug_het(:,1),will_to_pay_sug_het(:,2),will_to_pay_cal_het(:,1),will_to_pay_cal_het(:,2));
T2.Properties.VariableNames = {'wtp_low_sug','wtp_high_sug','wtp_low_cal','wtp_high_cal'};
writetable(T2,[path,'00_files/07_outputs/01_demand/05_numbers_to_plot.csv'],'Delimiter',',','QuoteStrings',true)

