
%% LOAD DATA

data       = readtable([path,'00_files/03_data/01_marketLevel_cereals_bins.csv']);

names = table2array(data(:,50:51));
data = [table2array(data(:,1:49)),table2array(data(:,54:55)),table2array(data(:,52:53)),table2array(data(:,56:63)),table2array(data(:,64:79)),table2array(data(:,80:178)),table2array(data(:,179:183))];


ns = 20; 
v = linspace(ns/10,9*ns/10,ns)'/ns;
v = norminv(v);
v1 = zeros(ns,14);
for i=1:14
    v1(:,i) = v(randperm(length(v)));
end

vp_ind = v1(:,1:4);
vx_ind = v1(:,5:9);
vf_ind = v1(:,10:14);

bins_weights_micro = ones(ns,1)/ns;
bins_weights_micro = repmat(bins_weights_micro',[length(data(:,1)),1]);

%% NAME VARIABLES
week = data(:,1);
store = data(:,2);
market = data(:,3);
market_bin = data(:,4);
product = data(:,5);
brand = data(:,6);
holding = data(:,60);
fineline = data(:,7);
x = data(:,177:181);
healthy = data(:,8);
exempted = data(:,9);
s = data(:,10);
s0 = data(:,11);
s_g = data(:,12);
s_f = data(:,13);
s_h = data(:,14);
p = data(:,15);
sug = data(:,16);
sug_pre = data(:,17);
cal = data(:,18);
cal_pre = data(:,19);
post = data(:,20);
L_sug = data(:,21);
l_sug = data(:,22);
L_cal = data(:,23);
l_cal = data(:,24);
mu_sug = data(:,25);
mu_cal = data(:,26);
sigma_sug = data(:,27);
sigma_cal = data(:,28);
package = data(:,29);
p_z1 = data(:,30);
p_z2 = data(:,31);
p_z_sug = data(:,54);
p_z_corn = data(:,55);
p_z_wheat = data(:,56);
p_z_oat = data(:,57);
p_z_rice = data(:,58);
p_z_cocoa = data(:,59);
hat_p = data(:,62);
l_sug_z = data(:,32);
l_sug_prob = data(:,33);
l_cal_z = data(:,34);
l_cal_prob = data(:,35);
choice_set_size = data(:,36);
choice_set_size_inst = data(:,61);
hat_p_fineline_mean = data(:,63:67);
hat_p_fineline_p20 = data(:,68:72);
hat_p_fineline_p80 = data(:,73:77);
product_entry = data(:,78:171);
fineline_entry = data(:,172:176);
market_size = data(:,37);
market_size_bin = data(:,38);
portion_size = data(:,39);
portion_size_bin = data(:,40);
individual_bins = data(:,41);
age_bins = data(:,42);
income_bins = data(:,43);
pre_sales = data(:,44);
delta_data = data(:,45);
mu_sug_hom = data(:,46);
mu_cal_hom = data(:,47);
sigma_sug_hom = data(:,48);
sigma_cal_hom = data(:,49);
market_bin_stata = data(:,53);

sug = sug/10;
sug_pre = sug_pre/10;
cal = cal/100;
cal_pre = cal_pre/100;

x(:,4) = cal_pre;
x(:,5) = sug_pre;


%% DEFINING VARIABLES

% rename stores, markets & weeks
store = findgroups(store);
market = findgroups(market);
week = findgroups(week);
market_bin = findgroups(market_bin);

% relabel variable indicators to avoid missings
J = max(product);
M = max(market);
T = max(week);
S = max(store);

% create auxiliar variables
logitvar = log(s)-log(s0);
f = dummyvar(fineline);
xi_t = dummyvar(week);
xi_s = dummyvar(store);
xi_j = dummyvar(product);

num_ind_bins_micro = max(individual_bins);
ind_dummies_micro = dummyvar(individual_bins);
product_bins = findgroups(product,individual_bins);
market_product = findgroups(individual_bins,market,product);
xi_j_micro = dummyvar(product_bins);
week_bins = findgroups(week,individual_bins);
xi_t_micro = dummyvar(week_bins);
store_bins = findgroups(store,individual_bins);
xi_s_micro = dummyvar(store_bins);

%% INSTRUMENTS

% price instrument
p_z = hat_p;

% nest instruments
z_i = [choice_set_size_inst/max(product),hat_p_fineline_mean,hat_p_fineline_p20,hat_p_fineline_p80,fineline_entry/max(product)];

% healthiness instruments
bin_cal = round(mu_cal/10);
bin_cal = dummyvar(bin_cal-min(bin_cal)+1);
bin_sug = round(mu_sug/3);
bin_sug = dummyvar(bin_sug-min(bin_sug)+1);
z_Ew = [post.*l_cal_z.*bin_cal,post.*(1-l_cal_z).*bin_cal,post.*l_sug_z.*bin_sug,post.*(1-l_sug_z).*bin_sug];
z_Ew = licols(z_Ew);

%% OTHER VARIABLES

% vector w
w = [cal, sug];
w_pre = [cal_pre,sug_pre];
l = [l_cal, l_sug];
l_z = [l_cal_z,l_sug_z];
labels = [extractData(product,L_cal),extractData(product,L_sug)];

% beliefs
wbar = [350/100,22.5/10];

mu_cal = mu_cal/100;
mu_sug = mu_sug/10;

sigma_cal = sigma_cal/100;
sigma_sug = sigma_sug/10;

mu_cal = ((mu_cal-wbar(1))./std(mu_cal)).*std(cal_pre)+wbar(1);
mu_sug = ((mu_sug-wbar(2))./std(mu_sug)).*std(sug_pre)+wbar(2);

sigma_ratio = std(sug_pre)/std(cal_pre);
    
muw = [mu_cal, mu_sug];
sigma_mu = [sigma_cal, sigma_sug];

muw_fixed = muw;


%% OTHER

maxiters = 1000;
delta_tol = 10^(-14);

[market_x, market_y] = ndgrid(market_bin,1:ns);
index = max(market_x(:,1))*(market_y-1)+market_x;


