
%% PRINT TABLES

%% Print parameters table


coefficients = {'$\bar{\alpha}_l$','$\bar{\alpha}_h$','$\bar{\phi}_l^c$','$\bar{\phi}_h^c$','$\bar{\phi}_l^s$','$\bar{\phi}_h^s$',...
    '$\sigma_{\alpha_l}$','$\sigma_{\alpha_h}$','$\sigma_{\phi^c_l}$','$\sigma_{\phi^c_h}$','$\sigma_{\phi^s_l}$','$\sigma_{\phi^s_h}$','$\rho$','$\mu$',...
    '$\sigma_{\beta_{r_1}}$','$\sigma_{\beta_{r_2}}$','$\sigma_{\beta_{r_3}}$','$\sigma_{\beta_{r_4}}$','$\sigma_{\beta_{r_5}}$'};

delete([path,'00_files/07_outputs/01_demand/01_demand_parameters.tex'])
diary([path,'00_files/07_outputs/01_demand/01_demand_parameters.tex'])
disp(char('\begin{table}[!h]'));
disp(char('\footnotesize'));
disp(char('\centering'));
disp(char('\caption{Demand parameters}'));
disp(char('\begin{tabular}{>{\raggedright}p{0.2\textwidth}cc} \hline'));

for k=1:length(coefficients)
    
    if stars_param(k)==0
        star='';
    elseif stars_param(k)==1
        star='$^{\ast}$';
    elseif stars_param(k)==2
        star='$^{\ast \ast}$';
    elseif stars_param(k)==3
        star='$^{\ast \ast \ast}$';
    end
    disp([coefficients{k},' & ',num2str(params(k)),star,' \\ [0.1em]'])
    disp([' & (',num2str(sd_params(k)),') \\ [0.7em]'])
    
end

disp(char(['\hline']));
disp(char(['\hline']));
disp(char(['\end{tabular}']));
disp(char(['\end{table}']));
disp(' ');
diary off





%% Prepare data for elasticiy/diversion tables

% order names
names_ordered = cell(J,2);
for j=1:J
    temp = strrep(names(product==j,:),'&','');
    names_ordered{j,1} = temp{1,1};
    names_ordered{j,2} = temp{1,2};
end
names_ordered{J+1,1} = 'OUTSIDE OPTION'; 
names_ordered{J+1,2} = ''; 
fineline_ordered = {'PLAIN','SUGARY','CHOCOLATE','OATMEAL','GRANOLA'};

% reduce matrix
big_brands = [2,6,9,18,35,77,81,90,91,94,95];


brands_row = [9,81,70,77,2,35,90,91,4,6,63,15,43,55,54,95];
brands_col = [9,81,77,2,90,91,6,63,43,55];

K1 = length(brands_row);
K2 = length(brands_col);
elast_mat = zeros(K1,K2);
diver_mat = zeros(K1,K2);
share_vec = zeros(K1,0);
names_mat = cell(K1,2);
for j=1:K1
    for k=1:K2
        elast_mat(j,k) = median_elast_mat(brands_row(j),brands_col(k));
        diver_mat(j,k) = median_diversion_mat(brands_row(j),brands_col(k));
    end
    names_mat{j,1}=names_ordered{brands_row(j),1};
    names_mat{j,2}=names_ordered{brands_row(j),2};
    share_vec(j) = tot_shares(brands_row(j));
end

%% Print elasticity table  

delete([path,'00_files/07_outputs/01_demand/02_elasticities.tex'])
diary([path,'00_files/07_outputs/01_demand/02_elasticities.tex'])
disp(char('\begin{landscape}'));
disp(char('\begin{table}[!h]'));
disp(char('\footnotesize'));
disp(char('\centering'));
disp(char('\caption{Price elasticities}'));
cols=[];
for k=1:K2
    cols = [cols 'c' 'c'];
end
disp(char(['\begin{tabular}{>{\raggedright}p{0.2\textwidth}c',cols,'} \hline']));
cols1 = [];
cols = [];
kk=1;
for k=1:K2
    cols = [cols, '& (',int2str(kk),')'];
    kk=kk+1;
    if mod(k,2)==0
    cols1 = [cols1, '& \multicolumn{2}{c}{',fineline_ordered{k/2},'}'];
    kk=kk+1;
    end
end
disp(char(['                     &    & SHARE         ',cols1, '    \\       '])); 
disp(char(['                     &    &          ',cols, '    \\  [1em]      '])); 
i=1;
for j=1:K1
if mod(j-1,3)==0 && j~=K1
    disp('\hline')
    disp([' \multicolumn{',int2str(K2+1),'}{l}{FINELINE: ',fineline_ordered{i},'} \\ [0.7em]'])
    i=i+1;
elseif mod(j-1,3)==0
    disp('\hline')
    disp([' \multicolumn{',int2str(K2+1),'}{l}{OUTSIDE OPTION:} \\ [0.7em]'])
    i=i+1;
end
cols = ['& ',num2str(100*roundn(share_vec(j),-4))];
for k=1:K2
    cols = [cols, '& ',num2str(roundn(elast_mat(j,k),-4))];
end
disp(char([names_mat{j,1},' ',names_mat{j,2},'& (',int2str(j),') ',  cols, '    \\  [0.5em]      ']));
end
disp(char(['\hline']));
disp(char(['\hline']));
disp(char(['\end{tabular}']));
disp(char(['\end{table}']));
disp(char('\end{landscape}'));
disp(' ');
diary off




%% Print diversion ratio table   

delete([path,'00_files/07_outputs/01_demand/03_diversion.tex'])
diary([path,'00_files/07_outputs/01_demand/03_diversion.tex'])
disp(char('\begin{landscape}'));
disp(char('\begin{table}[!h]'));
disp(char('\footnotesize'));
disp(char('\centering'));
disp(char('\caption{Diversion Ratios'));
cols=[];
for k=1:K2
    cols = [cols 'c' 'c'];
end
disp(char(['\begin{tabular}{>{\raggedright}p{0.2\textwidth}c',cols,'} \hline']));
cols1 = [];
cols = [];
kk=1;
for k=1:K2
    cols = [cols, '& (',int2str(kk),')'];
    kk=kk+1;
    if mod(k,2)==0
    cols1 = [cols1, '& \multicolumn{2}{c}{',fineline_ordered{k/2},'}'];
    kk=kk+1;
    end
end
disp(char(['                     &    & SHARE         ',cols1, '    \\       '])); 
disp(char(['                     &    &          ',cols, '    \\  [1em]      '])); 
i=1;
for j=1:K1
if mod(j-1,3)==0 && j~=K1
    disp('\hline')
    disp([' \multicolumn{',int2str(K2+1),'}{l}{FINELINE: ',fineline_ordered{i},'} \\ [0.7em]'])
    i=i+1;
elseif mod(j-1,3)==0
    disp('\hline')
    disp([' \multicolumn{',int2str(K2+1),'}{l}{OUTSIDE OPTION:} \\ [0.7em]'])
    i=i+1;
end
cols = ['& ',num2str(100*roundn(share_vec(j),-4))];
for k=1:K2  
    if brands_row(j)~=brands_col(k)
        cols = [cols, '& ',num2str(100*roundn(diver_mat(j,k),-4))];
    elseif brands_row(j)==brands_col(k)
        cols = [cols, '& . '];
    end
end
disp(char([names_mat{j,1},' ',names_mat{j,2},'& (',int2str(j),') ',  cols, '    \\  [0.5em]      ']));
end
disp(char(['\hline']));
disp(char(['\hline']));
disp(char(['\end{tabular}']));
disp(char(['\end{table}']));
disp(char('\end{landscape}'));
disp(' ');
diary off



