/*******************************************************************************
AUTHOR: Nano Barahona
CREATION: Feb-2020
ACTION: Do plots for nutritional counterfactuals
SUMMARY:

********************************************************************************/

clear all
set more off
set scheme s1mono

******************************************************************************** 
** SET PATH AND LOCALS
******************************************************************************** 

if c(username)=="Nano"   		  global Repo "/Users/Nano/Dropbox/Research/FoodLabels/food_labels/04_replication"
else 							  global Repo "."

global output "${Repo}/00_files/06_figures/03_results"

******************************************************************************** 
** LOAD AND PREPARE DATA
******************************************************************************** 

import delimited "${Repo}/00_files/05_counterfactuals/01_policyEvaluation/01_results.csv" , clear

* transform everything into dollars
gen phi_price = alpha
gen phi_prior_cal = phi_cal
gen phi_prior_sug = phi_sug
gen phi_beliefs_cal = phi_cal
gen phi_beliefs_sug = phi_sug
foreach var in cal sug price prior_cal prior_sug beliefs_cal beliefs_sug  {
	replace `var' = -`var'*phi_`var'/alpha
	cap replace `var'_b = -`var'_b*phi_`var'/alpha
}

local nsim = 20
gen num_cust = 468142
gen num_years = 11*8/52

keep if week >=7

collapse (sum) cs* q* cal* sug* price* taste cost* prior* beliefs* (first) num_cust num_years , by(sim counterfactual)

foreach var in cs q cal sug price taste prior_sug prior_cal beliefs_sug beliefs_cal {
	gen `var'_pc = `var'/(`nsim'*num_cust*num_years)
}

foreach var in cal sug price {
	gen `var'_av = `var'_b/(`nsim'*num_cust*num_years)
}

gen profits_pc = -(price+cost)/(`nsim'*num_cust*num_years)



foreach var in cs_pc cal_pc cal_av sug_pc sug_av price_pc price_av profits_pc prior_sug_pc prior_cal_pc beliefs_sug_pc beliefs_cal_pc  {
	gen temp = `var' if counterfactual == 1
	egen `var'0 = max(temp), by(sim)
	gen log`var' = log(abs(`var'))-log(abs(`var'0))
	replace `var' = `var'-`var'0
	drop temp
}

drop taste_pc 
gen taste_av = 0
gen taste_pc = cs_pc-cal_pc-sug_pc-price_pc
foreach var in cal sug price taste {
	gen `var'_dm = `var'_pc-`var'_av
}
gen cs_av = price_av + sug_av + cal_av + taste_av
gen cs_dm = price_dm + sug_dm + cal_dm + taste_dm
gen welfare_pc = cs_pc + profits_pc
gen prior_cs_pc = price_pc + prior_sug_pc + prior_cal_pc + taste_pc
gen beliefs_cs_pc = price_pc + beliefs_sug_pc + beliefs_cal_pc + taste_pc

keep cs_pc cs_dm cs_av cal_pc cal_dm cal_av sug_pc sug_dm sug_av price_pc price_dm price_av taste_pc taste_dm taste_av profits_pc welfare_pc prior_sug_pc prior_cal_pc prior_cs_pc beliefs_sug_pc beliefs_cal_pc beliefs_cs_pc counterfactual logprice_av logcal_pc logsug_pc

collapse (mean) outcomecs_pc = cs_pc outcomecs_dm = cs_dm outcomecs_av = cs_av outcomecal_pc = cal_pc outcomecal_dm = cal_dm outcomecal_av = cal_av outcomesug_pc = sug_pc outcomesug_dm = sug_dm outcomesug_av = sug_av outcomeprice_pc = price_pc outcomeprice_dm = price_dm outcomeprice_av = price_av outcometaste_pc = taste_pc outcometaste_dm = taste_dm outcometaste_av = taste_av outcomeprofits_pc = profits_pc outcomewelfare_pc = welfare_pc outcomeprior_sug_pc = prior_sug_pc outcomeprior_cal_pc = prior_cal_pc outcomeprior_cs_pc = prior_cs_pc outcomebeliefs_sug_pc = beliefs_sug_pc outcomebeliefs_cal_pc = beliefs_cal_pc outcomebeliefs_cs_pc = beliefs_cs_pc outcomelogprice_av = logprice_av outcomelogsug_pc = logsug_pc outcomelogcal_pc = logcal_pc ///
(p5) p5cs_pc = cs_pc p5cs_dm = cs_dm p5cs_av = cs_av p5cal_pc = cal_pc p5cal_dm = cal_dm p5cal_av = cal_av p5sug_pc = sug_pc p5sug_dm = sug_dm p5sug_av = sug_av p5price_pc = price_pc p5price_dm = price_dm p5price_av = price_av p5taste_pc = taste_pc p5taste_dm = taste_dm p5taste_av = taste_av p5profits_pc = profits_pc p5welfare_pc = welfare_pc p5prior_sug_pc = prior_sug_pc p5prior_cal_pc = prior_cal_pc p5prior_cs_pc = prior_cs_pc p5beliefs_sug_pc = beliefs_sug_pc p5beliefs_cal_pc = beliefs_cal_pc p5beliefs_cs_pc = beliefs_cs_pc ///
(p95) p95cs_pc = cs_pc p95cs_dm = cs_dm p95cs_av = cs_av p95cal_pc = cal_pc p95cal_dm = cal_dm p95cal_av = cal_av p95sug_pc = sug_pc p95sug_dm = sug_dm p95sug_av = sug_av p95price_pc = price_pc p95price_dm = price_dm p95price_av = price_av p95taste_pc = taste_pc p95taste_dm = taste_dm p95taste_av = taste_av p95profits_pc = profits_pc p95welfare_pc = welfare_pc p95prior_sug_pc = prior_sug_pc p95prior_cal_pc = prior_cal_pc p95prior_cs_pc = prior_cs_pc p95beliefs_sug_pc = beliefs_sug_pc p95beliefs_cal_pc = beliefs_cal_pc p95beliefs_cs_pc = beliefs_cs_pc ///
, by(counterfactual)


reshape long outcome p5 p95  , i(counterfactual) j(variable) string

sort variable counterfactual 

gen order = 5*inlist(variable,"sug_pc","sug_av","sug_dm","prior_sug_pc","beliefs_sug_pc")+4*inlist(variable,"cal_pc","cal_av","cal_dm","prior_cal_pc","beliefs_cal_pc")+3*inlist(,variable,"price_pc","price_av","price_dm","welfare_pc") ///
+2*inlist(,variable,"taste_pc","taste_av","taste_dm","profits_pc")+1*inlist(variable,"cs_pc","cs_av","cs_dm","prior_cs_pc","beliefs_cs_pc")

gen order_slides = 1*inlist(variable,"sug_pc","sug_av","sug_dm","prior_sug_pc","beliefs_sug_pc")+2*inlist(variable,"cal_pc","cal_av","cal_dm","prior_cal_pc","beliefs_cal_pc")+3*inlist(,variable,"price_pc","price_av","price_dm","welfare_pc") ///
+4*inlist(,variable,"taste_pc","taste_av","taste_dm","profits_pc")+5*inlist(variable,"cs_pc","cs_av","cs_dm","prior_cs_pc","beliefs_cs_pc")

drop if counterfactual == 0 | counterfactual == 1 | (counterfactual > 4 )

replace counterfactual = counterfactual - 1

gen counter_x = counterfactual if order == 1
replace counter_x = counterfactual + 4 if order == 2
replace counter_x = counterfactual + 8 if order == 3
replace counter_x = counterfactual + 12 if order == 4
replace counter_x = counterfactual + 16 if order == 5

gen counter_slides = counterfactual if order_slides == 1
replace counter_slides = counterfactual + 4 if order_slides == 2
replace counter_slides = counterfactual + 8 if order_slides == 3
replace counter_slides = counterfactual + 12 if order_slides == 4
replace counter_slides = counterfactual + 16 if order_slides == 5


******************************************************************************** 
** PRINT PLOTS
******************************************************************************** 


twoway (bar outcome counter_x if inlist(variable,"cal_pc","price_pc","sug_pc","taste_pc","cs_pc") & counterfactual == 1, lcolor("237 176 32") fcolor("237 176 32")) ///
(bar outcome counter_x if inlist(variable,"cal_pc","price_pc","sug_pc","taste_pc","cs_pc") & counterfactual == 2, lcolor("119 172 48") fcolor("119 172 48")) ///
(bar outcome counter_x if inlist(variable,"cal_pc","price_pc","sug_pc","taste_pc","cs_pc") & counterfactual == 3, fcolor("0 112 189") lcolor("0 112 189")) ///
(rcap p95 p5 counter_x if inlist(variable,"cal_pc","price_pc","sug_pc","taste_pc","cs_pc") & outcome!=0), ///
legend(row(1) order(1 "(1) demand only" 2 "(2) price resp." 3 "(3) equilibrium") region(lw(none)) ) ///
xlabel( 2 "{&Delta}CW" 6 "{&Delta}taste" 10 "-{&Delta}price" 14 "-{&Delta}calories" 18 "-{&Delta}sugar", noticks) yscale(range(-1.8 1.5)) ylabel(-1.5(0.5)1.5,labs(large) grid)  xscale(range(0 12)) ///
xtitle("") ytitle("{&Delta} consumer welfare ($)", size(large)) name(b32,replace)
gr export "${output}/figure6.pdf", replace




