/*******************************************************************************
AUTHOR: Nano Barahona
CREATION: Feb-2019
ACTION: Estimate first stage and others using Stata
SUMMARY:

********************************************************************************/

clear all
set more off
set scheme s1mono

******************************************************************************** 
** SET PATH AND LOCALS
******************************************************************************** 

if c(username)=="Nano"   		  global Repo "/Users/Nano/Dropbox/Research/FoodLabels/food_labels/04_replication"
else 							  global Repo "."

local nsim = 20

global output "${Repo}/00_files/06_figures/03_results"

local c_blue = "0 112 189"

local minsim = 1
local maxsim = 100

******************************************************************************** 
** ACROSS THRESHOLD DISTRIBUTION OF EFFECTS
******************************************************************************** 

local nutrient = "sugar"

import delimited "${Repo}/00_files/05_counterfactuals/02_policyCounterfactuals/01_results.csv" , clear

keep if sim<=`maxsim' & sim>=`minsim'

gen sug_gr = sug

* transform everything into dollars
gen phi_price = alpha
foreach var in cal sug price  {
	replace `var' = `var'*phi_`var'/alpha
	replace `var'_b = `var'_b*phi_`var'/alpha
}

* aggregate values at the consumer-year level

gen num_cust = 468142
gen num_years = 11*8/52

collapse (sum) cs* q* cal* sug* price* taste taxcol cost* (first) num_cust num_years , by(sim counterfactual threshold tax)

foreach var in cs q cal sug price taste taxcol cost {
	gen `var'_pc = `var'/(`nsim'*num_cust*num_years)
}

foreach var in cal sug price cost {
	gen `var'_av = `var'_b/(`nsim'*num_cust*num_years)
}

gen profits_pc = (price-cost-taxcol)/(`nsim'*num_cust*num_years)
gen welfare_pc = cs_pc + profits_pc + taxcol_pc


foreach var in cs_pc cal_pc cal_av sug_pc sug_av price_pc price_av profits_pc cost_av sug_gr taxcol_pc welfare_pc  {
	gen temp = `var' if counterfactual == 1
	egen `var'0 = max(temp), by(sim)
	gen log`var' = log(`var') - log(`var'0)
	replace `var' = `var'-`var'0
	drop temp
}



drop taste_pc 
gen taste_av = 0
gen taste_pc = cs_pc-cal_pc-sug_pc-price_pc
foreach var in cal sug price taste {
	gen `var'_dm = `var'_pc-`var'_av
}
gen cs_av = price_av + sug_av + cal_av + taste_av
gen cs_dm = price_dm + sug_dm + cal_dm + taste_dm

keep cs_pc cs_dm cs_av cal_pc cal_dm cal_av sug_pc sug_dm sug_av price_pc price_dm price_av taste_pc taste_dm taste_av profits_pc welfare_pc cost_av counterfactual threshold logsug_gr logprice_pc taxcol_pc tax cost_pc

collapse (mean) outcomecs_pc = cs_pc outcomecs_dm = cs_dm outcomecs_av = cs_av outcomecal_pc = cal_pc outcomecal_dm = cal_dm outcomecal_av = cal_av outcomesug_pc = sug_pc outcomesug_dm = sug_dm outcomesug_av = sug_av outcomeprice_pc = price_pc outcomeprice_dm = price_dm outcomeprice_av = price_av outcometaste_pc = taste_pc outcometaste_dm = taste_dm outcometaste_av = taste_av outcomeprofits_pc = profits_pc outcomewelfare_pc = welfare_pc outcomecost_av = cost_av  outcomecost_pc = cost_pc  outcometaxcol_pc = taxcol_pc  ///
outcomelogsug_gr = logsug_gr  outcomelogprice_pc = logprice_pc  ///
(p5) p5cs_pc = cs_pc p5cs_dm = cs_dm p5cs_av = cs_av p5cal_pc = cal_pc p5cal_dm = cal_dm p5cal_av = cal_av p5sug_pc = sug_pc p5sug_dm = sug_dm p5sug_av = sug_av p5price_pc = price_pc p5price_dm = price_dm p5price_av = price_av p5taste_pc = taste_pc p5taste_dm = taste_dm p5taste_av = taste_av p5profits_pc = profits_pc p5welfare_pc = welfare_pc p5cost_av = cost_av p5cost_pc = cost_pc p5taxcol_pc = taxcol_pc ///
(p95) p95cs_pc = cs_pc p95cs_dm = cs_dm p95cs_av = cs_av p95cal_pc = cal_pc p95cal_dm = cal_dm p95cal_av = cal_av p95sug_pc = sug_pc p95sug_dm = sug_dm p95sug_av = sug_av p95price_pc = price_pc p95price_dm = price_dm p95price_av = price_av p95taste_pc = taste_pc p95taste_dm = taste_dm p95taste_av = taste_av p95profits_pc = profits_pc p95welfare_pc = welfare_pc p95cost_av = cost_av p95cost_pc = cost_pc p95taxcol_pc = taxcol_pc ///
, by(counterfactual threshold tax)


gen outcomecs_pc_lambda = outcomecs_pc - 0.5*(outcomesug_pc*("`nutrient'"=="sugar") + outcomecal_pc*("`nutrient'"=="calories"))

replace outcomecs_pc = outcomecs_pc + outcometaxcol_pc if counterfactual>=8
gen temp = outcomecs_pc if counterfactual==4
egen max_lab_cs_pc = max(temp)
drop temp


if "`nutrient'"=="calories" {
drop if threshold<200
local xtit = "kcal per 100g"
local thres = 350
local ytext_`nutrient' = 0
}
else if "`nutrient'"=="sugar" {
local xtit = "g of sugar per 100g"
local thres = 22.5
local ytext_`nutrient' = 0
}



local nut = "cs_pc"

local maxy1 = 1
local miny1 = 0
local inter1 = 0.2
local maxy2 = 1
local miny2 = 0
local inter2 = 0.2
local ytit = "{&Delta} consumer welfare ($)"
local place = "nw"
local ytext1 = `miny1'
local ytext2 = `miny2'



twoway  (line outcome`nut' threshold if counterfactual==1 ,  lwidth(1) lcolor(gray)) ///
		(line outcome`nut' threshold if counterfactual==2 ,  lwidth(1) lcolor("237 176 32")) ///
		(line outcome`nut' threshold if counterfactual==4,  lwidth(1) lcolor("0 112 189") lpattern(longdash)) ///
		, name(a01_`nutrient'_`nut', replace)  xline(`thres') xtitle("Policy threshold (`xtit')", size(large)) ytitle( "`ytit'" ,size(large)) title("",size(vlarge)) subtitle(  ,size(large)) ///
		xlab(, labsize(large) ) ylab(0(0.1)0.5,labsize(large)) yscale(range(0 0.5))  ///
		legend(order(2 "(1) demand only" 3 "(3) equilibrium") rows(1)  region(lw(none)) size(medium)) ///
		text(`ytext_`nutrient'' `thres' "Current threshold" ,  placement(`place') orient(vertical) size(medium)) 
gr export "${output}/figure7a.pdf", replace

twoway  (line outcome`nut' tax if counterfactual==1 ,  lwidth(1) lcolor(gray)) ///
		(line max_lab_`nut' tax if counterfactual==9    ,  lwidth(1) lcolor("0 112 189") lpattern(longdash)) ///
		(line outcome`nut' tax if counterfactual==9 ,  lwidth(1) lcolor("237 176 32")) ///
		, name(a02_`nutrient'_`nut', replace)  xline(`thres') xtitle("Tax value (cents per gram of `nutrient')", size(large)) ytitle( "`ytit'" ,size(large)) title("",size(vlarge)) subtitle(  ,size(large)) ///
		xlab(, labsize(large) ) ylab(0(0.1)0.5,labsize(large)) yscale(range(0 0.5))  ///
		legend(order(2 "Food labels" 3 "Sugar tax") rows(1)  region(lw(none)) size(medium)) ///
		text(`ytext_`nutrient'' `thres' "Current threshold" ,  placement(`place') orient(vertical) size(medium)) 
gr export "${output}/figure7b.pdf", replace







