/*******************************************************************************
AUTHOR: Nano Barahona
CREATION: Feb-2019
ACTION: Estimate first stage and others using Stata
SUMMARY:

********************************************************************************/

clear all
set more off
set scheme s1color

******************************************************************************** 
** SET PATH AND LOCALS
******************************************************************************** 

if c(username)=="Nano"   		  global Repo "/Users/Nano/Dropbox/Research/FoodLabels/food_labels/04_replication"
else 							  global Repo "."

local nsim = 20

global output "${Repo}/00_files/06_figures/03_results"



******************************************************************************** 
** MAIN PLOTS
******************************************************************************** 

local grid_l = 51
local grid_p = 41

import delimited "${Repo}/00_files/05_counterfactuals/02_policyCounterfactuals/01_results.csv" , clear
tempfile results_data
save `results_data', replace

local nutrient="sugar"

forv lambda_index=1/`grid_l' {
forv psi_index=1/`grid_p' {

local lambda = 1+(`lambda_index'-1)*1.5/(`grid_l'-1)
local psi = 1.2-(`psi_index'-1)*0.4/(`grid_p'-1)

** LOAD DATA FROM LABELS COUNTERFACTUAL **
use `results_data', clear

* transform everything into dollars
gen phi_price = alpha
foreach var in cal sug price  {
	replace `var' = `var'*phi_`var'/alpha
	replace `var'_b = `var'_b*phi_`var'/alpha
}

* aggregate values at the consumer-year level

gen num_cust = 468142
gen num_years = 11*8/52

collapse (sum) cs* q* cal* sug* price* taste taxcol cost* (first) num_cust num_years , by(sim counterfactual threshold tax)

foreach var in cs q cal sug price taste taxcol cost {
	gen `var'_pc = `var'/(`nsim'*num_cust*num_years)
}

gen profits_pc = (price-cost-taxcol)/(`nsim'*num_cust*num_years)
gen welfare_pc = cs_pc + profits_pc + taxcol_pc


foreach var in cs_pc cal_pc sug_pc profits_pc taxcol_pc  {
	gen temp = `var' if counterfactual==1
	egen `var'0 = max(temp), by(sim)
	replace `var' = `var'-`var'0
	drop temp
}

collapse (mean) cs* q* cal* sug* price* taste cost* profits* welfare* taxcol*  , by(counterfactual threshold tax)

replace cs_pc = cs_pc - (`lambda'-1)*(sug_pc*("`nutrient'"=="sugar") + cal_pc*("`nutrient'"=="calories")) + `psi'*taxcol_pc

qui: sum cs_pc if counterfactual==9
local taxcs_`lambda_index'_`psi_index' = r(max)

qui: sum cs_pc if counterfactual==4
local labcs_`lambda_index'_`psi_index' = r(max)

}
}

clear
local tobs = `grid_l'*`grid_p'
set obs `tobs'

foreach var in lambda psi labcs taxcs {
	gen `var'=.
}

forv lambda_index=1/`grid_l' {
forv psi_index=1/`grid_p' {

local obs = `grid_p'*(`lambda_index'-1)+`psi_index'
local lambda = 1+(`lambda_index'-1)*1.5/(`grid_l'-1)
local psi = 1.2-(`psi_index'-1)*0.4/(`grid_p'-1)

replace lambda = `lambda' if _n==`obs'
replace psi = `psi' if _n==`obs'

replace labcs = `labcs_`lambda_index'_`psi_index'' if _n==`obs'
replace taxcs = `taxcs_`lambda_index'_`psi_index'' if _n==`obs'
}
}

gen difcs = (labcs-taxcs>0)
gen dif1cs = labcs-taxcs
gen dif1cs_alt = labcs-taxcs
lab var dif1cs "CW(Labels)-CW(Tax) ($)"
lab var dif1cs_alt "CW(Labels)-CW(Tax) ($)"

gen dots = 0
replace dots = 1 if lambda == 1 & abs(psi-1) <= 0.001
gen area = 0
replace area = 1 if (lambda>=1.48 & lambda <=2.07) & (psi>=0.7 & psi <=1.2)
gen maxpsi = 1.2
gen minpsi = 0.8
*egen maxpsi = max(psi) if area==1 , by(lambda)
*egen minpsi = min(psi) if area==1 , by(lambda)

local nutrient = "sugar"

if "`nutrient'"=="sugar" {
	*local cuts = "-4 -2 -1 0 0.5 1"
	*local cuts = "-2 -1.5 -1 -0.5 0 0.25 0.5"
	local cuts = "-2 -1.5 -1 -0.5 0 0.25 0.5 0.75"
}
else if "`nutrient'"=="calories" {
	local cuts = "-3 -2 -1 0 1 2 3"
}


twoway 	(contour dif1cs psi lambda, ccuts(`cuts') crule(intensity) scolor(red) ecolor(navy8) clegend(pos(3) ring(1) bmargin(tiny)  width(5) )) ///
		(contourline dif1cs psi lambda, ccuts(0) colorlines crule(linear) scolor(black) ecolor(black)) 	, name(a1,replace) ///
		text(0.9 1.43 "CW(Labels) > CW(Tax)" 1.1 2 "CW(Labels) < CW(Tax)", size(large)) xtitle("{&lambda}",size(large)) ytitle("{&psi}",size(large)) ylab( ,labsize(large)) xlab(,labsize(large))
		
		
twoway 	(contour dif1cs psi lambda, ccuts(`cuts') crule(intensity) scolor(red) ecolor(navy8) clegend(pos(3) ring(1) bmargin(tiny)  width(5) )) ///
		(contourline dif1cs psi lambda, ccuts(0) colorlines crule(linear) scolor(black) ecolor(black)) 	, name(a1_d,replace) ///
		text(0.9 1.43 "CW(Labels) > CW(Tax)" 1.08 2 "CW(Labels) < CW(Tax)", size(medlarge)) xtitle("{&lambda}",size(large)) ytitle("{&psi}",size(large)) ylab( ,labsize(large)) xlab(,labsize(large))
gr export "${output}/figure7c.pdf", replace



