

function [G02] = a00_main(rho_level)

rng(2020)

global J  X Z market market_product muw_fixed sigma_mu vp_ind vf_ind bins_weights_micro ind_dummies_micro market_bin f ns sigma_ratio wmatrix wbar post product ...
    product_bins exempted l individual_bins X s s_g vp_ind vf_ind logitvar maxiters delta_tol f ns ind_dummies_micro bins_weights_micro market_x market_y index

path = '../../../';
addpath([path,'03_estimation/99_functions/'])
addpath([path,'03_estimation/01_demand/'])

ktropts = optimset('TolFun',1E-09,'TolX',1E-24,'TolCon',1E-24); 

fprintf('\n------------------------------------------------------------\n');
fprintf(' DEMAND MODEL ESTIMATION ');
disp(' ');
disp(['Rho-level: ', int2str(rho_level)]);
fprintf('\n------------------------------------------------------------\n');

tic

%% LOAD DATA AND GENERATE RELEVANT VARIABLES
disp(' ')
disp('Step 1: Loading the data...')

a01_loadData;

disp(['Data loaded after: ', num2str(toc/60), ' minutes.'])

%% DEFINE FIXED EFFECTS

fe = [xi_j_micro(:,1:length(xi_j_micro(1,:))-2),xi_t_micro(:,1:length(xi_t_micro(1,:))-2),xi_s_micro(:,1:length(xi_s_micro(1,:))-2),ind_dummies_micro(:,1:length(ind_dummies_micro(1,:))-1),ones(length(p),1)];
fe = licols(fe);

%% DEFINE INSTRUMENTS

X = [repmat(p,[1,2]).*ind_dummies_micro,fe];
Z = [repmat(p_z,[1,2]).*expand(ind_dummies_micro,[1,length(p_z(1,:))]),repmat(z_Ew,[1,2]).*expand(ind_dummies_micro,[1,length(z_Ew(1,:))]),repmat(z_i,[1,2]).*expand(ind_dummies_micro,[1,length(z_i(1,:))]),fe]; 
Z = licols(Z);
wmatrix = inv(Z'*Z);

disp(['Instruments and fixed effects created after: ', num2str(toc/60), ' minutes.'])

%% ESTIMATION

disp(' ')
disp('Step 2: Estimating nested logit model...')

% x01 = [-1.38298831847693,-1.68065495561326,-3.36384839933665,-3.40107883990446,-5.17303736859388,-5.14889261666835];
% x02 = [0,0.0322115385581133,-0.558084994938953,1.65580765406874];
% x03 = -log(1/(0.959640167203358)-1);
% x04 = [tan(pi*(0.368136244860994)/(5*2)),tan(pi*(1.283008227992368)/(5*2))]; 
% x05 = zeros(1,5);
% x06 = zeros(1,2);
% x07 = [0.0585187263193139,0.195483574053715,-0.214693837523484,0.0361817476471113,0.295225055206506];
% x08 = zeros(1,10);

x01 = [-1.38,-1.68,-3.36,-3.4,-5.17,-5.15];
x02 = [0.03,-0.56,1.65];  
x04 = tan(pi*(0.368130879616284)/(5*2)); 
x05 = [0.06,0.2,-0.21,0.03,0.3];

if rho_level==1
    x03 = -log(1/(0.959640167203358)-1);
elseif rho_level==2
    x03 = -log(1/(0.9)-1);
elseif rho_level==3
    x03 = -log(1/(0.8)-1);
elseif rho_level==4
    x03 = -log(1/(0.7)-1);
elseif rho_level==5
    x03 = -log(1/(0.6)-1);
elseif rho_level==6
    x03 = -log(1/(0.5)-1);
end

rho_new = 1/(1+exp(-x03));
adj = ((1-rho_new)/(1-0.959640167203358)); 
x05 = x05*sqrt(adj);
x01 = x01 + log(adj);

objFun = @(x) a01_ComputeDistanceVector_robust(x(1:6),x(7:9),x03,x04,x(10:14));
x0 = [x01,x02,x05];
xl = [-Inf*ones(size(x01)),-2*sqrt(log(adj)/4+1)*ones(1,3),-0.4*sqrt(adj)*ones(size(x05))];
xu = [ones(size(x01)),2*sqrt(log(adj)/4+1)*ones(1,3),0.4*sqrt(adj)*ones(size(x05))];

[xsol,~] = knitromatlab(objFun,x0,[],[],[],[],xl,xu,[],[],ktropts,[path,'03_estimation/99_functions/knitroOpts.opt']);

x01 = xsol(1:6);
x02 = xsol(7:9);
x05 = xsol(10:14);


%% RECOVERING RESULTS


[G,dG,betahat,delta,moments,dmoments,e,V,si,sig] = a01_ComputeDistanceVector_robust(x01,x02,x03,x04,x05,1);

%% SAVING OUTPUT

disp(' ')
disp('Step 3: Saving output...')

rho_hat = 1./(1+exp(-[x03,x03]));
mu_hat = 5*(2/pi)*atan(x04);
mu_hat = [mu_hat,sigma_ratio*mu_hat];
mu_param = std(cal_pre)*mu_hat(1);

alpha_hat = [x01(1),x01(2)];
phi_cal_hat = [x01(3),x01(4)];
phi_sug_hat = [x01(5),x01(6)];
alpha_mean = [exp(x01(1)+x02(1)/2),exp(x01(2)+x02(1)/2)];
phic_mean = [exp(x01(3)+x02(2)/2),exp(x01(4)+x02(2)/2)];
phis_mean = [exp(x01(5)+x02(3)/2),exp(x01(6)+x02(3)/2)];
sigma_alpha = [sqrt(exp(x02(1)^2-1)*exp(2*x01(1)+x02(1)^2)),sqrt(exp(x02(1)^2-1)*exp(2*x01(2)+x02(1)^2))];
sigma_phic = [sqrt(exp(x02(2)^2-1)*exp(2*x01(3)+x02(2)^2)),sqrt(exp(x02(2)^2-1)*exp(2*x01(4)+x02(2)^2))];
sigma_phis = [sqrt(exp(x02(3)^2-1)*exp(2*x01(5)+x02(3)^2)),sqrt(exp(x02(3)^2-1)*exp(2*x01(6)+x02(3)^2))];

params = [alpha_mean';phic_mean';phis_mean';sigma_alpha';sigma_phic';sigma_phis';rho_hat(1);mu_param;abs(x05)'];

Sigma_hat = [x02,x05];
indiv_shares_hat = si;

start = 1; 

xi_j_hat = [betahat(start:2:start+2*(J-2)),betahat(start+1:2:start+1+2*(J-2));0,0];
xi_t_hat = [betahat(start+1+2*(J-2)+1:2:start+1+2*(J-2)+1+2*(T-2)),betahat(start+1+2*(J-2)+2:2:start+1+2*(J-2)+1+2*(T-2)+1);0,0];
xi_s_hat = [betahat(start+1+2*(J-2)+1+2*(T-2)+2:2:start+1+2*(J-2)+1+2*(T-2)+2+2*(S-2)),betahat(start+1+2*(J-2)+1+2*(T-2)+3:2:start+1+2*(J-2)+1+2*(T-2)+2+2*(S-2)+1);0,0];
beta0_hat = [betahat(start+1+2*(J-2)+1+2*(T-2)+2+2*(S-2)+2)+betahat(start+1+2*(J-2)+1+2*(T-2)+2+2*(S-2)+3),betahat(start+1+2*(J-2)+1+2*(T-2)+2+2*(S-2)+3)];
xi_hat = e;

sigma_mu_hat = sigma_mu;

[Ew_hat,~,~,muw_hat] = a03_calculatePosteriors(mu_hat,muw,sigma_mu);

save([path,'00_files/05_counterfactuals/03_robustness/01_demandparams_r',int2str(rho_level)],'alpha_hat','phi_cal_hat','phi_sug_hat','Sigma_hat','rho_hat','sigma_mu_hat','xi_j_hat','xi_t_hat','xi_s_hat','beta0_hat','muw_hat','xi_hat','data','names','Ew_hat','vp_ind','vf_ind','indiv_shares_hat','params','xsol','x0')



end