
%% load results

function [output] = b01_loadResults(rho_value)

global M N J data_product product_wide exempted_wide nut_labeled

path = '../../../';
addpath([path,'04_counterfactuals/03_robustness/a03_policyEvaluation/'])
addpath([path,'04_counterfactuals/98_simulation_codes/'])
addpath([path,'04_counterfactuals/99_functions/'])

exemption_mode = 'yes'; %no/yes 
nut_labeled = 'both'; %calories/sugar/both
smoot_vars = "no";

a01_parameters_robust;
a02_exogenousVars;

alpha_param = reshape(alpha_wide(:,1:J)',[J*M*N,1]);
phi_cal_param = reshape(phi_cal_wide(:,1:J)',[J*M*N,1]);
phi_sug_param = reshape(phi_sug_wide(:,1:J)',[J*M*N,1]);
individual_id = findgroups(alpha_param,phi_cal_param,phi_sug_param);

week_type = findgroups(week,individual_id);
product_type = findgroups(product,individual_id);
market_type = findgroups(market,individual_id); 

file = '03_results';

num_customers = 521000;
Num = 0;
table = [];

for it=1:100 
if isfile([path,'00_files/05_counterfactuals/03_robustness/01_simulations/results_r',int2str(rho_value),'_',int2str(it),'.mat'])
    Num = Num+1;
    display(['loading data from iteration: ',int2str(it)])
    
    load([path,'00_files/05_counterfactuals/03_robustness/01_simulations/results_r',int2str(rho_value),'_',int2str(it)]);
    
    sb = outcomes{1}(:,1);
   
    
    for citer = 1:7
        s = outcomes{citer}(:,1);
        p = outcomes{citer}(:,2);
        c = outcomes{citer}(:,3);
        cal = outcomes{citer}(:,4);
        sug = outcomes{citer}(:,5);
        cs = outcomes{citer}(:,6);
        
        if citer == 1
            policy = 'no';
        elseif citer <=4
            policy = 'equilibrium';
        else
            policy = 'perfect_equilibrium';
        end
        
        temp = accumarray(market_type,s);
        s0 = 1-temp(market_type);
        
        % estimate beliefs for subjective welfare
        cal_wide = [reshape(cal,[J,N*M])',zeros(N*M,1)];
        sug_wide = [reshape(sug,[J,N*M])',zeros(N*M,1)];       
        l_cal_wide = post_wide.*(cal_wide>wbar(1)).*(1-exempted_wide);
        l_sug_wide = post_wide.*(sug_wide>wbar(2)).*(1-exempted_wide);
        Elab_cal_wide = [sigmamu_cal_wide(:,1:J).*((normpdf((wbar(1)-mu_cal_wide(:,1:J))./sigmamu_cal_wide(:,1:J))./(1-normcdf((wbar(1)-mu_cal_wide(:,1:J))./sigmamu_cal_wide(:,1:J))))),zeros(N*M,1)];
        Enolab_cal_wide = [-sigmamu_cal_wide(:,1:J).*((normpdf((wbar(1)-mu_cal_wide(:,1:J))./sigmamu_cal_wide(:,1:J))./(normcdf((wbar(1)-mu_cal_wide(:,1:J))./sigmamu_cal_wide(:,1:J))))),zeros(N*M,1)];
        Elab_cal_wide(Elab_cal_wide==Inf|isnan(Elab_cal_wide)) = wbar(1)*ones(length(mu_cal_wide(Elab_cal_wide==Inf|isnan(Elab_cal_wide))),1)-mu_cal_wide(Elab_cal_wide==Inf|isnan(Elab_cal_wide));
        Enolab_cal_wide(Enolab_cal_wide==-Inf|isnan(Enolab_cal_wide)) = wbar(1)*ones(length(mu_cal_wide(Enolab_cal_wide==-Inf|isnan(Enolab_cal_wide))),1)-mu_cal_wide(Enolab_cal_wide==-Inf|isnan(Enolab_cal_wide));
        Elab_sug_wide = [sigmamu_sug_wide(:,1:J).*((normpdf((wbar(2)-mu_sug_wide(:,1:J))./sigmamu_sug_wide(:,1:J))./(1-normcdf((wbar(2)-mu_sug_wide(:,1:J))./sigmamu_sug_wide(:,1:J))))),zeros(N*M,1)];
        Enolab_sug_wide = [-sigmamu_sug_wide(:,1:J).*((normpdf((wbar(2)-mu_sug_wide(:,1:J))./sigmamu_sug_wide(:,1:J))./(normcdf((wbar(2)-mu_sug_wide(:,1:J))./sigmamu_sug_wide(:,1:J))))),zeros(N*M,1)];
        Elab_sug_wide(Elab_sug_wide==Inf|isnan(Elab_sug_wide)) = wbar(2)*ones(length(mu_sug_wide(Elab_sug_wide==Inf|isnan(Elab_sug_wide))),1)-mu_sug_wide(Elab_sug_wide==Inf|isnan(Elab_sug_wide));
        Enolab_sug_wide(Enolab_sug_wide==-Inf|isnan(Enolab_sug_wide)) = wbar(2)*ones(length(mu_sug_wide(Enolab_sug_wide==-Inf|isnan(Enolab_sug_wide))),1)-mu_sug_wide(Enolab_sug_wide==-Inf|isnan(Enolab_sug_wide));
        E_shifter = {Elab_cal_wide,Enolab_cal_wide,Elab_sug_wide,Enolab_sug_wide};
        [E_cal_wide,E_sug_wide] = a05_calculateExpectedw(mu_cal_wide,mu_sug_wide,post_wide,l_cal_wide,l_sug_wide,cal_wide,sug_wide,E_shifter,policy);
        E_cal = reshape(E_cal_wide(:,1:J)',[J*M*N,1]);
        E_sug = reshape(E_sug_wide(:,1:J)',[J*M*N,1]);
        
        % weekly outcomes
        week_tot = extractData(week_type(sb>0),week(sb>0));
        type_tot = extractData(week_type(sb>0),individual_type(sb>0));
        alpha_tot = extractData(week_type(sb>0),alpha_param(sb>0));
        phi_cal_tot = extractData(week_type(sb>0),phi_cal_param(sb>0));
        phi_sug_tot = extractData(week_type(sb>0),phi_sug_param(sb>0));
        cs_tot = accumarray(week_type(sb>0),10*cs(sb>0).*s(sb>0).*portion_size_bins(sb>0).*market_size_bins(sb>0)./(1-s0(sb>0)));
        q_tot = accumarray(week_type(sb>0),s(sb>0).*portion_size_bins(sb>0).*market_size_bins(sb>0));
        cal_tot = accumarray(week_type(sb>0),10*cal(sb>0).*s(sb>0).*portion_size_bins(sb>0).*market_size_bins(sb>0));
        sug_tot = accumarray(week_type(sb>0),10*sug(sb>0).*s(sb>0).*portion_size_bins(sb>0).*market_size_bins(sb>0));
        prior_cal_tot = accumarray(week_type(sb>0),10*mu_cal(sb>0).*s(sb>0).*portion_size_bins(sb>0).*market_size_bins(sb>0));
        prior_sug_tot = accumarray(week_type(sb>0),10*mu_sug(sb>0).*s(sb>0).*portion_size_bins(sb>0).*market_size_bins(sb>0));
        beliefs_cal_tot = accumarray(week_type(sb>0),10*E_cal(sb>0).*s(sb>0).*portion_size_bins(sb>0).*market_size_bins(sb>0));
        beliefs_sug_tot = accumarray(week_type(sb>0),10*E_sug(sb>0).*s(sb>0).*portion_size_bins(sb>0).*market_size_bins(sb>0));
        price_tot = accumarray(week_type(sb>0),10*p(sb>0).*s(sb>0).*portion_size_bins(sb>0).*market_size_bins(sb>0));
        cost_tot = accumarray(week_type(sb>0),10*c(sb>0).*s(sb>0).*portion_size_bins(sb>0).*market_size_bins(sb>0));
        taste_tot = accumarray(week_type(sb>0),10*xi_sum(sb>0).*s(sb>0).*portion_size_bins(sb>0).*market_size_bins(sb>0));
        base_q = accumarray(week_type(sb>0),sb(sb>0).*portion_size_bins(sb>0).*market_size_bins(sb>0));
        base_cal = accumarray(week_type(sb>0),10*cal(sb>0).*sb(sb>0).*portion_size_bins(sb>0).*market_size_bins(sb>0));
        base_sug = accumarray(week_type(sb>0),10*sug(sb>0).*sb(sb>0).*portion_size_bins(sb>0).*market_size_bins(sb>0));
        base_price = accumarray(week_type(sb>0),10*p(sb>0).*sb(sb>0).*portion_size_bins(sb>0).*market_size_bins(sb>0));
        base_cost = accumarray(week_type(sb>0),10*c(sb>0).*sb(sb>0).*portion_size_bins(sb>0).*market_size_bins(sb>0));
        
        table = [table;it*ones(T*N,1),citer*ones(T*N,1),week_tot,type_tot,cs_tot,q_tot,cal_tot,sug_tot,price_tot,cost_tot,taste_tot,base_q,base_cal,base_sug,base_price,base_cost,alpha_tot,phi_cal_tot,phi_sug_tot,prior_cal_tot,prior_sug_tot,beliefs_cal_tot,beliefs_sug_tot];
        
        
    end
    
    post_data = (week>6);
    shares = outcomes{1,1}(:,1).*(1-post_data)+outcomes{4,1}(:,1).*(post_data);
    price = outcomes{1,1}(:,2).*(1-post_data)+outcomes{4,1}(:,2).*(post_data);
    cal = outcomes{1,1}(:,4).*(1-post_data)+outcomes{4,1}(:,4).*(post_data);
    sug = outcomes{1,1}(:,5).*(1-post_data)+outcomes{4,1}(:,5).*(post_data);
    Lcal = (outcomes{4,1}(:,4)>350).*(1-exempted);
    Lsug = (outcomes{4,1}(:,5)>22.5).*(1-exempted);
    
  
    
    
end
end

    
    
T1 = array2table(table);
T1.Properties.VariableNames = {'sim','counterfactual','week','type','cs','q','cal','sug','price','cost','taste','q_b','cal_b','sug_b','price_b','cost_b','alpha','phi_cal','phi_sug','prior_cal','prior_sug','beliefs_cal','beliefs_sug'};  
writetable(T1,[path,'00_files/05_counterfactuals/03_robustness/',file,'_r',int2str(rho_value),'.csv'],'Delimiter',',','QuoteStrings',true)
   

output = 1;

end

