
# TITLE: Replication codes
# AUTHOR: Nano Barahona, Cristobal Otero, Sebastian Otero
# CREATION: Dec-2022
# ACTION: Runs the codes that produce the results of "Equilibrium Effects of Food Labeling Policies"

# Comments: 
# This script contains sbatach submissions using SLURM in Stanford's server Sherlock.
# The codes use the following programs: R, Stata, Matlab, Knitro.
# Some stata functions may need to be installed by `ssc install name_of_the_function`.
# Examples: recast2, reghdfe, ftools, geodist, rforest.
# The different steps need to be ran sequentially. STEP 2, for example, only will run after STEP 1 finishes running.


#########################################
##  STEP 1: Export Walmart raw data
#########################################

sbatch 01_bash/01_extractData.sbatch

#########################################
##  STEP 2: Prepare consumer panel
#########################################

sbatch 01_bash/02_masterPanel.sbatch

#########################################
##  STEP 3: Limit data to cereal purchases
#########################################

# Limit sample to Cereal purchases
sbatch 01_bash/03_buildCerealPanel.sbatch

#########################################
##  STEP 4: Prepare auxiliary data
#########################################

# Prepare auxiliary data
sbatch 01_bash/04_prepareAuxData.sbatch

#########################################
##  STEP 5: Build final sample
#########################################

# Build final sample
sbatch 01_bash/05_buildMainData.sbatch

#########################################
##  STEP 6: Estimate demand
#########################################

# Demand estimation
sbatch 01_bash/06_estimateDemand.sbatch

# Demand estimation (robustness)
sbatch 01_bash/14_robustDemand.sbatch

#########################################
##  STEP 7: Estimate supply PART I
#########################################

sbatch 01_bash/07_findIndifferentCost.sbatch

sbatch 01_bash/15_robustSupply1.sbatch

#########################################
##  STEP 8: Estimate supply PART II
#########################################

sbatch 01_bash/08_estimateSupply.sbatch

sbatch 01_bash/16_robustSupply2.sbatch

#########################################
##  STEP 9: Run counterfactuals
#########################################

sbatch 01_bash/09_polEval.sbatch

sbatch 01_bash/10_polCounter.sbatch

sbatch 01_bash/17_robustEval.sbatch

#########################################
##  STEP 10: Aggregate counterfactual outcomes
#########################################

sbatch 01_bash/11_loadResults.sbatch

sbatch 01_bash/12_modelData.sbatch

sbatch 01_bash/18_robustResults.sbatch

#########################################
##  STEP 11: Produce plots and tables
#########################################

sbatch 01_bash/13_outputPlots.sbatch


